@@ -87,6 +87,9 @@ void proto_reg_handoff_pkcs1(void) {
 	/* ECDSA SHA-1 algorithm from RFC 3279 */
 	register_ber_oid_dissector("1.2.840.10045.4.1", dissect_ber_oid_NULL_callback, proto_pkcs1, "ecdsa-with-SHA1");
 
+	/* SM2-with-SM3 from GM/T 0006 Cryptographic application identifier criterion specification */
+	register_ber_oid_dissector("1.2.156.10197.1.501", dissect_ber_oid_NULL_callback, proto_pkcs1, "SM2-with-SM3");
+
 	/* ECDSA SHA2 algorithms from X9.62, RFC5480, RFC 5758, RFC 5912 */
 	register_ber_oid_dissector("1.2.840.10045.4.3.1", dissect_ber_oid_NULL_callback, proto_pkcs1, "ecdsa-with-SHA224");
 	register_ber_oid_dissector("1.2.840.10045.4.3.2", dissect_ber_oid_NULL_callback, proto_pkcs1, "ecdsa-with-SHA256");
@@ -113,11 +116,59 @@ void proto_reg_handoff_pkcs1(void) {
 	oid_add_from_string("sect571k1","1.3.132.0.38");
 	oid_add_from_string("sect571r1","1.3.132.0.39");
 
+	/* SM2 from GM/T 0006 Cryptographic application identifier criterion specification */
+	oid_add_from_string("sm2","1.2.156.10197.1.301");
+
 	/* sha2 family, see RFC3447 and http://www.oid-info.com/get/2.16.840.1.101.3.4.2 */
 	oid_add_from_string("sha256", "2.16.840.1.101.3.4.2.1");
 	oid_add_from_string("sha384", "2.16.840.1.101.3.4.2.2");
 	oid_add_from_string("sha512", "2.16.840.1.101.3.4.2.3");
 	oid_add_from_string("sha224", "2.16.840.1.101.3.4.2.4");
 
+	/* SM3 from GM/T 0006 Cryptographic application identifier criterion specification */
+	oid_add_from_string("sm3","1.2.156.10197.1.401");
+
+	/* PQC digital signature algorithms from OQS-OpenSSL,
+		see https://github.com/open-quantum-safe/openssl/blob/OQS-OpenSSL_1_1_1-stable/oqs-template/oqs-sig-info.md */
+	oid_add_from_string("dilithium2", "1.3.6.1.4.1.2.267.7.4.4");
+	oid_add_from_string("p256_dilithium2", "1.3.9999.2.7.1");
+	oid_add_from_string("rsa3072_dilithium2", "1.3.9999.2.7.2");
+	oid_add_from_string("dilithium3", "1.3.6.1.4.1.2.267.7.6.5");
+	oid_add_from_string("p384_dilithium3", "1.3.9999.2.7.3");
+	oid_add_from_string("dilithium5", "1.3.6.1.4.1.2.267.7.8.7");
+	oid_add_from_string("p521_dilithium5", "1.3.9999.2.7.4");
+	oid_add_from_string("dilithium2_aes", "1.3.6.1.4.1.2.267.11.4.4");
+	oid_add_from_string("p256_dilithium2_aes", "1.3.9999.2.11.1");
+	oid_add_from_string("rsa3072_dilithium2_aes", "1.3.9999.2.11.2");
+	oid_add_from_string("dilithium3_aes", "1.3.6.1.4.1.2.267.11.6.5");
+	oid_add_from_string("p384_dilithium3_aes", "1.3.9999.2.11.3");
+	oid_add_from_string("dilithium5_aes", "1.3.6.1.4.1.2.267.11.8.7");
+	oid_add_from_string("p521_dilithium5_aes", "1.3.9999.2.11.4");
+	oid_add_from_string("falcon512", "1.3.9999.3.1");
+	oid_add_from_string("p256_falcon512", "1.3.9999.3.2");
+	oid_add_from_string("rsa3072_falcon512", "1.3.9999.3.3");
+	oid_add_from_string("falcon1024", "1.3.9999.3.4");
+	oid_add_from_string("p521_falcon1024", "1.3.9999.3.5");
+	oid_add_from_string("picnicl1full", "1.3.6.1.4.1.311.89.2.1.7");
+	oid_add_from_string("p256_picnicl1full", "1.3.6.1.4.1.311.89.2.1.8");
+	oid_add_from_string("rsa3072_picnicl1full", "1.3.6.1.4.1.311.89.2.1.9");
+	oid_add_from_string("picnic3l1", "1.3.6.1.4.1.311.89.2.1.21");
+	oid_add_from_string("p256_picnic3l1", "1.3.6.1.4.1.311.89.2.1.22");
+	oid_add_from_string("rsa3072_picnic3l1", "1.3.6.1.4.1.311.89.2.1.23");
+	oid_add_from_string("rainbowIclassic", "1.3.9999.5.1.1.1");
+	oid_add_from_string("p256_rainbowIclassic", "1.3.9999.5.1.2.1");
+	oid_add_from_string("rsa3072_rainbowIclassic", "1.3.9999.5.1.3.1");
+	oid_add_from_string("rainbowVclassic", "1.3.9999.5.3.1.1");
+	oid_add_from_string("p521_rainbowVclassic", "1.3.9999.5.3.2.1");
+	oid_add_from_string("sphincsharaka128frobust", "1.3.9999.6.1.1");
+	oid_add_from_string("p256_sphincsharaka128frobust", "1.3.9999.6.1.2");
+	oid_add_from_string("rsa3072_sphincsharaka128frobust", "1.3.9999.6.1.3");
+	oid_add_from_string("sphincssha256128frobust", "1.3.9999.6.4.1");
+	oid_add_from_string("p256_sphincssha256128frobust", "1.3.9999.6.4.2");
+	oid_add_from_string("rsa3072_sphincssha256128frobust", "1.3.9999.6.4.3");
+	oid_add_from_string("sphincsshake256128frobust", "1.3.9999.6.7.1");
+	oid_add_from_string("p256_sphincsshake256128frobust", "1.3.9999.6.7.2");
+	oid_add_from_string("rsa3072_sphincsshake256128frobust", "1.3.9999.6.7.3");
+
 }
 
