@@ -325,8 +325,9 @@ force_reassemble_seq(reassembly_table *table, packet_info *pinfo, guint32 id)
 	  last_fd=fd_i;
 	}
 
-	data = (guint8 *) wmem_alloc(pinfo->pool, size);
+	data = (guint8 *) g_malloc(size);
 	fd_head->tvb_data = tvb_new_real_data(data, size, size);
+        tvb_set_free_cb(fd_head->tvb_data, g_free);
 	fd_head->len = size;		/* record size for caller	*/
 
 	/* add all data fragments */
