@@ -22,6 +22,7 @@
 
 #include <epan/packet.h>
 #include <epan/prefs.h>
+
 #include <wiretap/blf.h>
 
 static int proto_blf = -1;
@@ -395,6 +396,7 @@ dissect_blf_api_version(proto_tree *tree, int hf, tvbuff_t *tvb, gint offset, gi
 }
 
 static int
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_blf_lobj(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, gint offset_orig) {
     proto_item    *ti_root = NULL;
     proto_item    *ti = NULL;
@@ -462,7 +464,7 @@ dissect_blf_lobj(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, gint o
             }
 
             /* TODO: actually the objects might overlap containers, which we do not consider here... */
-            if (sub_tvb) {
+            if (sub_tvb && tvb_captured_length(sub_tvb) > 0) {
                 guint offset_sub = 0;
                 ti = proto_tree_add_item(objtree, hf_blf_cont_payload, sub_tvb, 0, offset_orig + obj_length - offset, ENC_NA);
                 subtree = proto_item_add_subtree(ti, ett_blf_logcontainer_payload);
@@ -575,9 +577,8 @@ dissect_blf_lobj(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, gint o
             offset += 8;
             proto_tree_add_item(subtree, hf_blf_sys_var_name, tvb, offset, namelength, ENC_UTF_8 | ENC_NA);
             offset += namelength;
-            proto_tree_add_item(subtree, hf_blf_sys_var_data, tvb, offset, namelength, ENC_NA);
-            offset += namelength;
-
+            proto_tree_add_item(subtree, hf_blf_sys_var_data, tvb, offset, datalength, ENC_NA);
+            offset += datalength;
         }
         break;
         case BLF_OBJTYPE_ETHERNET_STATUS:
@@ -723,6 +724,7 @@ dissect_blf_lobj(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, gint o
 }
 
 static int
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_blf_next_object(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint offset) {
     gint offset_orig = offset;
 
@@ -730,7 +732,9 @@ dissect_blf_next_object(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gin
         if (tvb_memeql(tvb, offset, blf_lobj_magic, MAGIC_NUMBER_SIZE) != 0) {
             offset += 1;
         } else {
+            increment_dissection_depth(pinfo);
             int bytes_parsed = dissect_blf_lobj(tvb, pinfo, tree, offset);
+            decrement_dissection_depth(pinfo);
             if (bytes_parsed <= 0) {
                 return 0;
             } else {
