@@ -162,64 +162,64 @@ typedef struct
 
 /* Known (common on every product) registers */
 static FCOSRegisterDef registers_def[] = {
-    /*0x00*/ { 4,  REGISTER, "Type/Model", "5co-rap.RegTypeModel", FT_UINT32, BASE_CUSTOM, ENC_LITTLE_ENDIAN, -1, -1, CF_FUNC(disp_type)},
-    /*0x01*/ { 4,  REGISTER, "Version", "5co-rap.RegVersion", FT_UINT32, BASE_CUSTOM, ENC_LITTLE_ENDIAN, -1, -1, CF_FUNC(disp_version)},
-    /*0x02*/ { 0,  FUNCTION, "Reset device", "5co-rap.RegReset", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
-    /*0x03*/ { 0,  FUNCTION, "Save user parameters", "5co-rap.RegSave", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
-    /*0x04*/ { 0,  FUNCTION, "Restore user parameters", "5co-rap.RegRestore", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
-    /*0x05*/ { 0,  FUNCTION, "Restore factory parameters", "5co-rap.RegRestoreFact", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
-    /*0x06*/ { 0,  FUNCTION, "Save factory parameters", "5co-rap.SaveFact", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
-    /*0x07*/ { 4,  REGISTER, "Voltage", "5co-rap.Voltage", FT_UINT32, BASE_CUSTOM, ENC_LITTLE_ENDIAN, -1, -1, CF_FUNC(disp_voltage)},
-    /*0x08*/ { 4,  REGISTER, "Warnings", "5co-rap.Warnings", FT_UINT32, BASE_HEX, ENC_LITTLE_ENDIAN, -1, -1, NULL},
-    /*0x09*/ { 8,  REGISTER, "Time Read", "5co-rap.TimeR", FT_UINT64, BASE_HEX, ENC_NA, -1, -1, NULL},
-    /*0x0A*/ { 8,  REGISTER, "Time Write", "5co-rap.TimeW", FT_UINT64, BASE_HEX, ENC_NA, -1, -1, NULL},
-    /*0x0B*/ { 4,  REGISTER, "Number of power up", "5co-rap.NbPowerUp", FT_UINT32, BASE_DEC, ENC_LITTLE_ENDIAN, -1, -1, NULL},
-    /*0x0C*/ { 4,  REGISTER, "Service time (seconds)", "5co-rap.ServiceTime", FT_UINT32, BASE_DEC, ENC_LITTLE_ENDIAN, -1, -1, NULL},
-    /*0x0D*/ { 0,  REGISTER, "Unknown", "5co-rap.RegUnknown0D", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
-    /*0x0E*/ { 8,  REGISTER, "CPU usage", "5co-rap.CPUUsage", FT_UINT64, BASE_HEX, ENC_NA, -1, -1, NULL},
-    /*0x0F*/ { 0,  REGISTER, "Unknown", "5co-rap.RegUnknown0F", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
-    /*0x10*/ { 4,  REGISTER, "Communication options", "5co-rap.RegComOption", FT_UINT32, BASE_HEX, ENC_LITTLE_ENDIAN, -1, -1, NULL},
-    /*0x11*/ { 6,  REGISTER, "Ethernet MAC Address", "5co-rap.RegMAC", FT_UINT48, BASE_CUSTOM, ENC_NA, -1, -1, CF_FUNC(disp_mac)},
-    /*0x12*/ { 4,  REGISTER, "IP Address / Com ID", "5co-rap.RegIPAdd", FT_UINT32, BASE_CUSTOM, ENC_NA, -1, -1, CF_FUNC(disp_ip)},
-    /*0x13*/ { 4,  REGISTER, "IP Mask", "5co-rap.RegIPMask", FT_UINT32, BASE_CUSTOM, ENC_NA, -1, -1, CF_FUNC(disp_mask)},
-    /*0x14*/ { 1,  REGISTER, "TCP Timeout", "5co-rap.RegTCPTimeout", FT_UINT8, BASE_CUSTOM, ENC_LITTLE_ENDIAN, -1, -1, CF_FUNC(disp_timeout)},
-    /*0x15*/ { 16, REGISTER, "Module name", "5co-rap.RegName", FT_STRING, BASE_NONE, ENC_NA, -1, -1, NULL},
-    /*0x16*/ { 0,  REGISTER, "Unknown", "5co-rap.RegUnknown15", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
-    /*0x17*/ { 0,  REGISTER, "Unknown", "5co-rap.RegUnknown16", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
-    /*0x18*/ {16,  REGISTER, "FW upgrade flash data 0", "5co-rap.FwUpgFlashData0", FT_BYTES, SEP_SPACE, ENC_NA, -1, -1, NULL},
-    /*0x19*/ {16,  REGISTER, "FW upgrade flash data 1", "5co-rap.FwUpgFlashData1", FT_BYTES, SEP_SPACE, ENC_NA, -1, -1, NULL},
-    /*0x1A*/ {16,  REGISTER, "FW upgrade flash data 2", "5co-rap.FwUpgFlashData2", FT_BYTES, SEP_SPACE, ENC_NA, -1, -1, NULL},
-    /*0x1B*/ {16,  REGISTER, "FW upgrade flash data 3", "5co-rap.FwUpgFlashData3", FT_BYTES, SEP_SPACE, ENC_NA, -1, -1, NULL},
-    /*0x1C*/ { 6,  REGISTER, "FW upgrade flash pointer", "5co-rap.FwUpgFlashPointer", FT_BYTES, SEP_SPACE, ENC_NA, -1, -1, NULL},
-    /*0x1D*/ { 0,  FUNCTION, "FW upgrade execute", "5co-rap.FwForceExecute", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL}
+    /*0x00*/ { 4,  REGISTER, "Type/Model", "5co_rap.RegTypeModel", FT_UINT32, BASE_CUSTOM, ENC_LITTLE_ENDIAN, -1, -1, CF_FUNC(disp_type)},
+    /*0x01*/ { 4,  REGISTER, "Version", "5co_rap.RegVersion", FT_UINT32, BASE_CUSTOM, ENC_LITTLE_ENDIAN, -1, -1, CF_FUNC(disp_version)},
+    /*0x02*/ { 0,  FUNCTION, "Reset device", "5co_rap.RegReset", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
+    /*0x03*/ { 0,  FUNCTION, "Save user parameters", "5co_rap.RegSave", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
+    /*0x04*/ { 0,  FUNCTION, "Restore user parameters", "5co_rap.RegRestore", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
+    /*0x05*/ { 0,  FUNCTION, "Restore factory parameters", "5co_rap.RegRestoreFact", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
+    /*0x06*/ { 0,  FUNCTION, "Save factory parameters", "5co_rap.SaveFact", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
+    /*0x07*/ { 4,  REGISTER, "Voltage", "5co_rap.Voltage", FT_UINT32, BASE_CUSTOM, ENC_LITTLE_ENDIAN, -1, -1, CF_FUNC(disp_voltage)},
+    /*0x08*/ { 4,  REGISTER, "Warnings", "5co_rap.Warnings", FT_UINT32, BASE_HEX, ENC_LITTLE_ENDIAN, -1, -1, NULL},
+    /*0x09*/ { 8,  REGISTER, "Time Read", "5co_rap.TimeR", FT_UINT64, BASE_HEX, ENC_NA, -1, -1, NULL},
+    /*0x0A*/ { 8,  REGISTER, "Time Write", "5co_rap.TimeW", FT_UINT64, BASE_HEX, ENC_NA, -1, -1, NULL},
+    /*0x0B*/ { 4,  REGISTER, "Number of power up", "5co_rap.NbPowerUp", FT_UINT32, BASE_DEC, ENC_LITTLE_ENDIAN, -1, -1, NULL},
+    /*0x0C*/ { 4,  REGISTER, "Service time (seconds)", "5co_rap.ServiceTime", FT_UINT32, BASE_DEC, ENC_LITTLE_ENDIAN, -1, -1, NULL},
+    /*0x0D*/ { 0,  REGISTER, "Unknown", "5co_rap.RegUnknown0D", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
+    /*0x0E*/ { 8,  REGISTER, "CPU usage", "5co_rap.CPUUsage", FT_UINT64, BASE_HEX, ENC_NA, -1, -1, NULL},
+    /*0x0F*/ { 0,  REGISTER, "Unknown", "5co_rap.RegUnknown0F", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
+    /*0x10*/ { 4,  REGISTER, "Communication options", "5co_rap.RegComOption", FT_UINT32, BASE_HEX, ENC_LITTLE_ENDIAN, -1, -1, NULL},
+    /*0x11*/ { 6,  REGISTER, "Ethernet MAC Address", "5co_rap.RegMAC", FT_UINT48, BASE_CUSTOM, ENC_NA, -1, -1, CF_FUNC(disp_mac)},
+    /*0x12*/ { 4,  REGISTER, "IP Address / Com ID", "5co_rap.RegIPAdd", FT_UINT32, BASE_CUSTOM, ENC_NA, -1, -1, CF_FUNC(disp_ip)},
+    /*0x13*/ { 4,  REGISTER, "IP Mask", "5co_rap.RegIPMask", FT_UINT32, BASE_CUSTOM, ENC_NA, -1, -1, CF_FUNC(disp_mask)},
+    /*0x14*/ { 1,  REGISTER, "TCP Timeout", "5co_rap.RegTCPTimeout", FT_UINT8, BASE_CUSTOM, ENC_LITTLE_ENDIAN, -1, -1, CF_FUNC(disp_timeout)},
+    /*0x15*/ { 16, REGISTER, "Module name", "5co_rap.RegName", FT_STRING, BASE_NONE, ENC_NA, -1, -1, NULL},
+    /*0x16*/ { 0,  REGISTER, "Unknown", "5co_rap.RegUnknown15", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
+    /*0x17*/ { 0,  REGISTER, "Unknown", "5co_rap.RegUnknown16", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL},
+    /*0x18*/ {16,  REGISTER, "FW upgrade flash data 0", "5co_rap.FwUpgFlashData0", FT_BYTES, SEP_SPACE, ENC_NA, -1, -1, NULL},
+    /*0x19*/ {16,  REGISTER, "FW upgrade flash data 1", "5co_rap.FwUpgFlashData1", FT_BYTES, SEP_SPACE, ENC_NA, -1, -1, NULL},
+    /*0x1A*/ {16,  REGISTER, "FW upgrade flash data 2", "5co_rap.FwUpgFlashData2", FT_BYTES, SEP_SPACE, ENC_NA, -1, -1, NULL},
+    /*0x1B*/ {16,  REGISTER, "FW upgrade flash data 3", "5co_rap.FwUpgFlashData3", FT_BYTES, SEP_SPACE, ENC_NA, -1, -1, NULL},
+    /*0x1C*/ { 6,  REGISTER, "FW upgrade flash pointer", "5co_rap.FwUpgFlashPointer", FT_BYTES, SEP_SPACE, ENC_NA, -1, -1, NULL},
+    /*0x1D*/ { 0,  FUNCTION, "FW upgrade execute", "5co_rap.FwForceExecute", FT_NONE, BASE_NONE, ENC_NA, -1, -1, NULL}
 };
 
     /* List of static header fields */
 static hf_register_info hf_base[] = {
-        {&hf_fiveco_source_addr, {"Source address", "5co-rap.src_addr", FT_UINT8, BASE_DEC_HEX, NULL, 0x0, "FRAP source address", HFILL}},
-        {&hf_fiveco_dest_addr, {"Destination address", "5co-rap.dest_addr", FT_UINT8, BASE_DEC_HEX, NULL, 0x0, "FRAP destination address", HFILL}},
-        {&hf_fiveco_data, {"Data", "5co-rap.data", FT_NONE, BASE_NONE, NULL, 0x0, "Data (parameters)", HFILL}},
-        {&hf_fiveco_regread, {"Read register", "5co-rap.regread", FT_NONE, BASE_NONE, NULL, 0x0, "Read register at index", HFILL}},
-        {&hf_fiveco_regread_answer, {"Read answer register", "5co-rap.regreadans", FT_NONE, BASE_NONE, NULL, 0x0, "Answer to a read register", HFILL}},
-        {&hf_fiveco_regwrite, {"Write register", "5co-rap.regwrite", FT_NONE, BASE_NONE, NULL, 0x0, "Write register at index", HFILL}},
-        {&hf_fiveco_regcall, {"Call function", "5co-rap.regcall", FT_NONE, BASE_NONE, NULL, 0x0, "Call function at index", HFILL}},
-        {&hf_fiveco_routing, {"Routing to subdevice", "5co-rap.routing", FT_NONE, BASE_NONE, NULL, 0x0, "Frame to be routed to a sub device", HFILL}},
-        {&hf_fiveco_routing_answer, {"Answer from subdevice", "5co-rap.routinganswer", FT_NONE, BASE_NONE, NULL, 0x0, "Answer from a subdevice", HFILL}},
-        {&hf_fiveco_routing_interface, {"Interface", "5co-rap.routinginterface", FT_NONE, BASE_NONE, NULL, 0x0, "Device routing interface for sub device", HFILL}},
-        {&hf_fiveco_routing_timeout, {"Timeout", "5co-rap.routingtimeout", FT_UINT8, BASE_HEX, NULL, 0x0, "Answer timeout from the sub device", HFILL}},
-        {&hf_fiveco_routing_size, {"Size of frame to route", "5co-rap.routingsize", FT_NONE, BASE_NONE, NULL, 0x0, "Size of frame to be routed to a sub device", HFILL}},
-        {&hf_fiveco_ext_regerror, {"Register access error", "5co-rap.regerror", FT_NONE, BASE_NONE, NULL, 0x0, "Error while accessing a register", HFILL}},
-        {&hf_fiveco_ext_frameid, {"Frame ID", "5co-rap.frameid", FT_NONE, BASE_NONE, NULL, 0x0, "ID of the frame", HFILL}},
-        {&hf_fiveco_ext_eof, {"End of frame", "5co-rap.eof", FT_NONE, BASE_NONE, NULL, 0x0, "End of the frame", HFILL}},
-        {&hf_fiveco_cks, {"Checksum", "5co-rap.checksum", FT_UINT8, BASE_HEX_DEC, NULL, 0x0, "Checksum of the frame", HFILL}},
-        {&hf_fiveco_ext_frameerror, {"Frame error", "5co-rap.frameerror", FT_NONE, BASE_NONE, NULL, 0x0, "Frame error occurred", HFILL}},
-        {&hf_fiveco_ext_easyip, {"Easy IP configuration", "5co-rap.easyip", FT_NONE, BASE_NONE, NULL, 0x0, "Change IP config easily by broadcast", HFILL}},
-        {&hf_fiveco_ext_easyip_version, {"Extension version", "5co-rap.easyipversion", FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL}},
-        {&hf_fiveco_ext_easyip_interface, {"Destination FRAP interface", "5co-rap.easyipinterface", FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL}},
-        {&hf_fiveco_ext_easyip_mac, {"Destination MAC address", "5co-rap.easyipmac", FT_ETHER, BASE_NONE, NULL, 0x0, NULL, HFILL}},
-        {&hf_fiveco_ext_easyip_ip, {"New IP address", "5co-rap.easyipip", FT_IPv4, BASE_NONE, NULL, 0x0, NULL, HFILL}},
-        {&hf_fiveco_ext_easyip_mask, {"New subnet mask", "5co-rap.easyipmask", FT_IPv4, BASE_NETMASK, NULL, 0x0, NULL, HFILL}},
-        {&hf_fiveco_ext_unsupported, {"Unsupported function", "5co-rap.frameunsupported", FT_NONE, BASE_NONE, NULL, 0x0, "Function ignored by this dissector", HFILL}},
+        {&hf_fiveco_source_addr, {"Source address", "5co_rap.src_addr", FT_UINT8, BASE_DEC_HEX, NULL, 0x0, "FRAP source address", HFILL}},
+        {&hf_fiveco_dest_addr, {"Destination address", "5co_rap.dest_addr", FT_UINT8, BASE_DEC_HEX, NULL, 0x0, "FRAP destination address", HFILL}},
+        {&hf_fiveco_data, {"Data", "5co_rap.data", FT_NONE, BASE_NONE, NULL, 0x0, "Data (parameters)", HFILL}},
+        {&hf_fiveco_regread, {"Read register", "5co_rap.regread", FT_NONE, BASE_NONE, NULL, 0x0, "Read register at index", HFILL}},
+        {&hf_fiveco_regread_answer, {"Read answer register", "5co_rap.regreadans", FT_NONE, BASE_NONE, NULL, 0x0, "Answer to a read register", HFILL}},
+        {&hf_fiveco_regwrite, {"Write register", "5co_rap.regwrite", FT_NONE, BASE_NONE, NULL, 0x0, "Write register at index", HFILL}},
+        {&hf_fiveco_regcall, {"Call function", "5co_rap.regcall", FT_NONE, BASE_NONE, NULL, 0x0, "Call function at index", HFILL}},
+        {&hf_fiveco_routing, {"Routing to subdevice", "5co_rap.routing", FT_NONE, BASE_NONE, NULL, 0x0, "Frame to be routed to a sub device", HFILL}},
+        {&hf_fiveco_routing_answer, {"Answer from subdevice", "5co_rap.routinganswer", FT_NONE, BASE_NONE, NULL, 0x0, "Answer from a subdevice", HFILL}},
+        {&hf_fiveco_routing_interface, {"Interface", "5co_rap.routinginterface", FT_NONE, BASE_NONE, NULL, 0x0, "Device routing interface for sub device", HFILL}},
+        {&hf_fiveco_routing_timeout, {"Timeout", "5co_rap.routingtimeout", FT_UINT8, BASE_HEX, NULL, 0x0, "Answer timeout from the sub device", HFILL}},
+        {&hf_fiveco_routing_size, {"Size of frame to route", "5co_rap.routingsize", FT_NONE, BASE_NONE, NULL, 0x0, "Size of frame to be routed to a sub device", HFILL}},
+        {&hf_fiveco_ext_regerror, {"Register access error", "5co_rap.regerror", FT_NONE, BASE_NONE, NULL, 0x0, "Error while accessing a register", HFILL}},
+        {&hf_fiveco_ext_frameid, {"Frame ID", "5co_rap.frameid", FT_NONE, BASE_NONE, NULL, 0x0, "ID of the frame", HFILL}},
+        {&hf_fiveco_ext_eof, {"End of frame", "5co_rap.eof", FT_NONE, BASE_NONE, NULL, 0x0, "End of the frame", HFILL}},
+        {&hf_fiveco_cks, {"Checksum", "5co_rap.checksum", FT_UINT8, BASE_HEX_DEC, NULL, 0x0, "Checksum of the frame", HFILL}},
+        {&hf_fiveco_ext_frameerror, {"Frame error", "5co_rap.frameerror", FT_NONE, BASE_NONE, NULL, 0x0, "Frame error occurred", HFILL}},
+        {&hf_fiveco_ext_easyip, {"Easy IP configuration", "5co_rap.easyip", FT_NONE, BASE_NONE, NULL, 0x0, "Change IP config easily by broadcast", HFILL}},
+        {&hf_fiveco_ext_easyip_version, {"Extension version", "5co_rap.easyipversion", FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL}},
+        {&hf_fiveco_ext_easyip_interface, {"Destination FRAP interface", "5co_rap.easyipinterface", FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL}},
+        {&hf_fiveco_ext_easyip_mac, {"Destination MAC address", "5co_rap.easyipmac", FT_ETHER, BASE_NONE, NULL, 0x0, NULL, HFILL}},
+        {&hf_fiveco_ext_easyip_ip, {"New IP address", "5co_rap.easyipip", FT_IPv4, BASE_NONE, NULL, 0x0, NULL, HFILL}},
+        {&hf_fiveco_ext_easyip_mask, {"New subnet mask", "5co_rap.easyipmask", FT_IPv4, BASE_NETMASK, NULL, 0x0, NULL, HFILL}},
+        {&hf_fiveco_ext_unsupported, {"Unsupported function", "5co_rap.frameunsupported", FT_NONE, BASE_NONE, NULL, 0x0, "Function ignored by this dissector", HFILL}},
 };
 
 /*****************************************************************************/
@@ -229,6 +229,7 @@ static hf_register_info hf_base[] = {
 /* are used for size and if higher bit is set, the next byte is also used and*/
 /* so on until a byte with higher bit is not set.                            */
 /*****************************************************************************/
+/* XXX - Replace with equivalent tvb_get_varint(..., ENC_VARINT_PROTOBUF)? */
 static int
 get_data_size(tvbuff_t *tvb, guint32 first_index, guint32 *p_header_len) {
 
@@ -622,6 +623,7 @@ dissect_frame(tvbuff_t *tvb, packet_info* pinfo, proto_tree* fiveco_frame_tree,
                         } else {
                             proto_item_append_text(fiveco_routing_item,
                                 " Sub frame cannot be displayed because max number of subdevices that can be dissected is exceeded !");
+                            i += routing_header_len;
                         }
                         i += routing_size;
                         break;
@@ -891,7 +893,7 @@ disp_type( gchar *result, guint32 type)
 {
     guint nValueH = (type>>16) & 0xFFFF;
     guint nValueL = (type & 0xFFFF);
-    snprintf( result, 18, "%u.%u (%.4X.%.4X)", nValueH, nValueL, nValueH, nValueL);
+    snprintf( result, ITEM_LABEL_LENGTH, "%u.%u (%.4X.%.4X)", nValueH, nValueL, nValueH, nValueL);
 }
 
 static void
@@ -901,7 +903,7 @@ disp_version( gchar *result, guint32 version)
     {
         guint nValueH = (version>>16) & 0xFFFF;
         guint nValueL = (version & 0xFFFF);
-        snprintf( result, 11, "FW: %u.%u", nValueH, nValueL);
+        snprintf( result, ITEM_LABEL_LENGTH, "FW: %u.%u", nValueH, nValueL);
     }
     else
     {
@@ -909,7 +911,7 @@ disp_version( gchar *result, guint32 version)
         guint nHWLow = (version>>16) & 0xFF;
         guint nFWHigh = (version>>8) & 0xFF;
         guint nFWLow = version & 0xFF;
-        snprintf( result, 25, "HW: %u.%u / FW: %u.%u", nHWHigh, nHWLow, nFWHigh, nFWLow);
+        snprintf( result, ITEM_LABEL_LENGTH, "HW: %u.%u / FW: %u.%u", nHWHigh, nHWLow, nFWHigh, nFWLow);
     }
 }
 
@@ -917,14 +919,14 @@ static void disp_voltage(gchar *result, guint32 voltage)
 {
     guint nValueH = (voltage>>16) & 0xFFFF;
     guint nValueL = (voltage & 0xFFFF);
-    snprintf( result, 11, "%u.%u V", nValueH, nValueL);
+    snprintf( result, ITEM_LABEL_LENGTH, "%u.%u V", nValueH, nValueL);
 }
 
 static void disp_mac( gchar *result, guint64 mac)
 {
     guint8 *pData = (guint8*)(&mac);
 
-    snprintf( result, 18, "%.2X-%.2X-%.2X-%.2X-%.2X-%.2X", pData[5], pData[4], pData[3], pData[2],
+    snprintf( result, ITEM_LABEL_LENGTH, "%.2X-%.2X-%.2X-%.2X-%.2X-%.2X", pData[5], pData[4], pData[3], pData[2],
                            pData[1], pData[0]);
 }
 
@@ -932,23 +934,23 @@ static void disp_ip( gchar *result, guint32 ip)
 {
     guint8 *pData = (guint8*)(&ip);
 
-    snprintf( result, 15, "%u.%u.%u.%u", pData[3], pData[2], pData[1], pData[0]);
+    snprintf( result, ITEM_LABEL_LENGTH, "%u.%u.%u.%u", pData[3], pData[2], pData[1], pData[0]);
 }
 
 static void disp_mask( gchar *result, guint32 mask)
 {
     guint8 *pData = (guint8*)(&mask);
 
-    snprintf( result, 15, "%u.%u.%u.%u", pData[3], pData[2], pData[1], pData[0]);
+    snprintf( result, ITEM_LABEL_LENGTH, "%u.%u.%u.%u", pData[3], pData[2], pData[1], pData[0]);
 }
 
 static void disp_timeout( gchar *result, guint32 timeout)
 {
     if (timeout != 0)
-        snprintf( result, 12, "%u%s",
+        snprintf( result, ITEM_LABEL_LENGTH, "%u%s",
                   timeout, unit_name_string_get_value(timeout, &units_second_seconds));
     else
-        snprintf( result, 8, "Disabled");
+        snprintf( result, ITEM_LABEL_LENGTH, "Disabled");
 }
 
 /*
