@@ -171,17 +171,17 @@ dissect_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset)
 
             pitem = proto_tree_add_item(tree, hf_btbnep_destination_service_uuid, tvb, offset, uuid_size, ENC_NA);
             uuid_dst = tvb_get_ntohs(tvb, offset);
-            proto_item_append_text(pitem, " (%s)", val_to_str_ext(uuid_dst, &bluetooth_uuid_vals_ext,  "Unknown uuid"));
+            proto_item_append_text(pitem, " (%s)", val_to_str_ext_const(uuid_dst, &bluetooth_uuid_vals_ext,  "Unknown uuid"));
             offset += uuid_size;
 
             pitem = proto_tree_add_item(tree, hf_btbnep_source_service_uuid, tvb, offset, uuid_size, ENC_NA);
             uuid_src = tvb_get_ntohs(tvb, offset);
-            proto_item_append_text(pitem, " (%s)", val_to_str_ext(uuid_src, &bluetooth_uuid_vals_ext,  "Unknown uuid"));
+            proto_item_append_text(pitem, " (%s)", val_to_str_ext_const(uuid_src, &bluetooth_uuid_vals_ext,  "Unknown uuid"));
             offset += uuid_size;
 
             col_append_fstr(pinfo->cinfo, COL_INFO, " - dst: <%s>, src: <%s>",
-                    val_to_str_ext(uuid_dst, &bluetooth_uuid_vals_ext,  "Unknown uuid"),
-                    val_to_str_ext(uuid_src, &bluetooth_uuid_vals_ext,  "Unknown uuid"));
+                    val_to_str_ext_const(uuid_dst, &bluetooth_uuid_vals_ext,  "Unknown uuid"),
+                    val_to_str_ext_const(uuid_src, &bluetooth_uuid_vals_ext,  "Unknown uuid"));
             break;
         case 0x02: /* Setup Connection Response */
             proto_tree_add_item(tree, hf_btbnep_setup_connection_response_message, tvb, offset, 2, ENC_BIG_ENDIAN);
@@ -216,11 +216,11 @@ dissect_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset)
             offset += 2;
 
             for (i_item = 0; i_item + 12 > i_item && i_item < list_length; i_item += 12) {
-                proto_tree_add_item(tree, hf_btbnep_multicast_address_start, tvb, offset, 6, ENC_NA);
-                offset += 6;
+                proto_tree_add_item(tree, hf_btbnep_multicast_address_start, tvb, offset, FT_ETHER_LEN, ENC_NA);
+                offset += FT_ETHER_LEN;
 
-                proto_tree_add_item(tree, hf_btbnep_multicast_address_end, tvb, offset, 6, ENC_NA);
-                offset += 6;
+                proto_tree_add_item(tree, hf_btbnep_multicast_address_end, tvb, offset, FT_ETHER_LEN, ENC_NA);
+                offset += FT_ETHER_LEN;
             }
             break;
         case 0x06: /* Filter Multi Addr Response */
@@ -237,6 +237,7 @@ dissect_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset)
 }
 
 static int
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_extension(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset)
 {
     guint8  extension_flag;
@@ -262,7 +263,9 @@ dissect_extension(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offse
         offset += extension_length;
     }
 
+    increment_dissection_depth(pinfo);
     if (extension_flag) offset = dissect_extension(tvb, pinfo, tree, offset);
+    decrement_dissection_depth(pinfo);
 
     return offset;
 }
@@ -312,28 +315,28 @@ dissect_btbnep(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _
         set_address_tvb(&pinfo->dl_dst, AT_ETHER, 6, tvb, offset);
         copy_address_shallow(&pinfo->dst, &pinfo->dl_dst);
 
-        addr_item = proto_tree_add_item(btbnep_tree, hf_btbnep_dst, tvb, offset, 6, ENC_NA);
+        addr_item = proto_tree_add_item(btbnep_tree, hf_btbnep_dst, tvb, offset, FT_ETHER_LEN, ENC_NA);
         addr_tree = proto_item_add_subtree(addr_item, ett_addr);
-        proto_tree_add_item(addr_tree, hf_btbnep_addr, tvb, offset, 6, ENC_NA);
+        proto_tree_add_item(addr_tree, hf_btbnep_addr, tvb, offset, FT_ETHER_LEN, ENC_NA);
         proto_tree_add_item(addr_tree, hf_btbnep_lg, tvb, offset, 3, ENC_BIG_ENDIAN);
         proto_tree_add_item(addr_tree, hf_btbnep_ig, tvb, offset, 3, ENC_BIG_ENDIAN);
-        offset += 6;
+        offset += FT_ETHER_LEN;
     }
 
     if (bnep_type == BNEP_TYPE_GENERAL_ETHERNET || bnep_type == BNEP_TYPE_COMPRESSED_ETHERNET_SOURCE_ONLY) {
         set_address_tvb(&pinfo->dl_src, AT_ETHER, 6, tvb, offset);
         copy_address_shallow(&pinfo->src, &pinfo->dl_src);
 
-        addr_item = proto_tree_add_item(btbnep_tree, hf_btbnep_src, tvb, offset, 6, ENC_NA);
+        addr_item = proto_tree_add_item(btbnep_tree, hf_btbnep_src, tvb, offset, FT_ETHER_LEN, ENC_NA);
         addr_tree = proto_item_add_subtree(addr_item, ett_addr);
         if (tvb_get_guint8(tvb, offset) & 0x01) {
             expert_add_info(pinfo, addr_item, &ei_btbnep_src_not_group_address);
         }
 
-        proto_tree_add_item(addr_tree, hf_btbnep_addr, tvb, offset, 6, ENC_NA);
+        proto_tree_add_item(addr_tree, hf_btbnep_addr, tvb, offset, FT_ETHER_LEN, ENC_NA);
         proto_tree_add_item(addr_tree, hf_btbnep_lg, tvb, offset, 3, ENC_BIG_ENDIAN);
         proto_tree_add_item(addr_tree, hf_btbnep_ig, tvb, offset, 3, ENC_BIG_ENDIAN);
-        offset += 6;
+        offset += FT_ETHER_LEN;
     }
 
     if (bnep_type != BNEP_TYPE_CONTROL) {
@@ -443,10 +446,12 @@ dissect_btbnep(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _
                  */
                 ethertype_data_t ethertype_data;
 
+                proto_tree_add_uint(btbnep_tree, hf_btbnep_type, tvb,
+                                    offset - 2, 2, len_type);
+
                 ethertype_data.etype = len_type;
-                ethertype_data.offset_after_ethertype = offset;
+                ethertype_data.payload_offset = offset;
                 ethertype_data.fh_tree = btbnep_tree;
-                ethertype_data.etype_id = hf_btbnep_type;
                 ethertype_data.trailer_id = 0;
                 ethertype_data.fcs_len = 0;
 
@@ -496,7 +501,7 @@ proto_register_btbnep(void)
             NULL, HFILL }
         },
         { &hf_btbnep_unknown_control_type,
-            { "Unknown Control Type",              "btbnep.uknown_control_type",
+            { "Unknown Control Type",              "btbnep.unknown_control_type",
             FT_UINT8, BASE_HEX, VALS(control_type_vals), 0x00,
             NULL, HFILL }
         },
@@ -643,7 +648,7 @@ proto_reg_handoff_btbnep(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
