@@ -42,9 +42,9 @@ void proto_reg_handoff_dlt(void);
 void proto_register_dlt_storage_header(void);
 void proto_reg_handoff_dlt_storage_header(void);
 
-#define DLT_NAME                                        "DLT"
-#define DLT_NAME_LONG                                   "Diagnostic Log and Trace (DLT)"
-#define DLT_NAME_FILTER                                 "dlt"
+#define PNAME                                           "DLT"
+#define PSNAME                                          "Diagnostic Log and Trace (DLT)"
+#define PFNAME                                          "dlt"
 
 #define DLT_STORAGE_HEADER_NAME                         "DLT Storage Header (short)"
 #define DLT_STORAGE_HEADER_NAME_LONG                    "Shortened Diagnostic Log and Trace (DLT) Storage Header"
@@ -730,7 +730,7 @@ dissect_dlt_verbose_parameter_string(tvbuff_t *tvb, packet_info *pinfo, proto_tr
         return -1;
     }
 
-    subtvb = tvb_new_subset_length_caplen(tvb, offset, str_len, str_len);
+    subtvb = tvb_new_subset_length(tvb, offset, str_len);
 
     if (encoding == DLT_MSG_VERB_PARAM_SCOD_ASCII) {
         buf = tvb_get_stringz_enc(pinfo->pool, subtvb, 0, &tmp_length, ENC_ASCII);
@@ -1038,10 +1038,10 @@ dissect_dlt_non_verbose_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *r
             proto_item_append_text(ti, " (%s)", message_id_name);
         }
 
-        subtvb = tvb_new_subset_length_caplen(tvb, offset, tvb_captured_length_remaining(tvb, offset), tvb_captured_length_remaining(tvb, offset));
+        subtvb = tvb_new_subset_remaining(tvb, offset);
         dissect_dlt_non_verbose_payload_message(subtvb, pinfo, tree, 0, payload_le, msg_type, msg_type_info_comb, message_id);
     } else if(msg_type == DLT_MSG_TYPE_LOG_MSG) {
-        subtvb = tvb_new_subset_length_caplen(tvb, offset, tvb_captured_length_remaining(tvb, offset), tvb_captured_length_remaining(tvb, offset));
+        subtvb = tvb_new_subset_remaining(tvb, offset);
         if (dissect_dlt_non_verbose_payload_message_handoff(subtvb, pinfo, root_tree, payload_le, msg_type, msg_type_info_comb, message_id, ecu_id) <= 0) {
             proto_tree_add_item(tree, hf_dlt_payload_data, tvb, offset, tvb_captured_length_remaining(tvb, offset), payload_le);
         }
@@ -1078,9 +1078,9 @@ dissect_dlt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_,
 
     const guint8   *ecu_id = NULL;
 
-    col_set_str(pinfo->cinfo, COL_PROTOCOL, DLT_NAME);
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, PNAME);
     col_clear(pinfo->cinfo, COL_INFO);
-    col_append_sep_fstr(pinfo->cinfo, COL_INFO, ", ", "%s", DLT_NAME);
+    col_append_sep_fstr(pinfo->cinfo, COL_INFO, ", ", "%s", PNAME);
 
     if (captured_length < DLT_MIN_SIZE_FOR_PARSING) {
         expert_dlt_buffer_too_short(tree, pinfo, tvb, offset, captured_length);
@@ -1424,10 +1424,9 @@ void proto_register_dlt(void) {
     };
 
     /* Register the protocol name and description */
-    proto_dlt = proto_register_protocol(DLT_NAME_LONG, DLT_NAME, DLT_NAME_FILTER);
+    proto_dlt = proto_register_protocol(PSNAME, PNAME, PFNAME);
     dlt_handle_tcp = register_dissector("dlt_tcp", dissect_dlt_tcp, proto_dlt);
     dlt_handle_udp = register_dissector("dlt_udp", dissect_dlt_udp, proto_dlt);
-    dlt_handle_storage = register_dissector("dlt_storage", dissect_dlt_storage_header, proto_dlt_storage_header);
     proto_register_subtree_array(ett, array_length(ett));
     proto_register_field_array(proto_dlt, hf_dlt, array_length(hf_dlt));
 
@@ -1468,6 +1467,7 @@ void proto_register_dlt_storage_header(void) {
     proto_dlt_storage_header = proto_register_protocol(DLT_STORAGE_HEADER_NAME_LONG, DLT_STORAGE_HEADER_NAME, DLT_STORAGE_HEADER_NAME_FILTER);
     proto_register_subtree_array(ett, array_length(ett));
     proto_register_field_array(proto_dlt, hfs, array_length(hfs));
+    dlt_handle_storage = register_dissector("dlt_storage", dissect_dlt_storage_header, proto_dlt_storage_header);
 }
 
 void proto_reg_handoff_dlt_storage_header(void) {
