@@ -19,6 +19,8 @@
 void proto_register_eiss(void);
 void proto_reg_handoff_eiss(void);
 
+static dissector_handle_t eiss_handle;
+
 static int proto_eiss = -1;
 
 static int hf_eiss_reserved2 = -1;
@@ -93,9 +95,10 @@ static const value_string eiss_descriptor_values[] = {
 	{    0, NULL }
 };
 
+/* ETSI TS 101 812 - DVB-MHP Specification section 10.5 */
 static const range_string application_id_values[] = {
 	{ 0x0000, 0x3fff, "Unsigned Application" },
-	{ 0x4000, 0x3fff, "Signed Application" },
+	{ 0x4000, 0x7fff, "Signed Application" },
 	{ 0x8000, 0xfffd, "Reserved by DVB" },
 	{ 0xfffe, 0xfffe, "Wildcard for signed applications of an organisation" },
 	{ 0xffff, 0xffff, "Wildcard for all applications of an organisation" },
@@ -556,20 +559,19 @@ proto_register_eiss(void)
 	proto_register_subtree_array(ett, array_length(ett));
 	expert_eiss = expert_register_protocol(proto_eiss);
 	expert_register_field_array(expert_eiss, ei, array_length(ei));
+
+	eiss_handle = register_dissector("eiss", dissect_eiss, proto_eiss);
 }
 
 
 void
 proto_reg_handoff_eiss(void)
 {
-	dissector_handle_t eiss_handle;
-
-	eiss_handle = create_dissector_handle(dissect_eiss, proto_eiss);
 	dissector_add_uint("mpeg_sect.tid", EISS_SECTION_TID, eiss_handle);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
