@@ -19,6 +19,8 @@
 void proto_register_fcsbccs(void);
 void proto_reg_handoff_fcsbccs(void);
 
+static dissector_handle_t fc_sbccs_handle;
+
 /* Initialize the protocol and registered fields */
 static int proto_fc_sbccs = -1;
 static int hf_sbccs_chid = -1;
@@ -234,7 +236,7 @@ static const value_string fc_sbccs_dib_lrj_errcode_val[] = {
 static void
 dissect_iui_flags (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint16 flags)
 {
-    static const int * iui_flags[] = {
+    static int * const iui_flags[] = {
         &hf_sbccs_iui_as,
         &hf_sbccs_iui_es,
         &hf_sbccs_iui_val,
@@ -248,7 +250,7 @@ dissect_iui_flags (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint16 f
 static void
 dissect_linkctlinfo (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint16 flags)
 {
-    static const int * linkctlinfo_flags[] = {
+    static int * const linkctlinfo_flags[] = {
         &hf_sbccs_dib_linkctlinfo_ctcconn,
         &hf_sbccs_dib_linkctlinfo_ecrcg,
         NULL
@@ -262,7 +264,7 @@ dissect_linkctlinfo (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint16
 static void
 dissect_dh_flags (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint16 flags)
 {
-    static const int * dh_flags[] = {
+    static int * const dh_flags[] = {
         &hf_sbccs_dhflags_end,
         &hf_sbccs_dhflags_chaining,
         &hf_sbccs_dhflags_earlyend,
@@ -278,7 +280,7 @@ dissect_dh_flags (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint16 fl
 static void
 dissect_ccw_flags (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint8 flags)
 {
-    static const int * ccw_flags[] = {
+    static int * const ccw_flags[] = {
         &hf_sbccs_dib_ccw_flags_cd,
         &hf_sbccs_dib_ccw_flags_cc,
         &hf_sbccs_dib_ccw_flags_sli,
@@ -294,7 +296,7 @@ dissect_ccw_flags (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint8 fl
 static void
 dissect_cmd_flags (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint8 flags)
 {
-    static const int * cmd_flags[] = {
+    static int * const cmd_flags[] = {
         &hf_sbccs_dib_cmdflags_du,
         &hf_sbccs_dib_cmdflags_coc,
         &hf_sbccs_dib_cmdflags_syr,
@@ -318,7 +320,7 @@ static const value_string status_ffc_val[] = {
 static void
 dissect_status_flags (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint8 flags)
 {
-    static const int * status_flags[] = {
+    static int * const status_flags[] = {
         &hf_sbccs_dib_statusflags_ffc,
         &hf_sbccs_dib_statusflags_ci,
         &hf_sbccs_dib_statusflags_cr,
@@ -335,7 +337,7 @@ dissect_status_flags (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint8
 static void
 dissect_status (packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint8 flags)
 {
-    static const int * status_flags[] = {
+    static int * const status_flags[] = {
         &hf_sbccs_dib_status_attention,
         &hf_sbccs_dib_status_modifier,
         &hf_sbccs_dib_status_cue,
@@ -385,7 +387,7 @@ dissect_status (packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int
 static void
 dissect_sel_rst_param (proto_tree *parent_tree, tvbuff_t *tvb, int offset, guint32 flags)
 {
-    static const int * rst_param_flags[] = {
+    static int * const rst_param_flags[] = {
         &hf_sbccs_dib_ctlparam_rc,
         &hf_sbccs_dib_ctlparam_ru,
         &hf_sbccs_dib_ctlparam_ro,
@@ -640,7 +642,7 @@ static void dissect_fc_sbccs_dib_link_hdr (tvbuff_t *tvb, packet_info *pinfo,
                 proto_tree_add_bytes_format(tree, hf_sbccs_logical_path, tvb, offset, 4,
                                      NULL, "Logical Paths %d-%d: %s",
                                      i*8, ((i+4)*8) - 1,
-                                     tvb_bytes_to_str_punct(wmem_packet_scope(), tvb, offset, 4, ':'));
+                                     tvb_bytes_to_str_punct(pinfo->pool, tvb, offset, 4, ':'));
                 i += 4;
                 offset += 4;
             }
@@ -675,7 +677,7 @@ static int dissect_fc_sbccs (tvbuff_t *tvb, packet_info *pinfo,
 
     /* Retrieve conversation state to determine expected payload */
     conversation = find_conversation (pinfo->num, &pinfo->src, &pinfo->dst,
-                                      ENDPOINT_SBCCS, ch_cu_id, dev_addr, 0);
+                                      CONVERSATION_SBCCS, ch_cu_id, dev_addr, 0);
 
     if (conversation) {
 #if 0
@@ -689,7 +691,7 @@ static int dissect_fc_sbccs (tvbuff_t *tvb, packet_info *pinfo,
         conversation =
 #endif
                        conversation_new (pinfo->num, &pinfo->src, &pinfo->dst,
-                                         ENDPOINT_SBCCS, ch_cu_id, dev_addr, 0);
+                                         CONVERSATION_SBCCS, ch_cu_id, dev_addr, 0);
 #if 0
         task_key.conv_id = conversation->index;
         task_key.task_id = ccw;
@@ -820,7 +822,7 @@ proto_register_fcsbccs (void)
 
         { &hf_sbccs_dib_residualcnt,
           { "Residual Count", "fcsb3.residualcnt",
-            FT_UINT8, BASE_DEC, NULL, 0x0,
+            FT_UINT16, BASE_DEC, NULL, 0x0,
             NULL, HFILL}},
 
         { &hf_sbccs_dib_iupacing,
@@ -835,7 +837,7 @@ proto_register_fcsbccs (void)
 
         { &hf_sbccs_dib_qtu,
           { "Queue-Time Unit", "fcsb3.qtu",
-            FT_UINT16, BASE_DEC, NULL, 0xFFF,
+            FT_UINT16, BASE_DEC, NULL, 0x0FFF,
             NULL, HFILL}},
 
         { &hf_sbccs_dib_dtuf,
@@ -845,7 +847,7 @@ proto_register_fcsbccs (void)
 
         { &hf_sbccs_dib_dtu,
           { "Defer-Time Unit", "fcsb3.dtu",
-            FT_UINT16, BASE_DEC, NULL, 0xFFF,
+            FT_UINT16, BASE_DEC, NULL, 0x0FFF,
             NULL, HFILL}},
 
         { &hf_sbccs_dib_ctlfn,
@@ -894,7 +896,7 @@ proto_register_fcsbccs (void)
             NULL, HFILL}},
 
         { &hf_sbccs_dib_lrjcode,
-          { "LRJ Reaspn Code", "fcsb3.lrjcode",
+          { "LRJ Reason Code", "fcsb3.lrjcode",
             FT_UINT8, BASE_HEX, VALS (fc_sbccs_dib_lrj_errcode_val), 0x7F,
             NULL, HFILL}},
 
@@ -1065,17 +1067,17 @@ proto_register_fcsbccs (void)
 
         { &hf_sbccs_dib_ctlparam_rc,
           { "RC", "fcsb3.ctlparam.rc",
-            FT_BOOLEAN, 24, TFS(&tfs_set_notset), 0x80,
+            FT_BOOLEAN, 24, TFS(&tfs_set_notset), 0x000080,
             NULL, HFILL}},
 
         { &hf_sbccs_dib_ctlparam_ru,
           { "RU", "fcsb3.ctlparam.ru",
-            FT_BOOLEAN, 24, TFS(&tfs_set_notset), 0x10,
+            FT_BOOLEAN, 24, TFS(&tfs_set_notset), 0x000010,
             NULL, HFILL}},
 
         { &hf_sbccs_dib_ctlparam_ro,
           { "RO", "fcsb3.ctlparam.ro",
-            FT_BOOLEAN, 24, TFS(&tfs_set_notset), 0x08,
+            FT_BOOLEAN, 24, TFS(&tfs_set_notset), 0x000008,
             NULL, HFILL}},
 
         { &hf_sbccs_dib_linkctlinfo,
@@ -1085,12 +1087,12 @@ proto_register_fcsbccs (void)
 
         { &hf_sbccs_dib_linkctlinfo_ctcconn,
           { "CTC Conn", "fcsb3.linkctlinfo.ctc_conn",
-            FT_BOOLEAN, 16, TFS(&tfs_supported_not_supported), 0x80,
+            FT_BOOLEAN, 16, TFS(&tfs_supported_not_supported), 0x0080,
             NULL, HFILL}},
 
         { &hf_sbccs_dib_linkctlinfo_ecrcg,
           { "Enhanced CRC Generation", "fcsb3.linkctlinfo.ecrcg",
-            FT_BOOLEAN, 16, TFS(&tfs_supported_not_supported), 0x01,
+            FT_BOOLEAN, 16, TFS(&tfs_supported_not_supported), 0x0001,
             NULL, HFILL}},
 
         { &hf_sbccs_logical_path,
@@ -1119,21 +1121,18 @@ proto_register_fcsbccs (void)
 
     proto_register_field_array(proto_fc_sbccs, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+
+    fc_sbccs_handle = register_dissector("fcsb3", dissect_fc_sbccs, proto_fc_sbccs);
 }
 
 void
 proto_reg_handoff_fcsbccs (void)
 {
-    dissector_handle_t fc_sbccs_handle;
-
-    fc_sbccs_handle = create_dissector_handle (dissect_fc_sbccs,
-                                               proto_fc_sbccs);
-
     dissector_add_uint("fc.ftype", FC_FTYPE_SBCCS, fc_sbccs_handle);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
