@@ -497,7 +497,6 @@ enum abis_nm_pcause_type {
 	NM_PCAUSE_T_MANUF	= 0x03
 };
 
-#if 0
 /* Section 9.4.36: NACK Causes */
 enum abis_nm_nack_cause {
 	/* General Nack Causes */
@@ -535,7 +534,6 @@ enum abis_nm_nack_cause {
 	NM_NACK_MEAS_NOTSUPP		= 0x2b,
 	NM_NACK_MEAS_NOTSTART		= 0x2c
 };
-#endif
 
 /* Section 9.4.1 */
 struct abis_nm_channel {
@@ -665,6 +663,7 @@ static int hf_attr_oper_state = -1;
 static int hf_attr_avail_state = -1;
 static int hf_attr_event_type = -1;
 static int hf_attr_severity = -1;
+static int hf_attr_nack_causes = -1;
 static int hf_attr_bcch_arfcn = -1;
 static int hf_attr_bsic = -1;
 static int hf_attr_test_no = -1;
@@ -1204,10 +1203,10 @@ static void format_custom_msgtype(gchar *out, guint32 in)
 	}
 
 	if (tmp)
-		g_snprintf(out, ITEM_LABEL_LENGTH, "%s", tmp);
+		snprintf(out, ITEM_LABEL_LENGTH, "%s", tmp);
 	else {
 		tmp_str = val_to_str_wmem(NULL, in, oml_fom_msgtype_vals, "Unknown 0x%02x");
-		g_snprintf(out, ITEM_LABEL_LENGTH, "%s", tmp_str);
+		snprintf(out, ITEM_LABEL_LENGTH, "%s", tmp_str);
 		wmem_free(NULL, tmp_str);
 	}
 }
@@ -1231,10 +1230,10 @@ static void format_custom_attr(gchar *out, guint32 in)
 	}
 
 	if (tmp)
-		g_snprintf(out, ITEM_LABEL_LENGTH, "%s", tmp);
+		snprintf(out, ITEM_LABEL_LENGTH, "%s", tmp);
 	else {
 		tmp_str = val_to_str_wmem(NULL, in, oml_fom_attr_vals, "Unknown 0x%02x");
-		g_snprintf(out, ITEM_LABEL_LENGTH, "%s", tmp_str);
+		snprintf(out, ITEM_LABEL_LENGTH, "%s", tmp_str);
 		wmem_free(NULL, tmp_str);
 	}
 }
@@ -1242,7 +1241,7 @@ static void format_custom_attr(gchar *out, guint32 in)
 /* Interference level boundaries are coded as a binary presentation of -x dBm */
 static void format_interf_bound(gchar *buf, const guint32 in)
 {
-	g_snprintf(buf, ITEM_LABEL_LENGTH, "-%u%s", in,
+	snprintf(buf, ITEM_LABEL_LENGTH, "-%u%s", in,
 		   unit_name_string_get_value(in, &units_dbm));
 }
 
@@ -1310,9 +1309,8 @@ static const value_string oml_severity_vals[] = {
 	{ 0, NULL }
 };
 
-#if 0
 /* Section 9.4.36: NACK Causes */
-static const value_string oml_nack_cause[] = {
+static const value_string oml_nack_causes[] = {
 	{ NM_NACK_INCORR_STRUCT,	"Incorrect message structure" },
 	{ NM_NACK_MSGTYPE_INVAL,	"Invalid message type value" },
 	{ NM_NACK_OBJCLASS_INVAL,	"Invalid Object class value" },
@@ -1348,7 +1346,6 @@ static const value_string oml_nack_cause[] = {
 	{ 0xff,				"NULL" },
 	{ 0, NULL }
 };
-#endif
 
 static const value_string oml_test_no_vals[] = {
 	{ NM_IPACC_TESTNO_RLOOP_ANT,	"Radio Loop test via antenna" },
@@ -1726,6 +1723,10 @@ dissect_oml_attrs(tvbuff_t *tvb, int base_offs, int length,
 			proto_tree_add_item(att_tree, hf_attr_severity, tvb,
 					    offset, len, ENC_LITTLE_ENDIAN);
 			break;
+		case NM_ATT_NACK_CAUSES:
+			proto_tree_add_item(att_tree, hf_attr_nack_causes, tvb,
+					    offset, len, ENC_LITTLE_ENDIAN);
+			break;
 		case NM_ATT_TEST_REPORT:
 			dissect_ipacc_test_rep(att_tree, pinfo, sub_tvb);
 			break;
@@ -1806,15 +1807,15 @@ dissect_oml_attrs(tvbuff_t *tvb, int base_offs, int length,
 			break;
 		case NM_ATT_IPACC_LOCATION:
 			proto_tree_add_item(att_tree, hf_attr_ipa_location_name,
-					    tvb, offset, len, ENC_ASCII|ENC_NA);
+					    tvb, offset, len, ENC_ASCII);
 			break;
 		case NM_ATT_IPACC_UNIT_ID:
 			proto_tree_add_item(att_tree, hf_attr_ipa_unit_id,
-					    tvb, offset, len, ENC_ASCII|ENC_NA);
+					    tvb, offset, len, ENC_ASCII);
 			break;
 		case NM_ATT_IPACC_UNIT_NAME:
 			proto_tree_add_item(att_tree, hf_attr_ipa_unit_name,
-					    tvb, offset, len, ENC_ASCII|ENC_NA);
+					    tvb, offset, len, ENC_ASCII);
 			break;
 		case NM_ATT_IPACC_PRIM_OML_CFG_LIST:
 			proto_tree_add_item(att_tree, hf_attr_ipa_prim_oml_ip,
@@ -1982,7 +1983,7 @@ dissect_oml_manuf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	proto_tree_add_item_ret_uint(tree, hf_oml_manuf_id_len, tvb,
 				     offset, 1, ENC_NA, &len);
 	proto_tree_add_item(tree, hf_oml_manuf_id_val, tvb,
-			    offset + 1, len, ENC_ASCII|ENC_NA);
+			    offset + 1, len, ENC_ASCII);
 
 	/* Some implementations include '\0', some don't - handle this */
 	if ((len == (sizeof(ipaccess_magic) + 1) || len == sizeof(ipaccess_magic)) &&
@@ -2173,6 +2174,11 @@ proto_register_abis_oml(void)
 			  FT_UINT8, BASE_HEX, VALS(oml_severity_vals), 0,
 			  NULL, HFILL }
 		},
+		{ &hf_attr_nack_causes,
+			{ "NACK Causes", "gsm_abis_oml.fom.attr.nack_causes",
+			  FT_UINT8, BASE_HEX, VALS(oml_nack_causes), 0,
+			  NULL, HFILL }
+		},
 		{ &hf_attr_bcch_arfcn,
 			{ "BCCH ARFCN", "gsm_abis_oml.fom.attr.bcch_arfcn",
 			  FT_UINT16, BASE_DEC, NULL, 0,
@@ -2317,7 +2323,7 @@ proto_register_abis_oml(void)
 		},
 		{ &hf_attr_ipa_tr_f_qual,
 			{ "Frequency Quality", "gsm_abis_oml.fom.testrep.ipa.freq_qual",
-			  FT_UINT8, BASE_DEC, NULL, 0xfc, NULL, HFILL }
+			  FT_UINT16, BASE_DEC, NULL, 0x00fc, NULL, HFILL }
 		},
 		{ &hf_attr_ipa_tr_f_err,
 			{ "Frequency Error", "gsm_abis_oml.fom.testrep.ipa.freq_err",
