@@ -33,7 +33,7 @@
 /* debug the mux-pdu defragmentation code. warning: verbose output! */
 /* #define DEBUG_H223_FRAGMENTATION */
 
-#define PROTO_TAG_H223 "H223"
+#define PROTO_TAG_H223 "H.223"
 
 /* Wireshark ID of the H.223 protocol */
 static int proto_h223 = -1;
@@ -800,17 +800,20 @@ dissect_mux_sdu_fragment(tvbuff_t *volatile next_tvb, packet_info *pinfo,
 }
 
 static guint32
-mux_element_sublist_size( h223_mux_element* me )
+// NOLINTNEXTLINE(misc-no-recursion)
+mux_element_sublist_size(packet_info *pinfo, h223_mux_element* me)
 {
     h223_mux_element *current_me = me->next;
     guint32 length = 0;
+    increment_dissection_depth(pinfo);
     while ( current_me ) {
         if ( current_me->sublist )
-            length += current_me->repeat_count * mux_element_sublist_size( current_me->sublist );
+            length += current_me->repeat_count * mux_element_sublist_size(pinfo, current_me->sublist);
         else
             length += current_me->repeat_count;
         current_me = current_me->next;
     }
+    decrement_dissection_depth(pinfo);
 
     /* should never happen, but to avoid infinite loops... */
     DISSECTOR_ASSERT(length != 0);
@@ -832,6 +835,7 @@ mux_element_sublist_size( h223_mux_element* me )
  * endOfMuxSdu  true if the end-of-sdu flag was set
  */
 static guint32
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_mux_payload_by_me_list( tvbuff_t *tvb, packet_info *pinfo,
                                 guint32 pkt_offset, proto_tree *pdu_tree,
                                 h223_call_info* call_info,
@@ -843,10 +847,11 @@ dissect_mux_payload_by_me_list( tvbuff_t *tvb, packet_info *pinfo,
     guint32 frag_len;
     guint32 sublist_len;
     int i;
+    increment_dissection_depth(pinfo);
     while ( me ) {
         if ( me->sublist ) {
             if ( me->repeat_count == 0 ) {
-                for(sublist_len = mux_element_sublist_size( me->sublist );
+                for(sublist_len = mux_element_sublist_size(pinfo, me->sublist);
                     offset + sublist_len <= len;
                     offset = dissect_mux_payload_by_me_list( tvb, pinfo, pkt_offset, pdu_tree,
                                                              call_info, me->sublist, offset, endOfMuxSdu,
@@ -873,6 +878,7 @@ dissect_mux_payload_by_me_list( tvbuff_t *tvb, packet_info *pinfo,
         }
         me = me->next;
     }
+    decrement_dissection_depth(pinfo);
     return offset;
 }
 
@@ -1016,6 +1022,7 @@ dissect_mux_pdu( tvbuff_t *tvb, packet_info *pinfo, guint32 pkt_offset,
                                                0, 3, raw_hdr,
                                                "0x%06x (uncorrectable errors)", raw_hdr );
                 } else {
+                    /* B.3.2.1 Header field */
                     if( errors == 0 ) {
                         proto_tree_add_uint_format_value(hdr_tree, hf_h223_mux_rawhdr, tvb,
                                                    0, 3, raw_hdr,
@@ -1434,11 +1441,11 @@ void proto_register_h223 (void)
             "Corrected header bytes", HFILL }},
 
         { &hf_h223_mux_mc,
-          { "Multiplex Code", "h223.mux.mc", FT_UINT8, BASE_DEC, NULL, 0x0,
+          { "Multiplex Code", "h223.mux.mc", FT_UINT8, BASE_DEC, NULL, 0x0f,
             "H.223 MUX multiplex code", HFILL }},
 
         { &hf_h223_mux_mpl,
-          { "Multiplex Payload Length", "h223.mux.mpl", FT_UINT8, BASE_DEC, NULL, 0x0,
+          { "Multiplex Payload Length", "h223.mux.mpl", FT_UINT16, BASE_DEC, NULL, 0xf00f,
             "H.223 MUX multiplex Payload Length", HFILL }},
 
         { &hf_h223_mux_deact,
