@@ -129,6 +129,8 @@
 void proto_register_hsrp(void);
 void proto_reg_handoff_hsrp(void);
 
+static dissector_handle_t hsrp_handle;
+
 static gint proto_hsrp = -1;
 
 static gint hf_hsrp_version = -1;
@@ -322,7 +324,7 @@ process_hsrp_md5_tlv_sequence(tvbuff_t *tvb, proto_tree *hsrp_tree, guint offset
         proto_item *ti;
         proto_tree *md5_auth_tlv;
 
-        ti = proto_tree_add_uint_format_value(hsrp_tree, hf_hsrp2_md5_auth_tlv, tvb, offset, 1, type, "Type=%d Len=%d", type, len);
+        ti = proto_tree_add_uint_format_value(hsrp_tree, hf_hsrp2_md5_auth_tlv, tvb, offset, 2+len, type, "Type=%d Len=%d", type, len);
         offset+=2;
 
         /* Making MD5 Authentication TLV subtree */
@@ -549,8 +551,8 @@ dissect_hsrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
 
                                 if (tree) {
                                         proto_tree *interface_state_tlv;
-                                        ti = proto_tree_add_uint_format_value(hsrp_tree, hf_hsrp2_interface_state_tlv, tvb, offset, 1, type,
-                                        "Type=%d Len=%d", type, 2+len);
+                                        ti = proto_tree_add_uint_format_value(hsrp_tree, hf_hsrp2_interface_state_tlv, tvb, offset, 2+len, type,
+                                        "Type=%d Len=%d", type, len);
                                         offset+=2;
 
                                         /* Making Interface State TLV subtree */
@@ -831,14 +833,13 @@ void proto_register_hsrp(void)
         proto_register_subtree_array(ett, array_length(ett));
         expert_hsrp = expert_register_protocol(proto_hsrp);
         expert_register_field_array(expert_hsrp, ei, array_length(ei));
+
+        hsrp_handle = register_dissector("hsrp", dissect_hsrp, proto_hsrp);
 }
 
 void
 proto_reg_handoff_hsrp(void)
 {
-        dissector_handle_t hsrp_handle;
-
-        hsrp_handle = create_dissector_handle(dissect_hsrp, proto_hsrp);
         dissector_add_uint_range_with_preference("udp.port", UDP_PORT_HSRP_RANGE, hsrp_handle);
 }
 
