@@ -13,7 +13,6 @@
 #include "config.h"
 
 #include <range.h>
-#include <wiretap/wtap.h>
 #include <epan/packet.h>
 #include <epan/expert.h>
 #include <wsutil/strtoi.h>
@@ -42,6 +41,8 @@
 void proto_reg_handoff_icall(void);
 void proto_register_icall(void);
 
+static dissector_handle_t icall_handle;
+
 static expert_field ei_icall_unexpected_header = EI_INIT;
 static expert_field ei_icall_unexpected_record = EI_INIT;
 static expert_field ei_icall_unexpected_end = EI_INIT;
@@ -94,7 +95,7 @@ dissect_icall(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree _U_, void *dat
 
 	/* Read header */
 	header_offset = tvb_find_guint8(tvb, current_offset, -1, INDIGOCARE_ICALL_STX);
-	ws_strtoi32(tvb_get_string_enc(wmem_packet_scope(), tvb, current_offset, header_offset - current_offset, ENC_NA), NULL, &header);
+	ws_strtoi32(tvb_get_string_enc(pinfo->pool, tvb, current_offset, header_offset - current_offset, ENC_ASCII|ENC_NA), NULL, &header);
 	col_add_fstr(pinfo->cinfo, COL_INFO, "%s:", val_to_str(header, icall_headertypenames, "Unknown (%d)"));
 	switch(header) {
 		case INDIGOCARE_ICALL_CALL:
@@ -113,12 +114,12 @@ dissect_icall(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree _U_, void *dat
 	while (tvb_get_guint8(tvb, current_offset) != INDIGOCARE_ICALL_ETX) {
 		identifier_start = current_offset;
 		identifier_offset = tvb_find_guint8(tvb, current_offset, -1, INDIGOCARE_ICALL_US);
-		ws_strtoi32(tvb_get_string_enc(wmem_packet_scope(), tvb, current_offset, identifier_offset - current_offset, ENC_NA), NULL, &record_identifier);
+		ws_strtoi32(tvb_get_string_enc(pinfo->pool, tvb, current_offset, identifier_offset - current_offset, ENC_ASCII|ENC_NA), NULL, &record_identifier);
 		current_offset = identifier_offset + 1;
 
 		data_start = current_offset;
 		data_offset = tvb_find_guint8(tvb, data_start, -1, INDIGOCARE_ICALL_RS);
-		record_data = tvb_get_string_enc(wmem_packet_scope(), tvb, current_offset, data_offset - data_start, ENC_NA);
+		record_data = tvb_get_string_enc(pinfo->pool, tvb, current_offset, data_offset - data_start, ENC_ASCII|ENC_NA);
 
 		current_offset = data_offset + 1;
 
@@ -126,39 +127,39 @@ dissect_icall(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree _U_, void *dat
 			case INDIGOCARE_ICALL_CALL:
 				switch (record_identifier) {
 					case INDIGOCARE_ICALL_CALL_ROOM:
-						proto_tree_add_item_ret_string(icall_header_tree, hf_icall_call_room_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA, wmem_packet_scope(), &record_data);
+						proto_tree_add_item_ret_string(icall_header_tree, hf_icall_call_room_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA, pinfo->pool, &record_data);
 						col_append_fstr(pinfo->cinfo, COL_INFO, " Room=%s", record_data);
 					break;
 					case INDIGOCARE_ICALL_CALL_TYPE:
-						proto_tree_add_item_ret_string(icall_header_tree, hf_icall_call_type_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA, wmem_packet_scope(), &record_data);
+						proto_tree_add_item_ret_string(icall_header_tree, hf_icall_call_type_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA, pinfo->pool, &record_data);
 						col_append_fstr(pinfo->cinfo, COL_INFO, " Type=%s", record_data);
 					break;
 					case INDIGOCARE_ICALL_CALL_ADDITION:
-						proto_tree_add_item(icall_header_tree, hf_icall_call_addition_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA);
+						proto_tree_add_item(icall_header_tree, hf_icall_call_addition_type, tvb, data_start, data_offset - data_start, ENC_ASCII);
 					break;
 					case INDIGOCARE_ICALL_CALL_ID:
-						proto_tree_add_item(icall_header_tree, hf_icall_call_id_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA);
+						proto_tree_add_item(icall_header_tree, hf_icall_call_id_type, tvb, data_start, data_offset - data_start, ENC_ASCII);
 					break;
 					case INDIGOCARE_ICALL_CALL_TASK:
-						proto_tree_add_item(icall_header_tree, hf_icall_call_task_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA);
+						proto_tree_add_item(icall_header_tree, hf_icall_call_task_type, tvb, data_start, data_offset - data_start, ENC_ASCII);
 					break;
 					case INDIGOCARE_ICALL_CALL_LOCATION:
-						proto_tree_add_item_ret_string(icall_header_tree, hf_icall_call_location_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA, wmem_packet_scope(), &record_data);
+						proto_tree_add_item_ret_string(icall_header_tree, hf_icall_call_location_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA, pinfo->pool, &record_data);
 						col_append_fstr(pinfo->cinfo, COL_INFO, " Location=%s", record_data);
 					break;
 					case INDIGOCARE_ICALL_CALL_NAME1:
-						proto_tree_add_item_ret_string(icall_header_tree, hf_icall_call_name1_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA, wmem_packet_scope(), &record_data);
+						proto_tree_add_item_ret_string(icall_header_tree, hf_icall_call_name1_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA, pinfo->pool, &record_data);
 						col_append_fstr(pinfo->cinfo, COL_INFO, " Name 1=%s", record_data);
 					break;
 					case INDIGOCARE_ICALL_CALL_NAME2:
-						proto_tree_add_item_ret_string(icall_header_tree, hf_icall_call_name2_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA, wmem_packet_scope(), &record_data);
+						proto_tree_add_item_ret_string(icall_header_tree, hf_icall_call_name2_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA, pinfo->pool, &record_data);
 						col_append_fstr(pinfo->cinfo, COL_INFO, " Name 2=%s", record_data);
 					break;
 					case INDIGOCARE_ICALL_CALL_TYPE_NUMERICAL:
-						proto_tree_add_item(icall_header_tree, hf_icall_call_numerical_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA);
+						proto_tree_add_item(icall_header_tree, hf_icall_call_numerical_type, tvb, data_start, data_offset - data_start, ENC_ASCII);
 					break;
 					case INDIGOCARE_ICALL_CALL_NURSE:
-						proto_tree_add_item(icall_header_tree, hf_icall_call_nurse_type, tvb, data_start, data_offset - data_start, ENC_ASCII|ENC_NA);
+						proto_tree_add_item(icall_header_tree, hf_icall_call_nurse_type, tvb, data_start, data_offset - data_start, ENC_ASCII);
 					break;
 					default:
 						proto_tree_add_expert_format(icall_header_tree, pinfo, &ei_icall_unexpected_record, tvb, identifier_start, data_offset - identifier_start, "Unexpected record %d with value %s", record_identifier, record_data);
@@ -184,9 +185,6 @@ dissect_icall(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree _U_, void *dat
 void
 proto_reg_handoff_icall(void)
 {
-	dissector_handle_t icall_handle;
-
-	icall_handle = create_dissector_handle(dissect_icall, proto_icall);
 	dissector_add_for_decode_as("udp.port", icall_handle);
 	dissector_add_for_decode_as("tcp.port", icall_handle);
 }
@@ -295,10 +293,12 @@ proto_register_icall(void)
 
 	expert_icall = expert_register_protocol(proto_icall);
 	expert_register_field_array(expert_icall, ei, array_length(ei));
+
+	icall_handle = register_dissector("icall", dissect_icall, proto_icall);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
