@@ -7,29 +7,15 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
 
 #include <stdlib.h>
-#include <errno.h>
 
 #include <epan/packet.h>
 #include <epan/prefs.h>
-#include <epan/addr_resolv.h>
 #include <epan/conversation.h>
 
 #include "packet-infiniband.h"
@@ -37,6 +23,8 @@
 void proto_register_ib_sdp(void);
 void proto_reg_handoff_ib_sdp(void);
 
+static dissector_handle_t ib_sdp_handle;
+
 /* If the service-id is non-zero after being ANDed with the following mask then
    this is SDP traffic */
 #define SERVICE_ID_MASK 0x0000000000010000
@@ -164,7 +152,7 @@ dissect_ib_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _
     proto_tree_add_item(SDP_BSDH_header_tree, hf_ib_sdp_mid, tvb, local_offset, 1, ENC_BIG_ENDIAN); local_offset += 1;
 
     col_append_fstr(pinfo->cinfo, COL_INFO, "(SDP %s)",
-                    rval_to_str(mid, mid_meanings, "Unknown"));
+                    rval_to_str_const(mid, mid_meanings, "Unknown"));
 
     proto_tree_add_item(SDP_BSDH_header_tree, hf_ib_sdp_flags, tvb, local_offset, 1, ENC_BIG_ENDIAN);
     proto_tree_add_item(SDP_BSDH_header_tree, hf_ib_sdp_flags_oobpres, tvb, local_offset, 2, ENC_BIG_ENDIAN);
@@ -261,14 +249,14 @@ dissect_ib_sdp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *d
        will not work since we do not have the source QP. this WILL succeed when we're still
        in the process of CM negotiations */
     conv = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst,
-                             ENDPOINT_IBQP, pinfo->srcport, pinfo->destport, 0);
+                             CONVERSATION_IBQP, pinfo->srcport, pinfo->destport, 0);
 
     if (!conv) {
         /* if not, try to find an established RC channel. recall Infiniband conversations are
            registered with one side of the channel. since the packet is only guaranteed to
            contain the qpn of the destination, we'll use this */
         conv = find_conversation(pinfo->num, &pinfo->dst, &pinfo->dst,
-                                 ENDPOINT_IBQP, pinfo->destport, pinfo->destport, NO_ADDR_B|NO_PORT_B);
+                                 CONVERSATION_IBQP, pinfo->destport, pinfo->destport, NO_ADDR_B|NO_PORT_B);
 
         if (!conv)
             return FALSE;   /* nothing to do with no conversation context */
@@ -306,15 +294,15 @@ proto_register_ib_sdp(void)
         },
         {&hf_ib_sdp_flags_oobpres, {
             "OOB_PRES", "infiniband_sdp.bsdh.oobpres",
-            FT_UINT8, BASE_HEX, NULL, 0x1, "Out-Of-Band Data is present", HFILL}
+            FT_UINT8, BASE_HEX, NULL, 0x01, "Out-Of-Band Data is present", HFILL}
         },
         {&hf_ib_sdp_flags_oob_pend, {
             "OOB_PEND", "infiniband_sdp.bsdh.oobpend",
-            FT_UINT8, BASE_HEX, NULL, 0x2, "Out-Of-Band Data is pending", HFILL}
+            FT_UINT8, BASE_HEX, NULL, 0x02, "Out-Of-Band Data is pending", HFILL}
         },
         {&hf_ib_sdp_flags_reqpipe, {
             "REQ_PIPE", "infiniband_sdp.bsdh.reqpipe",
-            FT_UINT8, BASE_HEX, NULL, 0x4, "Request change to Pipelined Mode", HFILL}
+            FT_UINT8, BASE_HEX, NULL, 0x04, "Request change to Pipelined Mode", HFILL}
         },
         {&hf_ib_sdp_bufs, {
             "Buffers", "infiniband_sdp.bsdh.bufs",
@@ -335,7 +323,7 @@ proto_register_ib_sdp(void)
         /* SDP Hello Header */
         {&hf_ib_sdp_hh, {
             "Hello Header", "infiniband_sdp.hh",
-            FT_NONE, BASE_NONE, NULL, 0x00, NULL, HFILL}
+            FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL}
         },
         {&hf_ib_sdp_majv, {
             "Major Protocol Version Number", "infiniband_sdp.hh.majv",
@@ -441,14 +429,14 @@ proto_register_ib_sdp(void)
 
     proto_ib_sdp = proto_register_protocol("Infiniband Sockets Direct Protocol", "Infiniband SDP", "infiniband_sdp");
 
-    register_dissector("infiniband_sdp", dissect_ib_sdp, proto_ib_sdp);
+    ib_sdp_handle = register_dissector("infiniband_sdp", dissect_ib_sdp, proto_ib_sdp);
 
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_ib_sdp, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
 
     /* Register preferences */
-    ib_sdp_module = prefs_register_protocol(proto_ib_sdp, proto_reg_handoff_ib_sdp);
+    ib_sdp_module = prefs_register_protocol(proto_ib_sdp, NULL);
 
     prefs_register_static_text_preference(ib_sdp_module, "use_decode_as",
         "Heuristic matching preferences removed.  Use Infiniband protocol preferences or Decode As.",
@@ -474,13 +462,13 @@ proto_reg_handoff_ib_sdp(void)
     heur_dissector_add("infiniband.payload", dissect_ib_sdp_heur, "Infiniband SDP", "sdp_infiniband", proto_ib_sdp, HEURISTIC_ENABLE);
     heur_dissector_add("infiniband.mad.cm.private", dissect_ib_sdp_heur, "Infiniband SDP in PrivateData of CM packets", "sdp_ib_private", proto_ib_sdp, HEURISTIC_ENABLE);
 
-    dissector_add_for_decode_as("infiniband", create_dissector_handle( dissect_ib_sdp, proto_ib_sdp ) );
+    dissector_add_for_decode_as("infiniband", ib_sdp_handle);
 
     proto_infiniband = proto_get_id_by_filter_name( "infiniband" );
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
