@@ -24,6 +24,10 @@
 void proto_register_ismacryp(void);
 void proto_reg_handoff_ismacryp(void);
 
+static dissector_handle_t ismacryp_handle;
+static dissector_handle_t ismacryp_v11_handle;
+static dissector_handle_t ismacryp_v20_handle;
+
 /* keeps track of current position in buffer in terms of bit and byte offset */
 typedef struct Toffset_struct
 {
@@ -67,7 +71,6 @@ static int proto_ismacryp_v11 = -1;
 static int proto_ismacryp_v20 = -1;
 
 /* parameters set in preferences */
-static range_t *pref_dynamic_payload_type_range = NULL; /* RTP dynamic payload types */
 static guint    pref_au_size_length           = DEFAULT_AU_SIZE_LENGTH;            /* default Au size length */
 static guint    pref_au_index_length          = DEFAULT_AU_INDEX_LENGTH;           /* default Au index length */
 static guint    pref_au_index_delta_length    = DEFAULT_AU_INDEX_DELTA_LENGTH;     /* default Au index delta length */
@@ -853,15 +856,14 @@ void proto_register_ismacryp (void)
 	proto_register_field_array (proto_ismacryp, hf, array_length (hf));
 	proto_register_subtree_array (ett, array_length (ett));
 
-	/* Register our configuration options for ismacryp */
-	/* this registers our preferences, function proto_reg_handoff_ismacryp is called when preferences are applied */
-	ismacryp_module = prefs_register_protocol(proto_ismacryp, proto_reg_handoff_ismacryp);
+	ismacryp_handle = register_dissector("ismacryp", dissect_ismacryp, proto_ismacryp);
+	ismacryp_v11_handle = register_dissector("ismacryp_v11", dissect_ismacryp_v11, proto_ismacryp_v11);
+	ismacryp_v20_handle = register_dissector("ismacryp_v20", dissect_ismacryp_v20, proto_ismacryp_v20);
 
-	prefs_register_range_preference(ismacryp_module, "dynamic.payload.type",
-				   "ISMACryp dynamic payload types",
-				   "Dynamic payload types which will be interpreted as ISMACryp"
-				   "; values must be in the range 1 - 127",
-				   &pref_dynamic_payload_type_range, 127);
+	/* Register our configuration options for ismacryp */
+	ismacryp_module = prefs_register_protocol(proto_ismacryp, NULL);
+
+	prefs_register_obsolete_preference(ismacryp_module, "dynamic.payload.type");
 
 	prefs_register_enum_preference(ismacryp_module, "version",
 					       "ISMACryp version",
@@ -988,36 +990,14 @@ void proto_register_ismacryp (void)
 				       "Indicates the number of bits on which the stream state field is encoded"
 				       " in the AU Header (bits)",
 				       10, &pref_stream_state_indication);
-
 }
 
 void proto_reg_handoff_ismacryp(void)
 {
-	static gboolean ismacryp_prefs_initialized = FALSE;
-	static dissector_handle_t ismacryp_handle;
-	static range_t *dynamic_payload_type_range;
-
-	if (!ismacryp_prefs_initialized) {
-		dissector_handle_t ismacryp_v11_handle;
-		dissector_handle_t ismacryp_v20_handle;
-		ismacryp_handle = create_dissector_handle(dissect_ismacryp, proto_ismacryp);
-		ismacryp_v11_handle = create_dissector_handle(dissect_ismacryp_v11, proto_ismacryp_v11);
-		ismacryp_v20_handle = create_dissector_handle(dissect_ismacryp_v20, proto_ismacryp_v20);
-		ismacryp_prefs_initialized = TRUE;
-		dissector_add_string("rtp_dyn_payload_type", "ISMACRYP", ismacryp_handle);
-		dissector_add_string("rtp_dyn_payload_type", "enc-mpeg4-generic", ismacryp_v11_handle);
-		dissector_add_string("rtp_dyn_payload_type", "enc-isoff-generic", ismacryp_v20_handle);
-	  }
-	else { /* ismacryp_prefs_initialized = TRUE */
-		/* delete existing association of ismacryp with payload_type */
-		dissector_delete_uint_range("rtp.pt", dynamic_payload_type_range, ismacryp_handle);
-		wmem_free(wmem_epan_scope(), dynamic_payload_type_range);
-	}
-	/* always do the following */
-	/* update payload_type to new value */
-	dynamic_payload_type_range = range_copy(wmem_epan_scope(), pref_dynamic_payload_type_range);
-	range_remove_value(wmem_epan_scope(), &dynamic_payload_type_range, 0);
-	dissector_add_uint_range("rtp.pt", dynamic_payload_type_range, ismacryp_handle);
+	dissector_add_string("rtp_dyn_payload_type", "ISMACRYP", ismacryp_handle);
+	dissector_add_string("rtp_dyn_payload_type", "enc-mpeg4-generic", ismacryp_v11_handle);
+	dissector_add_string("rtp_dyn_payload_type", "enc-isoff-generic", ismacryp_v20_handle);
+	dissector_add_uint_range_with_preference("rtp.pt", "", ismacryp_handle);
 
 }
 
