@@ -157,6 +157,7 @@ static int hf_iso15765_flow_status = -1;
 
 static int hf_iso15765_fc_bs = -1;
 static int hf_iso15765_fc_stmin = -1;
+static int hf_iso15765_fc_stmin_in_us = -1;
 
 static int hf_iso15765_autosar_ack = -1;
 
@@ -248,7 +249,7 @@ copy_config_can_addr_mapping_cb(void *n, const void *o, size_t size _U_) {
     return new_rec;
 }
 
-static gboolean
+static bool
 update_config_can_addr_mappings(void *r, char **err) {
     config_can_addr_mapping_t *rec = (config_can_addr_mapping_t *)r;
 
@@ -399,7 +400,7 @@ copy_config_pdu_transport_config_cb(void *n, const void *o, size_t size _U_) {
     return new_rec;
 }
 
-static gboolean
+static bool
 update_config_pdu_transport_config_item(void *r, char **err) {
     config_pdu_transport_config_t *rec = (config_pdu_transport_config_t *)r;
 
@@ -621,7 +622,7 @@ dissect_iso15765(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 bu
                 proto_tree_add_uint(iso15765_tree, hf_iso15765_data_length, tvb, ae, 1, data_length);
             }
 
-            next_tvb = tvb_new_subset_length_caplen(tvb, offset, data_length, data_length);
+            next_tvb = tvb_new_subset_length(tvb, offset, data_length);
             complete = TRUE;
 
             col_append_fstr(pinfo->cinfo, COL_INFO, "(Len: %d)", data_length);
@@ -687,16 +688,24 @@ dissect_iso15765(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 bu
             guint32 status = 0;
             guint32 bs = 0;
             guint32 stmin = 0;
+            gboolean stmin_in_us = FALSE;
             data_length = 0;
 
             proto_tree_add_item_ret_uint(iso15765_tree, hf_iso15765_flow_status, tvb, ae,
                                          ISO15765_PCI_LEN, ENC_BIG_ENDIAN, &status);
             proto_tree_add_item_ret_uint(iso15765_tree, hf_iso15765_fc_bs, tvb, ae + ISO15765_FC_BS_OFFSET,
                                          ISO15765_FC_BS_LEN, ENC_BIG_ENDIAN, &bs);
-            proto_tree_add_item_ret_uint(iso15765_tree, hf_iso15765_fc_stmin, tvb, ae + ISO15765_FC_STMIN_OFFSET,
-                                         ISO15765_FC_STMIN_LEN, ENC_BIG_ENDIAN, &stmin);
-            col_append_fstr(pinfo->cinfo, COL_INFO, "(Status: %d, Block size: 0x%x, Separation time minimum: %d ms)",
-                            status, bs, stmin);
+
+            stmin = tvb_get_guint8(tvb, ae + ISO15765_FC_STMIN_OFFSET);
+            if (stmin >= 0xF1 && stmin <= 0xF9) {
+                stmin_in_us = TRUE;
+                stmin = (stmin - 0xF0) * 100U;
+                proto_tree_add_uint(iso15765_tree, hf_iso15765_fc_stmin_in_us, tvb, ae + ISO15765_FC_STMIN_OFFSET,
+                    ISO15765_FC_STMIN_LEN, stmin);
+            } else {
+                proto_tree_add_uint(iso15765_tree, hf_iso15765_fc_stmin, tvb, ae + ISO15765_FC_STMIN_OFFSET,
+                                             ISO15765_FC_STMIN_LEN, stmin);
+            }
 
             if (message_type == ISO15765_MESSAGE_TYPES_FR_ACK_FRAME) {
                 guint32 ack = 0;
@@ -706,11 +715,11 @@ dissect_iso15765(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 bu
                 proto_tree_add_item_ret_uint(iso15765_tree, hf_iso15765_autosar_ack, tvb, offset, 1, ENC_BIG_ENDIAN, &ack);
                 proto_tree_add_item_ret_uint(iso15765_tree, hf_iso15765_sequence_number, tvb, offset, 1, ENC_BIG_ENDIAN, &sn);
 
-                col_append_fstr(pinfo->cinfo, COL_INFO, "(Status: %d, Block size: 0x%x, Separation time minimum: %d ms, Ack: %d, Seq: %d)",
-                                status, bs, stmin, ack, sn);
+                col_append_fstr(pinfo->cinfo, COL_INFO, "(Status: %d, Block size: 0x%x, Separation time minimum: %d %s, Ack: %d, Seq: %d)",
+                                status, bs, stmin, stmin_in_us ? "µs" : "ms", ack, sn);
             } else {
-                col_append_fstr(pinfo->cinfo, COL_INFO, "(Status: %d, Block size: 0x%x, Separation time minimum: %d ms)",
-                                status, bs, stmin);
+                col_append_fstr(pinfo->cinfo, COL_INFO, "(Status: %d, Block size: 0x%x, Separation time minimum: %d %s)",
+                                status, bs, stmin, stmin_in_us ? "µs" : "ms");
             }
             break;
         }
@@ -720,7 +729,7 @@ dissect_iso15765(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 bu
             data_length = tvb_get_guint8(tvb, ae + 1);
             proto_tree_add_item(iso15765_tree, hf_iso15765_data_length, tvb, ae + 1, 1, ENC_BIG_ENDIAN);
 
-            next_tvb = tvb_new_subset_length_caplen(tvb, offset, data_length, data_length);
+            next_tvb = tvb_new_subset_length(tvb, offset, data_length);
             complete = TRUE;
 
             /* Show some info */
@@ -833,7 +842,7 @@ dissect_iso15765(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 bu
                 next_tvb = new_tvb;
                 complete = TRUE;
             } else {
-                next_tvb = tvb_new_subset_length_caplen(tvb, offset, data_length, data_length);
+                next_tvb = tvb_new_subset_length(tvb, offset, data_length);
             }
         }
     }
@@ -862,10 +871,17 @@ dissect_iso15765_can(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void*
         return 0;
     }
 
-    if (can_info.fd) {
+    switch (can_info.fd) {
+
+    case CAN_TYPE_CAN_FD:
         return dissect_iso15765(tvb, pinfo, tree, ISO15765_TYPE_CAN_FD, can_info.id, can_info.len);
-    } else {
+
+    case CAN_TYPE_CAN_CLASSIC:
         return dissect_iso15765(tvb, pinfo, tree, ISO15765_TYPE_CAN, can_info.id, can_info.len);
+
+    default:
+        DISSECTOR_ASSERT_NOT_REACHED();
+        return tvb_captured_length(tvb);
     }
 }
 
@@ -1034,6 +1050,15 @@ proto_register_iso15765(void)
                             NULL, HFILL
                     }
             },
+            {
+                    &hf_iso15765_fc_stmin_in_us,
+                    {
+                            "Separation time minimum (µs)",    "iso15765.flow_control.stmin",
+                            FT_UINT8,  BASE_DEC,
+                            NULL, 0x00,
+                            NULL, HFILL
+                    }
+            },
             {
                     &hf_iso15765_autosar_ack,
                     {
