@@ -10,16 +10,22 @@
 #ifndef __PACKET_ISO15765_H__
 #define __PACKET_ISO15765_H__
 
-#define ISO15765_TYPE_NONE    0
-#define ISO15765_TYPE_CAN     1
-#define ISO15765_TYPE_CAN_FD  2
-#define ISO15765_TYPE_LIN     3
-#define ISO15765_TYPE_FLEXRAY 4
+#define ISO15765_TYPE_NONE          0
+#define ISO15765_TYPE_CAN           1
+#define ISO15765_TYPE_CAN_FD        2
+#define ISO15765_TYPE_LIN           3
+#define ISO15765_TYPE_FLEXRAY       4
+#define ISO15765_TYPE_IPDUM         5
+#define ISO15765_TYPE_PDU_TRANSPORT 6
+
 
 struct iso15765_info {
-    guint32 bus_type;
-    guint32 id;
-    guint32 len;
+    guint32  bus_type;
+    guint32  id;
+    guint32  len;
+    guint32  target_address;
+    guint32  source_address;
+    guint8   number_of_addresses_valid;
 };
 
 typedef struct iso15765_info iso15765_info_t;
