@@ -9,15 +9,18 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
+#include "config.h"
+
 #define WS_LOG_DOMAIN "packet-knxip"
 
 #include <wsutil/file_util.h>
-#include "proto.h"
+#include <epan/proto.h>
 #include "packet-knxip_decrypt.h"
 #include <epan/wmem_scopes.h>
 #include <wsutil/wsgcrypt.h>
 #include <wsutil/strtoi.h>
 #include <wsutil/wslog.h>
+#include <wsutil/inet_addr.h>
 
 #define TEXT_BUFFER_SIZE  128
 
@@ -295,7 +298,7 @@ static void decrypt_key( guint8 key[] _U_, guint8 password_hash[] _U_, guint8 cr
 static void decode_and_decrypt_key( guint8 key[ BASE64_KNX_KEY_LENGTH + 1 ], const gchar* text, guint8 password_hash[], guint8 created_hash[] )
 {
   gsize out_len;
-  g_snprintf( (gchar*) key, BASE64_KNX_KEY_LENGTH + 1, "%s", text );
+  snprintf( (gchar*) key, BASE64_KNX_KEY_LENGTH + 1, "%s", text );
   g_base64_decode_inplace( (gchar*) key, &out_len );
   decrypt_key( key, password_hash, created_hash );
 }
@@ -501,7 +504,7 @@ static void add_ia_seq( guint16 ia, const gchar* text, FILE* f2 )
 
   if( f2 )
   {
-    fprintf( f2, "IA %u.%u.%u SeqNr %" G_GINT64_MODIFIER "u\n", (ia >> 12) & 0xF, (ia >> 8) & 0xF, ia & 0xFF, seq );
+    fprintf( f2, "IA %u.%u.%u SeqNr %" PRIu64 "\n", (ia >> 12) & 0xF, (ia >> 8) & 0xF, ia & 0xFF, seq );
   }
 
   ia_seq = wmem_new(wmem_epan_scope(), struct knx_keyring_ia_seqs);
@@ -635,7 +638,7 @@ void read_knx_keyring_xml_file( const gchar* key_file, const gchar* password, co
 
         if( !tag_name_done )  // tag name
         {
-          g_snprintf( tag_name, sizeof tag_name, "%s", name );
+          snprintf( tag_name, sizeof tag_name, "%s", name );
           *name = '\0';
           tag_name_done = 1;
         }
