@@ -70,11 +70,16 @@ void proto_register_logcat_text(void);
 void proto_reg_handoff_logcat_text(void);
 
 static int get_priority(const gchar *frame, const gchar *token, tvbuff_t *tvb,
-        proto_tree *maintree, gint start_offset, packet_info *pinfo _U_) {
+        proto_tree *maintree, gint start_offset, packet_info *pinfo) {
     int prio;
     gchar *p = g_strstr_len(frame + start_offset, -1, token);
     int offset = (int)(p - frame);
 
+    if (!p) {
+        proto_tree_add_expert(maintree, pinfo, &ei_malformed_token, tvb, start_offset, -1);
+        return (start_offset + 1);
+    }
+
     switch (*p) {
     case 'I':
         prio = 4;
@@ -213,7 +218,7 @@ static void add_exported_pdu(tvbuff_t *tvb, packet_info *pinfo, const char * sub
     if (have_tap_listener(exported_pdu_tap)) {
         exp_pdu_data_t *exp_pdu_data;
 
-        exp_pdu_data = export_pdu_create_tags(pinfo, subdissector_name, EXP_PDU_TAG_PROTO_NAME, NULL);
+        exp_pdu_data = export_pdu_create_tags(pinfo, subdissector_name, EXP_PDU_TAG_DISSECTOR_NAME, NULL);
 
         exp_pdu_data->tvb_captured_length = tvb_captured_length(tvb);
         exp_pdu_data->tvb_reported_length = tvb_reported_length(tvb);
