@@ -12,9 +12,9 @@
 
 /*
  * See Mongo Wire Protocol Specification
- * http://www.mongodb.org/display/DOCS/Mongo+Wire+Protocol
+ * https://www.mongodb.com/docs/manual/reference/mongodb-wire-protocol/
  * See also BSON Specification
- * http://bsonspec.org/#/specification
+ * http://bsonspec.org/spec.html
  */
 
 #include "config.h"
@@ -23,6 +23,9 @@
 #include <epan/exceptions.h>
 #include <epan/expert.h>
 #include <epan/proto_data.h>
+#include <epan/exceptions.h>
+#include <wsutil/crc32.h> // CRC32C_PRELOAD
+#include <epan/crc32-tvb.h> // crc32c_tvb_offset_calculate
 #include "packet-tcp.h"
 #include "packet-tls.h"
 #ifdef HAVE_SNAPPY
@@ -96,11 +99,13 @@ static const value_string section_kind_vals[] = {
 #define MONGO_COMPRESSOR_NOOP    0
 #define MONGO_COMPRESSOR_SNAPPY  1
 #define MONGO_COMPRESSOR_ZLIB    2
+#define MONGO_COMPRESSOR_ZSTD    3
 
 static const value_string compressor_vals[] = {
   { MONGO_COMPRESSOR_NOOP,   "Noop (Uncompressed)" },
   { MONGO_COMPRESSOR_SNAPPY, "Snappy" },
   { MONGO_COMPRESSOR_ZLIB,   "Zlib" },
+  { MONGO_COMPRESSOR_ZSTD,   "Zstd" },
   { 0,  NULL }
 };
 
@@ -124,6 +129,7 @@ static const value_string compressor_vals[] = {
 #define BSON_ELEMENT_TYPE_INT32         16  /* 0x10 */
 #define BSON_ELEMENT_TYPE_TIMESTAMP     17  /* 0x11 */
 #define BSON_ELEMENT_TYPE_INT64         18  /* 0x12 */
+#define BSON_ELEMENT_TYPE_DECIMAL128    19  /* 0x13 */
 #define BSON_ELEMENT_TYPE_MIN_KEY      255  /* 0xFF */
 #define BSON_ELEMENT_TYPE_MAX_KEY      127  /* 0x7F */
 
@@ -146,6 +152,7 @@ static const value_string element_type_vals[] = {
   { BSON_ELEMENT_TYPE_INT32,          "Int32" },
   { BSON_ELEMENT_TYPE_TIMESTAMP,      "Timestamp" },
   { BSON_ELEMENT_TYPE_INT64,          "Int64" },
+  { BSON_ELEMENT_TYPE_DECIMAL128,     "128-bit decimal floating point" },
   { BSON_ELEMENT_TYPE_MIN_KEY,        "Min Key" },
   { BSON_ELEMENT_TYPE_MAX_KEY,        "Max Key" },
   { 0, NULL }
@@ -221,6 +228,7 @@ static int hf_mongo_element_length = -1;
 static int hf_mongo_element_value_boolean = -1;
 static int hf_mongo_element_value_int32 = -1;
 static int hf_mongo_element_value_int64 = -1;
+static int hf_mongo_element_value_decimal128 = -1;
 static int hf_mongo_element_value_double = -1;
 static int hf_mongo_element_value_string = -1;
 static int hf_mongo_element_value_string_length = -1;
@@ -260,6 +268,8 @@ static int hf_mongo_msg_sections_section_body = -1;
 static int hf_mongo_msg_sections_section_doc_sequence = -1;
 static int hf_mongo_msg_sections_section_size = -1;
 static int hf_mongo_msg_sections_section_doc_sequence_id = -1;
+static int hf_mongo_msg_checksum = -1;
+static int hf_mongo_msg_checksum_status = -1;
 
 static gint ett_mongo = -1;
 static gint ett_mongo_doc = -1;
@@ -278,9 +288,11 @@ static gint ett_mongo_doc_sequence= -1;
 
 static expert_field ei_mongo_document_recursion_exceeded = EI_INIT;
 static expert_field ei_mongo_document_length_bad = EI_INIT;
+static expert_field ei_mongo_section_size_bad = EI_INIT;
 static expert_field ei_mongo_unknown = EI_INIT;
 static expert_field ei_mongo_unsupported_compression = EI_INIT;
 static expert_field ei_mongo_too_large_compressed = EI_INIT;
+static expert_field ei_mongo_msg_checksum = EI_INIT;
 
 static int
 dissect_fullcollectionname(tvbuff_t *tvb, guint offset, proto_tree *tree)
@@ -465,6 +477,12 @@ dissect_bson_document(tvbuff_t *tvb, packet_info *pinfo, guint offset, proto_tre
         proto_tree_add_item(element_sub_tree, hf_mongo_element_value_int64, tvb, offset, 8, ENC_LITTLE_ENDIAN);
         offset += 8;
         break;
+      case BSON_ELEMENT_TYPE_DECIMAL128:
+        /* TODO Implement routine to convert to decimal128 for now, simply display bytes */
+        /* https://github.com/mongodb/specifications/blob/master/source/bson-decimal128/decimal128.rst */
+        proto_tree_add_item(element_sub_tree, hf_mongo_element_value_decimal128, tvb, offset, 16, ENC_NA);
+        offset += 16;
+        break;
       default:
         break;
     }  /* end switch() */
@@ -754,6 +772,22 @@ dissect_mongo_op_compressed(tvbuff_t *tvb, packet_info *pinfo, guint offset, pro
   } break;
 #endif
 
+#ifdef HAVE_ZSTD
+  case MONGO_COMPRESSOR_ZSTD:
+  {
+    tvbuff_t *uncompressed_tvb = tvb_child_uncompress_zstd (tvb, tvb, offset, tvb_captured_length_remaining (tvb, offset));
+    if (!uncompressed_tvb) {
+      expert_add_info_format(pinfo, ti, &ei_mongo_unsupported_compression, "Error uncompressing zstd data");
+    } else {
+      add_new_data_source(pinfo, uncompressed_tvb, "Decompressed Data");
+      dissect_opcode_types(uncompressed_tvb, pinfo, 0, tree, opcode, effective_opcode);
+    }
+
+    offset = tvb_reported_length(tvb);
+  }
+  break;
+#endif
+
   case MONGO_COMPRESSOR_ZLIB: {
     tvbuff_t* compressed_tvb = NULL;
 
@@ -790,16 +824,27 @@ dissect_op_msg_section(tvbuff_t *tvb, packet_info *pinfo, guint offset, proto_tr
   gint section_len = -1;   /* Section length */
 
   e_type = tvb_get_guint8(tvb, offset);
-  section_len = tvb_get_letohl(tvb, offset+1);
 
-  ti = proto_tree_add_item(tree, hf_mongo_msg_sections_section, tvb, offset, 1 + section_len, ENC_NA);
+  ti = proto_tree_add_item(tree, hf_mongo_msg_sections_section, tvb, offset, 1, ENC_NA);
   section_tree = proto_item_add_subtree(ti, ett_mongo_section);
   proto_tree_add_item(section_tree, hf_mongo_msg_sections_section_kind, tvb, offset, 1, ENC_LITTLE_ENDIAN);
   offset += 1;
 
+  section_len = tvb_get_letohil(tvb, offset);
+  /* The section length must be strictly smaller than the total message size,
+   * both signed int32s. This prevents signed integer overflow. */
+  if (section_len < 0 || section_len == INT32_MAX) {
+    proto_tree_add_expert_format(section_tree, pinfo, &ei_mongo_section_size_bad, tvb, offset, 4, "Bogus Mongo message section size: %i", section_len);
+    THROW(ReportedBoundsError);
+  }
+  proto_item_set_len(ti, 1 + section_len);
+
   switch (e_type) {
     case KIND_BODY:
-      dissect_bson_document(tvb, pinfo, offset, section_tree, hf_mongo_msg_sections_section_body);
+      section_len = dissect_bson_document(tvb, pinfo, offset, section_tree, hf_mongo_msg_sections_section_body);
+      /* If section_len is bogus (e.g., negative), dissect_bson_document sets
+       * an expert info and can return a different value than read above.
+       */
       break;
     case KIND_DOCUMENT_SEQUENCE: {
       gint32 dsi_length;
@@ -808,6 +853,9 @@ dissect_op_msg_section(tvbuff_t *tvb, packet_info *pinfo, guint offset, proto_tr
       proto_tree *documents_tree;
 
       proto_tree_add_item(section_tree, hf_mongo_msg_sections_section_size, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+      /* This is redundant with the lengths in the documents, we don't use this
+       * size at all. We could still report an expert info if it's bogus.
+       */
       offset += 4;
       to_read -= 4;
 
@@ -842,14 +890,26 @@ dissect_mongo_op_msg(tvbuff_t *tvb, packet_info *pinfo, guint offset, proto_tree
     &hf_mongo_msg_flags_exhaustallowed,
     NULL
   };
+  gint64 op_msg_flags;
+  bool checksum_present = false;
+
+  proto_tree_add_bitmask_ret_uint64 (tree, tvb, offset, hf_mongo_msg_flags, ett_mongo_msg_flags, mongo_msg_flags, ENC_LITTLE_ENDIAN, &op_msg_flags);
+  if (op_msg_flags & 0x00000001) {
+    checksum_present = true;
+  }
 
-  proto_tree_add_bitmask(tree, tvb, offset, hf_mongo_msg_flags, ett_mongo_msg_flags, mongo_msg_flags, ENC_LITTLE_ENDIAN);
   offset += 4;
 
-  while (tvb_reported_length_remaining(tvb, offset) > 0){
+  while (tvb_reported_length_remaining(tvb, offset) > (checksum_present ? 4 : 0)){
     offset += dissect_op_msg_section(tvb, pinfo, offset, tree);
   }
 
+  if (checksum_present) {
+    guint32 calculated_checksum = ~crc32c_tvb_offset_calculate (tvb, 0, tvb_reported_length (tvb) - 4, CRC32C_PRELOAD);
+    proto_tree_add_checksum(tree, tvb, offset, hf_mongo_msg_checksum, hf_mongo_msg_checksum_status, &ei_mongo_msg_checksum, pinfo, calculated_checksum, ENC_BIG_ENDIAN, PROTO_CHECKSUM_VERIFY);
+    offset += 4;
+  }
+
   return offset;
 }
 
@@ -1281,6 +1341,16 @@ proto_register_mongo(void)
       FT_STRING, BASE_NONE, NULL, 0x0,
       "Document sequence identifier", HFILL }
     },
+    { &hf_mongo_msg_checksum,
+      { "Checksum", "mongo.msg.checksum",
+      FT_UINT32, BASE_HEX, NULL, 0x0,
+      "CRC32C checksum.", HFILL }
+    },
+    { &hf_mongo_msg_checksum_status,
+      { "Checksum Status", "mongo.msg.checksum.status",
+      FT_UINT8, BASE_NONE, VALS(proto_checksum_vals), 0x0,
+      NULL, HFILL }
+    },
     { &hf_mongo_number_of_cursor_ids,
       { "Number of Cursor IDS", "mongo.number_to_cursor_ids",
       FT_INT32, BASE_DEC, NULL, 0x0,
@@ -1321,6 +1391,11 @@ proto_register_mongo(void)
       FT_INT64, BASE_DEC, NULL, 0x0,
       "Element Value", HFILL }
     },
+    { &hf_mongo_element_value_decimal128,
+      { "Value", "mongo.element.value.decimal128",
+      FT_BYTES, BASE_NONE, NULL, 0x0,
+      "Element Value", HFILL }
+    },
     { &hf_mongo_element_value_double,
       { "Value", "mongo.element.value.double",
       FT_DOUBLE, BASE_NONE, NULL, 0x0,
@@ -1458,9 +1533,11 @@ proto_register_mongo(void)
   static ei_register_info ei[] = {
      { &ei_mongo_document_recursion_exceeded, { "mongo.document.recursion_exceeded", PI_MALFORMED, PI_ERROR, "BSON document recursion exceeds", EXPFILL }},
      { &ei_mongo_document_length_bad, { "mongo.document.length.bad",  PI_MALFORMED, PI_ERROR, "BSON document length bad", EXPFILL }},
+     { &ei_mongo_section_size_bad, { "mongo.msg.sections.section.size.bad",  PI_MALFORMED, PI_ERROR, "Bogus Mongo message section size", EXPFILL }},
      { &ei_mongo_unknown, { "mongo.unknown.expert", PI_UNDECODED, PI_WARN, "Unknown Data (not interpreted)", EXPFILL }},
      { &ei_mongo_unsupported_compression, { "mongo.unsupported_compression.expert", PI_UNDECODED, PI_WARN, "This packet was compressed with an unsupported compressor", EXPFILL }},
      { &ei_mongo_too_large_compressed, { "mongo.too_large_compressed.expert", PI_UNDECODED, PI_WARN, "The size of the uncompressed packet exceeded the maximum allowed value", EXPFILL }},
+     { &ei_mongo_msg_checksum, { "mongo.bad_checksum.expert", PI_UNDECODED, PI_ERROR, "Bad checksum", EXPFILL }},
   };
 
   proto_mongo = proto_register_protocol("Mongo Wire Protocol", "MONGO", "mongo");
