@@ -7,19 +7,7 @@
  * This file created by Mike Hall <mlh@io.com>
  * Copyright 1998
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -32,7 +20,6 @@
 #include "packet-ppp.h"
 #include <epan/etypes.h>
 #include <epan/aftypes.h>
-#include <wiretap/wtap.h>
 
 void proto_register_null(void);
 void proto_reg_handoff_null(void);
@@ -61,6 +48,9 @@ static const value_string family_vals[] = {
   {0,                    NULL             }
 };
 
+static dissector_handle_t null_handle, loop_handle;
+static capture_dissector_handle_t null_cap_handle;
+
 static dissector_handle_t ppp_hdlc_handle;
 static capture_dissector_handle_t ppp_hdlc_cap_handle;
 
@@ -349,9 +339,10 @@ dissect_null(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
     col_set_str(pinfo->cinfo, COL_INFO, "Null/Loopback");
 
     /*
-     * Treat it as a normal DLT_NULL header.
+     * Treat it as a normal DLT_NULL header.  Fetch it in host
+     * byte order.
      */
-    tvb_memcpy(tvb, (guint8 *)&null_header, 0, sizeof(null_header));
+    null_header = tvb_get_h_guint32(tvb, 0);
 
     if ((null_header & 0xFFFF0000) != 0) {
       /*
@@ -493,14 +484,15 @@ proto_register_null(void)
                                                   "Null type", proto_null, FT_UINT32, BASE_DEC);
 
   register_capture_dissector_table("null.bsd", "Null/Loopback BSD AF");
+
+  null_handle = register_dissector("null", dissect_null, proto_null);
+  loop_handle = register_dissector("null.loop", dissect_loop, proto_null);
+  null_cap_handle = register_capture_dissector("null", capture_null, proto_null);
 }
 
 void
 proto_reg_handoff_null(void)
 {
-  dissector_handle_t null_handle, loop_handle;
-  capture_dissector_handle_t null_cap_handle;
-
   /*
    * Get a handle for the PPP-in-HDLC-like-framing dissector and
    * the "I don't know what this is" dissector.
@@ -509,13 +501,10 @@ proto_reg_handoff_null(void)
 
   ethertype_dissector_table = find_dissector_table("ethertype");
 
-  null_handle = create_dissector_handle(dissect_null, proto_null);
   dissector_add_uint("wtap_encap", WTAP_ENCAP_NULL, null_handle);
 
-  loop_handle = create_dissector_handle(dissect_loop, proto_null);
   dissector_add_uint("wtap_encap", WTAP_ENCAP_LOOP, loop_handle);
 
-  null_cap_handle = create_capture_dissector_handle(capture_null, proto_null);
   capture_dissector_add_uint("wtap_encap", WTAP_ENCAP_NULL, null_cap_handle);
   capture_dissector_add_uint("wtap_encap", WTAP_ENCAP_LOOP, null_cap_handle);
 
