@@ -102,6 +102,16 @@ static int hf_openflow_total_len = -1;
 static int hf_openflow_in_port = -1;
 static int hf_openflow_reason = -1;
 static int hf_openflow_pkt_in_pad = -1;
+static int hf_openflow_flow_removed_cookie = -1;
+static int hf_openflow_flow_removed_priority = -1;
+static int hf_openflow_flow_removed_reason = -1;
+static int hf_openflow_flow_removed_pad1 = -1;
+static int hf_openflow_flow_removed_duration_sec = -1;
+static int hf_openflow_flow_removed_duration_nsec = -1;
+static int hf_openflow_flow_removed_idle_timeout = -1;
+static int hf_openflow_flow_removed_pad2 = -1;
+static int hf_openflow_flow_removed_packet_count = -1;
+static int hf_openflow_flow_removed_byte_count = -1;
 static int hf_openflow_table_id = -1;
 static int hf_openflow_cookie = -1;
 /* static int hf_openflow_cookie_mask = -1; */
@@ -423,7 +433,7 @@ dissect_openflow_phy_port(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tre
     offset+=2;
     proto_tree_add_item(tree, hf_openflow_hw_addr, tvb, offset, 6, ENC_NA);
     offset+=6;
-    proto_tree_add_item(tree, hf_openflow_port_name, tvb, offset, OFP_MAX_PORT_NAME_LEN, ENC_ASCII|ENC_NA);
+    proto_tree_add_item(tree, hf_openflow_port_name, tvb, offset, OFP_MAX_PORT_NAME_LEN, ENC_ASCII);
     offset+=OFP_MAX_PORT_NAME_LEN;
 
     /* Bitmap of OFPPC_* flags. */
@@ -644,6 +654,63 @@ dissect_openflow_pkt_in(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int
 
 }
 
+#define OFPRR_IDLE_TIMEOUT  0
+#define OFPRR_HARD_TIMEOUT  1
+#define OFPRR_DELETE        2
+static const value_string openflow_flow_removed_reason_values[] = {
+    { OFPRR_IDLE_TIMEOUT, "OFPRR_IDLE_TIMEOUT" },
+    { OFPRR_HARD_TIMEOUT, "OFPRR_HARD_TIMEOUT" },
+    { OFPRR_DELETE,       "OFPRR_DELETE" },
+    { 0,                  NULL }
+};
+
+static void
+dissect_openflow_flow_removed(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, guint16 length _U_)
+{
+    /* struct match; */
+    offset = dissect_openflow_ofp_match_v1(tvb, pinfo, tree, offset);
+
+    /* uint64_t cookie; */
+    proto_tree_add_item(tree, hf_openflow_flow_removed_cookie, tvb, offset, 8, ENC_BIG_ENDIAN);
+    offset+=8;
+
+    /* uint16_t priority; */
+    proto_tree_add_item(tree, hf_openflow_flow_removed_priority, tvb, offset, 2, ENC_BIG_ENDIAN);
+    offset+=2;
+
+    /* uint8_t reason; */
+    proto_tree_add_item(tree, hf_openflow_flow_removed_reason, tvb, offset, 1, ENC_BIG_ENDIAN);
+    offset+=1;
+
+    /* uint8_t pad1; */
+    proto_tree_add_item(tree, hf_openflow_flow_removed_pad1, tvb, offset, 1, ENC_BIG_ENDIAN);
+    offset+=1;
+
+    /* uint32_t duration_sec; */
+    proto_tree_add_item(tree, hf_openflow_flow_removed_duration_sec, tvb, offset, 4, ENC_BIG_ENDIAN);
+    offset+=4;
+
+    /* uint32_t duration_nsec; */
+    proto_tree_add_item(tree, hf_openflow_flow_removed_duration_nsec, tvb, offset, 4, ENC_BIG_ENDIAN);
+    offset+=4;
+
+    /* uint16_t idle_timeout; */
+    proto_tree_add_item(tree, hf_openflow_flow_removed_idle_timeout, tvb, offset, 2, ENC_BIG_ENDIAN);
+    offset+=2;
+
+    /* uint8_t pad2; */
+    proto_tree_add_item(tree, hf_openflow_flow_removed_pad2, tvb, offset, 2, ENC_BIG_ENDIAN);
+    offset+=2;
+
+    /* uint64_t packet_count; */
+    proto_tree_add_item(tree, hf_openflow_flow_removed_packet_count, tvb, offset, 8, ENC_BIG_ENDIAN);
+    offset+=8;
+
+    /* uint64_t byte_count; */
+    proto_tree_add_item(tree, hf_openflow_flow_removed_byte_count, tvb, offset, 8, ENC_BIG_ENDIAN);
+
+}
+
 static void
 dissect_openflow_pkt_out(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, guint16 length)
 {
@@ -881,6 +948,9 @@ dissect_openflow_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *d
     case OFPT_1_0_PACKET_IN: /* 10 */
         dissect_openflow_pkt_in(tvb, pinfo, openflow_tree, offset, length);
         break;
+    case OFPT_1_0_FLOW_REMOVED: /* 11 */
+        dissect_openflow_flow_removed(tvb, pinfo, openflow_tree, offset, length);
+        break;
     case OFPT_1_0_PACKET_OUT: /* 13 */
         dissect_openflow_pkt_out(tvb, pinfo, openflow_tree, offset, length);
         break;
@@ -1257,6 +1327,56 @@ proto_register_openflow_v1(void)
                FT_BYTES, BASE_NONE, NULL, 0x0,
                NULL, HFILL }
         },
+        { &hf_openflow_flow_removed_cookie,
+            { "Cookie", "openflow.flow_removed.cookie",
+               FT_UINT64, BASE_HEX, NULL, 0x0,
+               NULL, HFILL }
+        },
+        { &hf_openflow_flow_removed_priority,
+            { "Priority", "openflow.flow_removed.priority",
+               FT_UINT16, BASE_DEC, NULL, 0x0,
+               NULL, HFILL }
+        },
+        { &hf_openflow_flow_removed_reason,
+            { "Reason", "openflow.flow_removed.reason",
+               FT_UINT8, BASE_DEC, VALS(openflow_flow_removed_reason_values), 0x0,
+               NULL, HFILL }
+        },
+        { &hf_openflow_flow_removed_pad1,
+            { "Pad1", "openflow.flow_removed.pad1",
+               FT_UINT8, BASE_HEX, NULL, 0x0,
+               NULL, HFILL }
+        },
+        { &hf_openflow_flow_removed_duration_sec,
+            { "Duration sec", "openflow.flow_removed.duration_sec",
+               FT_UINT32, BASE_DEC, NULL, 0x0,
+               NULL, HFILL }
+        },
+        { &hf_openflow_flow_removed_duration_nsec,
+            { "Duration nsec", "openflow.flow_removed.duration_nsec",
+               FT_UINT32, BASE_DEC, NULL, 0x0,
+               NULL, HFILL }
+        },
+        { &hf_openflow_flow_removed_idle_timeout,
+            { "Idle timeout", "openflow.flow_removed.idle_timeout",
+               FT_UINT16, BASE_DEC, NULL, 0x0,
+               NULL, HFILL }
+        },
+        { &hf_openflow_flow_removed_pad2,
+            { "Pad2", "openflow.flow_removed.pad2",
+               FT_UINT16, BASE_HEX, NULL, 0x0,
+               NULL, HFILL }
+        },
+        { &hf_openflow_flow_removed_packet_count,
+            { "Packet count", "openflow.flow_removed.packet_count",
+               FT_UINT64, BASE_DEC, NULL, 0x0,
+               NULL, HFILL }
+        },
+        { &hf_openflow_flow_removed_byte_count,
+            { "Byte count", "openflow.flow_removed.byte_count",
+               FT_UINT64, BASE_DEC, NULL, 0x0,
+               NULL, HFILL }
+        },
         { &hf_openflow_table_id,
             { "Table Id", "openflow.table_id",
                FT_UINT8, BASE_DEC, NULL, 0x0,
@@ -1440,8 +1560,7 @@ proto_register_openflow_v1(void)
     expert_module_t* expert_openflow_v1;
 
     /* Register the protocol name and description */
-    proto_openflow_v1 = proto_register_protocol("OpenFlow 1.0",
-            "openflow_v1", "openflow_v1");
+    proto_openflow_v1 = proto_register_protocol("OpenFlow 1.0", "openflow_v1", "openflow_v1");
 
     register_dissector("openflow_v1", dissect_openflow_v1, proto_openflow_v1);
 
