@@ -104,9 +104,17 @@ static const fragment_items pop_data_frag_items = {
   "DATA fragments"
 };
 
+typedef enum {
+  pop_arg_type_unknown,
+  pop_arg_type_username,
+  pop_arg_type_password
+} pop_arg_type_t;
+
 struct pop_proto_data {
   guint16 conversation_id;
   gboolean more_frags;
+  gboolean ei_tot_len_invalid;
+  pop_arg_type_t arg_type;
 };
 
 struct pop_data_val {
@@ -118,12 +126,6 @@ struct pop_data_val {
   guint username_num;
 };
 
-typedef enum {
-  pop_arg_type_unknown,
-  pop_arg_type_username,
-  pop_arg_type_password
-} pop_arg_type_t;
-
 static gboolean response_is_continuation(const guchar *data);
 
 static int
@@ -140,17 +142,15 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
   int                    linelen;
   int                    tokenlen;
   const guchar           *next_token;
-  fragment_head          *frag_msg = NULL;
-  tvbuff_t               *next_tvb = NULL;
-  conversation_t         *conversation = NULL;
-  struct pop_data_val    *data_val = NULL;
+  fragment_head          *frag_msg;
+  tvbuff_t               *next_tvb;
+  conversation_t         *conversation;
+  struct pop_data_val    *data_val;
   gint                   length_remaining;
   pop_arg_type_t         pop_arg_type = pop_arg_type_unknown;
 
   col_set_str(pinfo->cinfo, COL_PROTOCOL, "POP");
 
-  frame_data_p = (struct pop_proto_data *)p_get_proto_data(wmem_file_scope(), pinfo, proto_pop, 0);
-
   conversation = find_or_create_conversation(pinfo);
   data_val = (struct pop_data_val *)conversation_get_proto_data(conversation, proto_pop);
   if (!data_val) {
@@ -201,16 +201,19 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 
     if (pop_data_desegment) {
 
-      if (!frame_data_p) {
+      if (!PINFO_FD_VISITED(pinfo)) {
 
         data_val->msg_read_len += tvb_reported_length(tvb);
 
-        frame_data_p = wmem_new(wmem_file_scope(), struct pop_proto_data);
+        frame_data_p = wmem_new0(wmem_file_scope(), struct pop_proto_data);
 
         frame_data_p->conversation_id = conversation->conv_index;
         frame_data_p->more_frags = data_val->msg_read_len < data_val->msg_tot_len;
 
         p_add_proto_data(wmem_file_scope(), pinfo, proto_pop, 0, frame_data_p);
+      } else {
+          frame_data_p = (struct pop_proto_data *)p_get_proto_data(wmem_file_scope(), pinfo, proto_pop, 0);
+          DISSECTOR_ASSERT(frame_data_p);
       }
 
       frag_msg = fragment_add_seq_next(&pop_data_reassembly_table, tvb, 0,
@@ -230,7 +233,7 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
         if (imf_handle)
           call_dissector(imf_handle, next_tvb, pinfo, tree);
 
-        if (data_val) {
+        if (!PINFO_FD_VISITED(pinfo)) {
           /* we have read everything - reset */
 
           data_val->msg_read_len = 0;
@@ -262,7 +265,7 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
                                     tvb, offset,
                                     next_offset - offset,
                                     "", "%s",
-                                    tvb_format_text(tvb, offset, next_offset - offset));
+                                    tvb_format_text(pinfo->pool, tvb, offset, next_offset - offset));
   reqresp_tree = proto_item_add_subtree(ti, ett_pop_reqresp);
 
   /*
@@ -277,7 +280,7 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
                             hf_pop_response_indicator,
                         tvb, offset, tokenlen, ENC_ASCII|ENC_NA);
 
-    if (data_val) {
+    if (!PINFO_FD_VISITED(pinfo)) {
       if (is_request) {
         /* see if this is RETR or TOP command */
         if (g_ascii_strncasecmp(line, "RETR", 4) == 0 ||
@@ -296,6 +299,13 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
         if (g_ascii_strncasecmp(line, "PASS", 4) == 0) {
           pop_arg_type = pop_arg_type_password;
         }
+
+        if (pop_arg_type != pop_arg_type_unknown) {
+          /* store info for subsequent pass */
+          frame_data_p = wmem_new0(wmem_file_scope(), struct pop_proto_data);
+          frame_data_p->arg_type = pop_arg_type;
+          p_add_proto_data(wmem_file_scope(), pinfo, proto_pop, 0, frame_data_p);
+        }
       } else {
         if (data_val->msg_request) {
           /* this is a response to a RETR or TOP command */
@@ -304,8 +314,13 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
             /* the message will be sent - work out how many bytes */
             data_val->msg_read_len = 0;
             data_val->msg_tot_len = 0;
-            if (sscanf(line, "%*s %u %*s", &data_val->msg_tot_len) != 1)
+            if (sscanf(line, "%*s %u %*s", &data_val->msg_tot_len) != 1) {
               expert_add_info(pinfo, ti, &ei_pop_resp_tot_len_invalid);
+              /* store expect info presence to add it to the tree during subsequent pass */
+              frame_data_p = wmem_new0(wmem_file_scope(), struct pop_proto_data);
+              frame_data_p->ei_tot_len_invalid = TRUE;
+              p_add_proto_data(wmem_file_scope(), pinfo, proto_pop, 0, frame_data_p);
+            }
           }
           data_val->msg_request = FALSE;
         }
@@ -318,6 +333,13 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
           data_val->stls_request = FALSE;
         }
       }
+    } else {
+      frame_data_p = (struct pop_proto_data *)p_get_proto_data(wmem_file_scope(), pinfo, proto_pop, 0);
+      if (frame_data_p) {
+        pop_arg_type = frame_data_p->arg_type;
+        if (frame_data_p->ei_tot_len_invalid)
+          expert_add_info(pinfo, ti, &ei_pop_resp_tot_len_invalid);
+      }
     }
 
     offset += (gint) (next_token - line);
@@ -379,7 +401,7 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
                                  tvb, offset,
                                  next_offset - offset,
                                  "", "%s",
-                                 tvb_format_text(tvb, offset, next_offset - offset));
+                                 tvb_format_text(pinfo->pool, tvb, offset, next_offset - offset));
     offset = next_offset;
   }
   return tvb_captured_length(tvb);
