@@ -127,8 +127,8 @@ static const value_string names_colors[] = {
 	{ 11, "Green" },
 	{ 12, "Yellow" },
 	{ 13, "Blue" },
-	{ 14, "Blue" },
-	{ 15, "Blue" },
+	{ 14, "Fire" },
+	{ 15, "Brights" },
 	{  0, NULL }
 };
 
@@ -177,7 +177,7 @@ dissect_quake_CCREQ_RULE_INFO
 (tvbuff_t *tvb, proto_tree *tree)
 {
 	proto_tree_add_item(tree, hf_quake_CCREQ_RULE_INFO_lastrule,
-			tvb, 0, -1, ENC_ASCII|ENC_NA);
+			tvb, 0, -1, ENC_ASCII);
 }
 
 
@@ -202,7 +202,7 @@ dissect_quake_CCREP_REJECT
 (tvbuff_t *tvb, proto_tree *tree)
 {
 	proto_tree_add_item(tree, hf_quake_CCREP_REJECT_reason,
-			tvb, 0, -1, ENC_ASCII|ENC_NA);
+			tvb, 0, -1, ENC_ASCII);
 }
 
 
@@ -283,7 +283,7 @@ dissect_quake_CCREP_PLAYER_INFO
 	offset += 4;
 
 	proto_tree_add_item(tree, hf_quake_CCREP_PLAYER_INFO_address,
-			tvb, offset, -1, ENC_ASCII|ENC_NA);
+			tvb, offset, -1, ENC_ASCII);
 }
 
 
@@ -301,7 +301,7 @@ dissect_quake_CCREP_RULE_INFO
 	offset += item_len;
 
 	proto_tree_add_item(tree, hf_quake_CCREP_RULE_INFO_value,
-			tvb, offset, -1, ENC_ASCII|ENC_NA);
+			tvb, offset, -1, ENC_ASCII);
 }
 
 
@@ -386,28 +386,28 @@ dissect_quake(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "QUAKE");
 	col_clear(pinfo->cinfo, COL_INFO);
 
-	flags = tvb_get_ntohs(tvb, 2);
+	flags = tvb_get_ntohs(tvb, 0);
 
 	quake_item = proto_tree_add_item(tree, proto_quake, tvb, 0, -1, ENC_NA);
 	quake_tree = proto_item_add_subtree(quake_item, ett_quake);
 
 	flags_item = proto_tree_add_item(quake_tree, hf_quake_header_flags,
-			tvb, 2, 2, ENC_BIG_ENDIAN);
+			tvb, 0, 2, ENC_BIG_ENDIAN);
 	flags_tree = proto_item_add_subtree(flags_item, ett_quake_flags);
 	proto_tree_add_item(flags_tree, hf_quake_header_flags_data,
-			tvb, 2, 2, ENC_BIG_ENDIAN);
+			tvb, 0, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(flags_tree, hf_quake_header_flags_ack,
-			tvb, 2, 2, ENC_BIG_ENDIAN);
+			tvb, 0, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(flags_tree, hf_quake_header_flags_no_ack,
-			tvb, 2, 2, ENC_BIG_ENDIAN);
+			tvb, 0, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(flags_tree, hf_quake_header_flags_endmsg,
-			tvb, 2, 2, ENC_BIG_ENDIAN);
+			tvb, 0, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(flags_tree, hf_quake_header_flags_unreliable,
-			tvb, 2, 2, ENC_BIG_ENDIAN);
+			tvb, 0, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(flags_tree, hf_quake_header_flags_control,
-			tvb, 2, 2, ENC_BIG_ENDIAN);
+			tvb, 0, 2, ENC_BIG_ENDIAN);
 
-	proto_tree_add_item(quake_tree, hf_quake_header_length, tvb, 0, 2, ENC_BIG_ENDIAN);
+	proto_tree_add_item(quake_tree, hf_quake_header_length, tvb, 2, 2, ENC_BIG_ENDIAN);
 
 	if (flags == NETFLAG_CTL) {
 		next_tvb = tvb_new_subset_remaining(tvb, 4);
@@ -571,13 +571,14 @@ proto_register_quake(void)
 	proto_quake = proto_register_protocol("Quake Network Protocol", "QUAKE", "quake");
 	proto_register_field_array(proto_quake, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+
+	quake_handle = register_dissector("quake", dissect_quake, proto_quake);
 }
 
 
 void
 proto_reg_handoff_quake(void)
 {
-	quake_handle = create_dissector_handle(dissect_quake, proto_quake);
 	dissector_add_uint_with_preference("udp.port", DEFAULTnet_hostport, quake_handle);
 }
 
