@@ -74,6 +74,7 @@ static const value_string ltype_vals[] = {
 	{ LINUX_SLL_P_IRDA_LAP,	"IrDA LAP" },
 	{ LINUX_SLL_P_ISI,	"ISI" },
 	{ LINUX_SLL_P_IEEE802154,	"IEEE 802.15.4" },
+	{ LINUX_SLL_P_MCTP,	"MCTP" },
 	{ 0,			NULL }
 };
 
@@ -144,39 +145,39 @@ sll_conversation_packet(void *pct, packet_info *pinfo, epan_dissect_t *edt _U_,
 
 	const sll_tap_data *tap_data = (const sll_tap_data*)vip;
 
-	add_conversation_table_data(hash, &tap_data->src_address, &no_dst, 0, 0, 1, pinfo->fd->pkt_len, &pinfo->rel_ts, &pinfo->abs_ts, &sll_ct_dissector_info, ENDPOINT_NONE);
+	add_conversation_table_data(hash, &tap_data->src_address, &no_dst, 0, 0, 1, pinfo->fd->pkt_len, &pinfo->rel_ts, &pinfo->abs_ts, &sll_ct_dissector_info, CONVERSATION_NONE);
 
 	return TAP_PACKET_REDRAW;
 }
 
-static const char* sll_host_get_filter_type(hostlist_talker_t* host, conv_filter_type_e filter)
+static const char* sll_endpoint_get_filter_type(endpoint_item_t* endpoint, conv_filter_type_e filter)
 {
-	if ((filter == CONV_FT_SRC_ADDRESS) && (host->myaddress.type == AT_ETHER))
+	if ((filter == CONV_FT_SRC_ADDRESS) && (endpoint->myaddress.type == AT_ETHER))
 		return "sll.src.eth";
 
-	if ((filter == CONV_FT_ANY_ADDRESS) && (host->myaddress.type == AT_ETHER))
+	if ((filter == CONV_FT_ANY_ADDRESS) && (endpoint->myaddress.type == AT_ETHER))
 		return "sll.src.eth";
 
-	if ((filter == CONV_FT_SRC_ADDRESS) && (host->myaddress.type == AT_IPv4))
+	if ((filter == CONV_FT_SRC_ADDRESS) && (endpoint->myaddress.type == AT_IPv4))
 		return "sll.src.ipv4";
 
-	if ((filter == CONV_FT_ANY_ADDRESS) && (host->myaddress.type == AT_IPv4))
+	if ((filter == CONV_FT_ANY_ADDRESS) && (endpoint->myaddress.type == AT_IPv4))
 		return "sll.src.ipv4";
 
 	return CONV_FILTER_INVALID;
 }
 
-static hostlist_dissector_info_t sll_host_dissector_info = {&sll_host_get_filter_type};
+static et_dissector_info_t sll_endpoint_dissector_info = {&sll_endpoint_get_filter_type};
 
 static tap_packet_status
-sll_hostlist_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, const void *vip, tap_flags_t flags)
+sll_endpoint_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, const void *vip, tap_flags_t flags)
 {
 	conv_hash_t *hash = (conv_hash_t*) pit;
     hash->flags = flags;
 
 	const sll_tap_data *tap_data = (const sll_tap_data*)vip;
 
-	add_hostlist_table_data(hash, &tap_data->src_address, 0, TRUE, 1, pinfo->fd->pkt_len, &sll_host_dissector_info, ENDPOINT_NONE);
+	add_endpoint_table_data(hash, &tap_data->src_address, 0, TRUE, 1, pinfo->fd->pkt_len, &sll_endpoint_dissector_info, ENDPOINT_NONE);
 
 	return TAP_PACKET_REDRAW;
 }
@@ -295,9 +296,10 @@ add_protocol_type(proto_tree *fh_tree, tvbuff_t *tvb, int protocol_offset,
 		switch (hatype) {
 
 		case ARPHRD_IPGRE:
+		case ARPHRD_IP6GRE:
 			/*
 			 * XXX - the link-layer header appears to consist
-			 * of an IPv4 header followed by a bunch of stuff
+			 * of an IP header followed by a bunch of stuff
 			 * that includes the GRE flags and version, but
 			 * cooked captures strip the link-layer header,
 			 * so we can't provide the flags and version to
@@ -344,9 +346,10 @@ dissect_payload(proto_tree *tree, packet_info *pinfo, proto_tree *fh_tree,
 		switch (hatype) {
 
 		case ARPHRD_IPGRE:
+		case ARPHRD_IP6GRE:
 			/*
 			 * XXX - the link-layer header appears to consist
-			 * of an IPv4 header followed by a bunch of stuff
+			 * of an IP header followed by a bunch of stuff
 			 * that includes the GRE flags and version, but
 			 * cooked captures strip the link-layer header,
 			 * so we can't provide the flags and version to
@@ -585,8 +588,8 @@ proto_register_sll(void)
 	proto_register_field_array(proto_sll, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
-	sll_handle = create_dissector_handle(dissect_sll_v1, proto_sll);
-	sll2_handle = create_dissector_handle(dissect_sll_v2, proto_sll);
+	sll_handle = register_dissector("sll_v1", dissect_sll_v1, proto_sll);
+	sll2_handle = register_dissector("sll_v2", dissect_sll_v2, proto_sll);
 	sll_tap = register_tap("sll");
 
 	/*
@@ -617,7 +620,7 @@ proto_register_sll(void)
 	);
 	register_capture_dissector_table("sll.ltype", "Linux SLL protocol");
 
-	register_conversation_table(proto_sll, TRUE, sll_conversation_packet, sll_hostlist_packet);
+	register_conversation_table(proto_sll, TRUE, sll_conversation_packet, sll_endpoint_packet);
 
 	register_decode_as(&sll_da);
 }
