@@ -8,19 +8,7 @@
  *
  * Copied from packet-pop.c
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -381,7 +369,7 @@ static const true_false_string tfs_os_nts = {
 static void
 dissect_election_criterion_os(tvbuff_t *tvb, proto_tree *parent_tree, int offset)
 {
-	static const int * flags[] = {
+	static int * const flags[] = {
 		&hf_election_os_wfw,
 		&hf_election_os_ntw,
 		&hf_election_os_nts,
@@ -394,7 +382,7 @@ dissect_election_criterion_os(tvbuff_t *tvb, proto_tree *parent_tree, int offset
 static void
 dissect_election_criterion_desire(tvbuff_t *tvb, proto_tree *parent_tree, int offset)
 {
-	static const int * flags[] = {
+	static int * const flags[] = {
 		&hf_election_desire_flags_backup,
 		&hf_election_desire_flags_standby,
 		&hf_election_desire_flags_master,
@@ -449,7 +437,7 @@ dissect_smb_server_type_flags(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	guint32 flags;
 	int i;
 
-	static const int * type_flags[] = {
+	static int * const type_flags[] = {
 		&hf_server_type_workstation,
 		&hf_server_type_server,
 		&hf_server_type_sql,
@@ -565,11 +553,11 @@ dissect_mailslot_browse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 		proto_tree_add_uint_format_value(tree, hf_periodicity, tvb, offset, 4,
 		    periodicity,
 		    "%s",
-		    signed_time_msecs_to_str(wmem_packet_scope(), periodicity));
+		    signed_time_msecs_to_str(pinfo->pool, periodicity));
 		offset += 4;
 
 		/* server name */
-		host_name = tvb_get_stringzpad(wmem_packet_scope(), tvb, offset, HOST_NAME_LEN, ENC_CP437|ENC_NA);
+		host_name = tvb_get_stringzpad(pinfo->pool, tvb, offset, HOST_NAME_LEN, ENC_CP437|ENC_NA);
 		col_append_fstr(pinfo->cinfo, COL_INFO, " %s", host_name);
 		proto_tree_add_string_format(tree, hf_server_name,
 			tvb, offset, HOST_NAME_LEN,
@@ -641,7 +629,7 @@ dissect_mailslot_browse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 		offset += 1;
 
 		/* name of computer to which to send reply */
-		computer_name = tvb_get_stringz_enc(wmem_packet_scope(), tvb, offset, &namelen, ENC_ASCII);
+		computer_name = tvb_get_stringz_enc(pinfo->pool, tvb, offset, &namelen, ENC_ASCII);
 		proto_tree_add_string(tree, hf_response_computer_name,
 			tvb, offset, namelen, computer_name);
 		col_append_fstr(pinfo->cinfo, COL_INFO, " %s", computer_name);
@@ -662,7 +650,7 @@ dissect_mailslot_browse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 		proto_tree_add_uint_format_value(tree, hf_server_uptime,
 		    tvb, offset, 4, uptime,
 		    "%s",
-		    signed_time_msecs_to_str(wmem_packet_scope(), uptime));
+		    signed_time_msecs_to_str(pinfo->pool, uptime));
 		offset += 4;
 
 		/* next 4 bytes must be zero */
@@ -671,7 +659,7 @@ dissect_mailslot_browse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 		/* server name */
 		namelen = tvb_strsize(tvb, offset);
 		proto_tree_add_item(tree, hf_server_name,
-			tvb, offset, namelen, ENC_ASCII|ENC_NA);
+			tvb, offset, namelen, ENC_ASCII);
 		break;
 
 	case BROWSE_BACKUP_LIST_REQUEST:
@@ -698,7 +686,7 @@ dissect_mailslot_browse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 		for (i = 0; i < server_count; i++) {
 			namelen = tvb_strsize(tvb, offset);
 			proto_tree_add_item(tree, hf_backup_server,
-				tvb, offset, namelen, ENC_ASCII|ENC_NA);
+				tvb, offset, namelen, ENC_ASCII);
 			offset += namelen;
 		}
 		break;
@@ -707,11 +695,11 @@ dissect_mailslot_browse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 		/* master browser server name */
 		namelen = tvb_strsize(tvb, offset);
 		proto_tree_add_item(tree, hf_mb_server_name,
-			tvb, offset, namelen, ENC_ASCII|ENC_NA);
+			tvb, offset, namelen, ENC_ASCII);
 		break;
 
 	case BROWSE_RESETBROWSERSTATE_ANNOUNCEMENT: {
-		static const int * flags[] = {
+		static int * const flags[] = {
 			&hf_mb_reset_demote,
 			&hf_mb_reset_flush,
 			&hf_mb_reset_stop,
@@ -726,7 +714,7 @@ dissect_mailslot_browse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 		/* name of browser to promote */
 		namelen = tvb_strsize(tvb, offset);
 		proto_tree_add_item(tree, hf_browser_to_promote,
-			tvb, offset, namelen, ENC_ASCII|ENC_NA);
+			tvb, offset, namelen, ENC_ASCII);
 		break;
 	}
 	return tvb_captured_length(tvb);
@@ -809,15 +797,15 @@ dissect_mailslot_lanman(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tr
 		proto_tree_add_uint_format_value(tree, hf_periodicity, tvb, offset, 2,
 		    periodicity,
 		    "%s",
-		    signed_time_msecs_to_str(wmem_packet_scope(), periodicity));
+		    signed_time_msecs_to_str(pinfo->pool, periodicity));
 		offset += 2;
 
 		/* server name */
-		host_name = tvb_get_stringz_enc(wmem_packet_scope(), tvb, offset, &namelen, ENC_CP437|ENC_NA);
+		host_name = tvb_get_stringz_enc(pinfo->pool, tvb, offset, &namelen, ENC_CP437|ENC_NA);
 		col_append_fstr(pinfo->cinfo, COL_INFO, " %s", host_name);
 
 		proto_tree_add_item(tree, hf_server_name,
-			tvb, offset, namelen, ENC_ASCII|ENC_NA);
+			tvb, offset, namelen, ENC_ASCII);
 		offset += namelen;
 
 		/* master browser server name or server comment */
@@ -1113,7 +1101,7 @@ proto_register_smb_browse(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
