@@ -14,10 +14,14 @@
 #include "ws_symbol_export.h"
 #include <epan/packet.h>
 
-/** Maps Session-ID to pre-master secrets. */
-WS_DLL_PUBLIC GHashTable *ssl_session_hash;
-/** Maps Client Random to pre-master secrets. */
-WS_DLL_PUBLIC GHashTable *ssl_crandom_hash;
+struct tlsinfo {
+        guint32 seq; /* The sequence number within the TLS stream. */
+        gboolean is_reassembled;
+        gboolean end_of_stream; /* TCP FIN, close_notify, etc. */
+        /* The app handle for the session, set by heuristic dissectors
+         * to be called in the future. */
+        dissector_handle_t *app_handle;
+};
 
 WS_DLL_PUBLIC void ssl_dissector_add(guint port, dissector_handle_t handle);
 WS_DLL_PUBLIC void ssl_dissector_delete(guint port, dissector_handle_t handle);
@@ -46,7 +50,7 @@ tls13_exporter(packet_info *pinfo, gboolean is_early,
                guint context_length, guint key_length, guchar **out);
 
 gint
-tls13_get_quic_secret(packet_info *pinfo, gboolean is_from_server, int type, guint secret_len, guint8 *secret_out);
+tls13_get_quic_secret(packet_info *pinfo, gboolean is_from_server, int type, guint secret_min_len, guint secret_max_len, guint8 *secret_out);
 
 /**
  * Returns the application-layer protocol name (ALPN) for the current TLS
