@@ -31,6 +31,8 @@
 void proto_register_wsmp(void);
 void proto_reg_handoff_wsmp(void);
 
+static dissector_handle_t wsmp_handle;
+
 static const value_string wsmp_elemenid_names[] = {
     { 0x80, "WSMP" },
     { 0x81, "WSMP-S" },
@@ -69,6 +71,7 @@ static int ett_wsmp_ie_ext = -1;
 static int ett_wsmp_ie = -1;
 
 static expert_field ei_wsmp_length_field_err = EI_INIT;
+static expert_field ei_wsmp_psid_invalid = EI_INIT;
 
 dissector_handle_t IEEE1609dot2_handle;
 
@@ -138,7 +141,8 @@ dissect_wsmp_psid(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, int o
     *psid = 0;
 
     if ((oct & 0xF0) == 0xF0) {
-        psidLen = 255;
+        proto_tree_add_expert(tree, pinfo, &ei_wsmp_psid_invalid, tvb, offset, 1);
+        return offset + 1;
     } else if ((oct & 0xF0) == 0xE0) {
         psidLen = 4;
     } else if ((oct & 0xE0) == 0xC0) {
@@ -160,7 +164,7 @@ dissect_wsmp_psid(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, int o
 
     proto_tree_add_bits_item(tree, hf_wsmp_var_len_det, tvb, offset << 3, psidLen, ENC_NA);
     proto_tree_add_uint_bits_format_value(tree, hf_wsmp_psid, tvb, (offset << 3) + psidLen,
-            (psidLen << 3) - psidLen,*psid,"%s(%u)", val64_to_str_const(*psid, ieee1609dot2_Psid_vals, "Unknown"), *psid);
+            (psidLen << 3) - psidLen,*psid,ENC_BIG_ENDIAN,"%s(%u)", val64_to_str_const(*psid, ieee1609dot2_Psid_vals, "Unknown"), *psid);
     offset += psidLen;
 
     return offset;
@@ -213,12 +217,12 @@ dissect_wsmp_v3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 oct)
     proto_tree *sub_tree, *n_tree, *t_tree, *data_tree;
     proto_item *item;
     int offset = 0, ie_start, len_to_set;
-    guint8 header_opt_ind = oct & 0x08 >> 3;
+    guint8 header_opt_ind = (oct & 0x08) >> 3;
     guint8 ie;
     guint16 count, ie_len, wsm_len;
     guint32 tpid, psid = 0;
 
-    static const int * flags[] = {
+    static int * const flags[] = {
         &hf_wsmp_subtype,
         &hf_wsmp_N_header_opt_ind,
         &hf_wsmp_version_v3,
@@ -399,7 +403,7 @@ dissect_wsmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
     wsmdata_tree = proto_tree_add_subtree(wsmp_tree, tvb, offset, wsmlength,
                                         ett_wsmdata, NULL, "Wave Short Message");
 
-    wsmdata_tvb  = tvb_new_subset_length_caplen(tvb, offset, -1, wsmlength);
+    wsmdata_tvb  = tvb_new_subset_length(tvb, offset, wsmlength);
 
     /* TODO: Branch on the application context and display accordingly
      * Default: call the data dissector
@@ -499,6 +503,7 @@ proto_register_wsmp(void)
     static ei_register_info ei[] = {
     { &ei_wsmp_length_field_err, { "wsmp.length_field_err", PI_PROTOCOL, PI_ERROR,
         "Length field wrongly encoded, b6 not 0. The rest of the dissection is suspect", EXPFILL }},
+    { &ei_wsmp_psid_invalid, { "wsmp.psid.invalid", PI_PROTOCOL, PI_ERROR, "Invalid PSID", EXPFILL }},
     };
 
     expert_module_t* expert_wsmp;
@@ -513,21 +518,20 @@ proto_register_wsmp(void)
     expert_wsmp = expert_register_protocol(proto_wsmp);
     expert_register_field_array(expert_wsmp, ei, array_length(ei));
 
+    /* Register the dissector handle */
+    wsmp_handle = register_dissector("wsmp", dissect_wsmp, proto_wsmp);
 }
 
 void
 proto_reg_handoff_wsmp(void)
 {
-    dissector_handle_t wsmp_handle;
-
-    wsmp_handle = create_dissector_handle(dissect_wsmp, proto_wsmp);
     dissector_add_uint("ethertype", ETHERTYPE_WSMP, wsmp_handle);
 
     IEEE1609dot2_handle = find_dissector_add_dependency("ieee1609dot2.data", proto_wsmp);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
