@@ -1119,6 +1119,7 @@ static gchar *fully_qualified_name(GPtrArray *hier, gchar *name, gchar *proto_na
 }
 
 
+// NOLINTNEXTLINE(misc-no-recursion)
 static xml_ns_t *make_xml_hier(gchar      *elem_name,
                                xml_ns_t   *root,
                                wmem_map_t *elements,
@@ -1136,7 +1137,7 @@ static xml_ns_t *make_xml_hier(gchar      *elem_name,
     guint     i;
     struct _attr_reg_data  d;
 
-    if ( g_str_equal(elem_name, root->name) ) {
+    if ( !elem_name || g_str_equal(elem_name, root->name) ) {
         return NULL;
     }
 
@@ -1145,6 +1146,11 @@ static xml_ns_t *make_xml_hier(gchar      *elem_name,
         return NULL;
     }
 
+    if (hier->len >= prefs.gui_max_tree_depth) {
+        g_string_append_printf(error, "hierarchy too deep: %u\n", hier->len);
+        return NULL;
+    }
+
     for (i = 0; i < hier->len; i++) {
         if( (elem_name) && (strcmp(elem_name, (gchar *) g_ptr_array_index(hier, i) ) == 0 )) {
             recurred = TRUE;
