@@ -89,6 +89,10 @@
 #include <nghttp2/nghttp2.h>
 #endif
 
+#ifdef HAVE_NGHTTP3
+#include <nghttp3/nghttp3.h>
+#endif
+
 #ifdef HAVE_BROTLI
 #include <brotli/decode.h>
 #endif
@@ -278,6 +282,15 @@ epan_init(register_cb cb, gpointer client_data, gboolean load_plugins)
 	}
 
 	/* initialize libgcrypt (beware, it won't be thread-safe) */
+#if GCRYPT_VERSION_NUMBER >= 0x010a00
+	/* Ensure FIPS mode is disabled; it makes it impossible to decrypt
+	 * non-NIST approved algorithms. We're decrypting, not promising
+	 * security. This overrides any file or environment variables that
+	 * would normally turn on FIPS mode, and has to be done prior to
+	 * gcry_check_version().
+	 */
+	gcry_control (GCRYCTL_NO_FIPS_MODE);
+#endif
 	gcry_check_version(NULL);
 #if defined(_WIN32)
 	gcry_set_log_handler (quiet_gcrypt_logger, NULL);
@@ -286,6 +299,11 @@ epan_init(register_cb cb, gpointer client_data, gboolean load_plugins)
 	gcry_control (GCRYCTL_INITIALIZATION_FINISHED, 0);
 #ifdef HAVE_LIBGNUTLS
 	gnutls_global_init();
+#if GNUTLS_VERSION_NUMBER >= 0x030602
+	if (gnutls_fips140_mode_enabled()) {
+		gnutls_fips140_set_mode(GNUTLS_FIPS140_LAX, 0);
+	}
+#endif
 #endif
 #ifdef HAVE_LIBXML2
 	xmlInitParser();
@@ -426,17 +444,17 @@ epan_cleanup(void)
 	except_deinit();
 	addr_resolv_cleanup();
 
-#ifdef HAVE_PLUGINS
-	plugins_cleanup(libwireshark_plugins);
-	libwireshark_plugins = NULL;
-#endif
-
 	if (pinfo_pool_cache != NULL) {
 		wmem_destroy_allocator(pinfo_pool_cache);
 		pinfo_pool_cache = NULL;
 	}
 
 	wmem_cleanup_scopes();
+
+#ifdef HAVE_PLUGINS
+	plugins_cleanup(libwireshark_plugins);
+	libwireshark_plugins = NULL;
+#endif
 }
 
 struct epan_session {
@@ -494,8 +512,10 @@ epan_get_frame_ts(const epan_t *session, guint32 frame_num)
 	if (session && session->funcs.get_frame_ts)
 		abs_ts = session->funcs.get_frame_ts(session->prov, frame_num);
 
-	if (!abs_ts)
-		ws_warning("!!! couldn't get frame ts for %u !!!\n", frame_num);
+	if (!abs_ts) {
+		/* This can happen if frame_num doesn't have a ts */
+		ws_debug("!!! couldn't get frame ts for %u !!!\n", frame_num);
+	}
 
 	return abs_ts;
 }
@@ -827,6 +847,13 @@ epan_gather_compile_info(feature_list l)
 	without_feature(l, "nghttp2");
 #endif /* HAVE_NGHTTP2 */
 
+	/* nghttp3 */
+#ifdef HAVE_NGHTTP3
+	with_feature(l, "nghttp3 %s", NGHTTP3_VERSION);
+#else
+	without_feature(l, "nghttp3");
+#endif /* HAVE_NGHTTP3 */
+
 	/* brotli */
 #ifdef HAVE_BROTLI
 	with_feature(l, "brotli");
@@ -896,6 +923,12 @@ epan_gather_runtime_info(feature_list l)
 	with_feature(l, "nghttp2 %s",  nghttp2_ptr->version_str);
 #endif /* NGHTTP2_VERSION_AGE */
 
+	/* nghttp3 */
+#if NGHTTP3_VERSION_AGE >= 1
+	const nghttp3_info *nghttp3_ptr = nghttp3_version(0);
+	with_feature(l, "nghttp3 %s", nghttp3_ptr->version_str);
+#endif /* NGHTTP3_VERSION_AGE */
+
 	/* brotli */
 #ifdef HAVE_BROTLI
 	with_feature(l, "brotli %d.%d.%d", BrotliDecoderVersion() >> 24,
