@@ -24,12 +24,6 @@
 extern "C" {
 #endif /* __cplusplus */
 
-typedef enum {
-  TCP_STREAM = 0,
-  UDP_STREAM,
-  MAX_STREAM
-} stream_type;
-
 typedef enum {
     FRS_OK,
     FRS_OPEN_ERROR,
@@ -37,30 +31,6 @@ typedef enum {
     FRS_PRINT_ERROR
 } frs_return_t;
 
-/* Type of follow we are doing */
-typedef enum {
-    FOLLOW_TCP,
-    FOLLOW_TLS,
-    FOLLOW_UDP,
-    FOLLOW_DCCP,
-    FOLLOW_HTTP,
-    FOLLOW_HTTP2,
-    FOLLOW_QUIC,
-    FOLLOW_SIP,
-} follow_type_t;
-
-/* Show Type */
-typedef enum {
-    SHOW_ASCII,
-    SHOW_CARRAY,
-    SHOW_EBCDIC,
-    SHOW_HEXDUMP,
-    SHOW_RAW,
-    SHOW_CODEC, // Ordered to match UTF-8 combobox index
-    SHOW_YAML
-} show_type_t;
-
-
 /* Show Stream */
 typedef enum {
     FROM_CLIENT,
@@ -76,7 +46,6 @@ typedef union _stream_addr {
 struct _follow_info;
 
 typedef gboolean (*follow_print_line_func)(char *, size_t, gboolean, void *);
-typedef frs_return_t (*follow_read_stream_func)(struct _follow_info *follow_info, follow_print_line_func follow_print, void *arg);
 
 #define SUBSTREAM_UNUSED	G_GUINT64_CONSTANT(0xFFFFFFFFFFFFFFFF)
 
@@ -110,11 +79,14 @@ typedef gchar* (*follow_conv_filter_func)(epan_dissect_t *edt, packet_info *pinf
 typedef gchar* (*follow_index_filter_func)(guint stream, guint sub_stream);
 typedef gchar* (*follow_address_filter_func)(address* src_addr, address* dst_addr, int src_port, int dst_port);
 typedef gchar* (*follow_port_to_display_func)(wmem_allocator_t *allocator, guint port);
+typedef guint32 (*follow_stream_count_func)(void);
+typedef gboolean (*follow_sub_stream_id_func)(guint stream, guint sub_stream, gboolean le, guint *sub_stream_out);
 
 WS_DLL_PUBLIC
 void register_follow_stream(const int proto_id, const char* tap_listener,
                             follow_conv_filter_func conv_filter, follow_index_filter_func index_filter, follow_address_filter_func address_filter,
-                            follow_port_to_display_func port_to_display, tap_packet_cb tap_handler);
+                            follow_port_to_display_func port_to_display, tap_packet_cb tap_handler,
+                            follow_stream_count_func stream_count, follow_sub_stream_id_func sub_stream_id);
 
 /** Get protocol ID from registered follower
  *
@@ -137,6 +109,13 @@ WS_DLL_PUBLIC const char* get_follow_tap_string(register_follow_t* follower);
  */
 WS_DLL_PUBLIC register_follow_t* get_follow_by_name(const char* proto_short_name);
 
+/** Get a registered follower by protocol id
+ *
+ * @param proto_id Protocol Id
+ * @return tap registered follower if match, otherwise NULL
+ */
+WS_DLL_PUBLIC register_follow_t* get_follow_by_proto_id(const int proto_id);
+
 /** Provide function that builds a follow filter based on the current packet's conversation.
  *
  * @param follower [in] Registered follower
@@ -172,12 +151,32 @@ WS_DLL_PUBLIC follow_port_to_display_func get_follow_port_to_display(register_fo
  */
 WS_DLL_PUBLIC tap_packet_cb get_follow_tap_handler(register_follow_t* follower);
 
+/** Provide function that gets the total number of streams for a registered follower
+ * The function can be NULL if the follower does not count the number of streams
+ *
+ * @param follower [in] Registered follower
+ * @return A stream count handler
+ */
+WS_DLL_PUBLIC follow_stream_count_func get_follow_stream_count_func(register_follow_t* follower);
+
+/** Provide function that, for given stream and sub stream ids, searches for
+ * the first sub stream id less than or equal (or greater than or equal) the
+ * given sub stream id present on the given stream id. Returns TRUE and the
+ * sub stream id found, or FALSE.
+ * This is used by the GUI to select valid sub stream numbers, e.g. when
+ * incrementing or decrementing the sub stream ID widget.
+ * This function should be NULL if the follower does not have sub streams.
+ *
+ * @param follower [in] Registered follower
+ * @return A sub stream id function handler
+ */
+WS_DLL_PUBLIC follow_sub_stream_id_func get_follow_sub_stream_id_func(register_follow_t* follower);
 
 /** Tap function handler when dissector's tap provides follow data as a tvb.
  * Used by TCP, UDP and HTTP followers
  */
 WS_DLL_PUBLIC tap_packet_status
-follow_tvb_tap_listener(void *tapdata, packet_info *pinfo, epan_dissect_t *edt _U_, const void *data);
+follow_tvb_tap_listener(void *tapdata, packet_info *pinfo, epan_dissect_t *edt _U_, const void *data, tap_flags_t flags);
 
 /** Interator to walk all registered followers and execute func
  *
