@@ -18,11 +18,11 @@ struct _fvalue_t {
 	ftype_t	*ftype;
 	union {
 		/* Put a few basic types in here */
-		guint32			uinteger;
-		gint32			sinteger;
-		guint64			uinteger64;
-		gint64			sinteger64;
-		gdouble			floating;
+		uint32_t		uinteger;
+		int32_t			sinteger;
+		uint64_t		uinteger64;
+		int64_t			sinteger64;
+		double			floating;
 		wmem_strbuf_t		*strbuf;
 		GBytes			*bytes;
 		ipv4_addr_and_mask	ipv4;
@@ -30,8 +30,8 @@ struct _fvalue_t {
 		e_guid_t		guid;
 		nstime_t		time;
 		protocol_value_t 	protocol;
-		guint16			sfloat_ieee_11073;
-		guint32			float_ieee_11073;
+		uint16_t		sfloat_ieee_11073;
+		uint32_t		float_ieee_11073;
 	} value;
 };
 
@@ -47,24 +47,24 @@ typedef void (*FvalueNewFunc)(fvalue_t*);
 typedef void (*FvalueCopyFunc)(fvalue_t*, const fvalue_t*);
 typedef void (*FvalueFreeFunc)(fvalue_t*);
 
-typedef gboolean (*FvalueFromLiteral)(fvalue_t*, const char*, gboolean, gchar **);
-typedef gboolean (*FvalueFromString)(fvalue_t*, const char*, size_t, gchar **);
-typedef gboolean (*FvalueFromCharConst)(fvalue_t*, unsigned long, gchar **);
+typedef bool (*FvalueFromLiteral)(fvalue_t*, const char*, bool, char **);
+typedef bool (*FvalueFromString)(fvalue_t*, const char*, size_t, char **);
+typedef bool (*FvalueFromCharConst)(fvalue_t*, unsigned long, char **);
 typedef char *(*FvalueToStringRepr)(wmem_allocator_t *, const fvalue_t*, ftrepr_t, int field_display);
 
-typedef enum ft_result (*FvalueToUnsignedInteger64Func)(const fvalue_t*, guint64 *);
-typedef enum ft_result (*FvalueToSignedInteger64Func)(const fvalue_t*, gint64 *);
+typedef enum ft_result (*FvalueToUnsignedInteger64Func)(const fvalue_t*, uint64_t *);
+typedef enum ft_result (*FvalueToSignedInteger64Func)(const fvalue_t*, int64_t *);
 
 typedef void (*FvalueSetBytesFunc)(fvalue_t*, GBytes *);
 typedef void (*FvalueSetGuidFunc)(fvalue_t*, const e_guid_t *);
 typedef void (*FvalueSetTimeFunc)(fvalue_t*, const nstime_t *);
 typedef void (*FvalueSetStrbufFunc)(fvalue_t*, wmem_strbuf_t *);
-typedef void (*FvalueSetProtocolFunc)(fvalue_t*, tvbuff_t *value, const gchar *name, int length);
-typedef void (*FvalueSetUnsignedIntegerFunc)(fvalue_t*, guint32);
-typedef void (*FvalueSetSignedIntegerFunc)(fvalue_t*, gint32);
-typedef void (*FvalueSetUnsignedInteger64Func)(fvalue_t*, guint64);
-typedef void (*FvalueSetSignedInteger64Func)(fvalue_t*, gint64);
-typedef void (*FvalueSetFloatingFunc)(fvalue_t*, gdouble);
+typedef void (*FvalueSetProtocolFunc)(fvalue_t*, tvbuff_t *value, const char *name, int length);
+typedef void (*FvalueSetUnsignedIntegerFunc)(fvalue_t*, uint32_t);
+typedef void (*FvalueSetSignedIntegerFunc)(fvalue_t*, int32_t);
+typedef void (*FvalueSetUnsignedInteger64Func)(fvalue_t*, uint64_t);
+typedef void (*FvalueSetSignedInteger64Func)(fvalue_t*, int64_t);
+typedef void (*FvalueSetFloatingFunc)(fvalue_t*, double);
 typedef void (*FvalueSetIpv6)(fvalue_t*, const ws_in6_addr *);
 
 typedef GBytes *(*FvalueGetBytesFunc)(fvalue_t*);
@@ -72,23 +72,23 @@ typedef const e_guid_t *(*FvalueGetGuidFunc)(fvalue_t*);
 typedef const nstime_t *(*FvalueGetTimeFunc)(fvalue_t*);
 typedef const wmem_strbuf_t *(*FvalueGetStrbufFunc)(fvalue_t*);
 typedef tvbuff_t *(*FvalueGetProtocolFunc)(fvalue_t*);
-typedef guint32 (*FvalueGetUnsignedIntegerFunc)(fvalue_t*);
-typedef gint32  (*FvalueGetSignedIntegerFunc)(fvalue_t*);
-typedef guint64 (*FvalueGetUnsignedInteger64Func)(fvalue_t*);
-typedef gint64 (*FvalueGetSignedInteger64Func)(fvalue_t*);
+typedef uint32_t (*FvalueGetUnsignedIntegerFunc)(fvalue_t*);
+typedef int32_t (*FvalueGetSignedIntegerFunc)(fvalue_t*);
+typedef uint64_t (*FvalueGetUnsignedInteger64Func)(fvalue_t*);
+typedef int64_t (*FvalueGetSignedInteger64Func)(fvalue_t*);
 typedef double (*FvalueGetFloatingFunc)(fvalue_t*);
 typedef const ws_in6_addr *(*FvalueGetIpv6)(fvalue_t*);
 
 typedef enum ft_result (*FvalueCmp)(const fvalue_t*, const fvalue_t*, int*);
-typedef enum ft_result (*FvalueContains)(const fvalue_t*, const fvalue_t*, gboolean*);
-typedef enum ft_result (*FvalueMatches)(const fvalue_t*, const ws_regex_t*, gboolean*);
+typedef enum ft_result (*FvalueContains)(const fvalue_t*, const fvalue_t*, bool*);
+typedef enum ft_result (*FvalueMatches)(const fvalue_t*, const ws_regex_t*, bool*);
 
-typedef gboolean (*FvalueIs)(const fvalue_t*);
-typedef guint (*FvalueLen)(fvalue_t*);
-typedef guint (*FvalueHashFunc)(const fvalue_t *);
-typedef void (*FvalueSlice)(fvalue_t*, void *, guint offset, guint length);
-typedef enum ft_result (*FvalueUnaryOp)(fvalue_t *, const fvalue_t*, gchar **);
-typedef enum ft_result (*FvalueBinaryOp)(fvalue_t *, const fvalue_t*, const fvalue_t*, gchar **);
+typedef bool (*FvalueIs)(const fvalue_t*);
+typedef unsigned (*FvalueLen)(fvalue_t*);
+typedef unsigned (*FvalueHashFunc)(const fvalue_t *);
+typedef void (*FvalueSlice)(fvalue_t*, void *, unsigned offset, unsigned length);
+typedef enum ft_result (*FvalueUnaryOp)(fvalue_t *, const fvalue_t*, char **);
+typedef enum ft_result (*FvalueBinaryOp)(fvalue_t *, const fvalue_t*, const fvalue_t*, char **);
 
 struct _ftype_t {
 	ftenum_t		ftype;
@@ -180,14 +180,14 @@ void ftype_register_pseudofields_time(int proto);
 void ftype_register_pseudofields_tvbuff(int proto);
 
 GByteArray *
-byte_array_from_literal(const char *s, gchar **err_msg);
+byte_array_from_literal(const char *s, char **err_msg);
 
 GByteArray *
-byte_array_from_charconst(unsigned long num, gchar **err_msg);
+byte_array_from_charconst(unsigned long num, char **err_msg);
 
 char *
 bytes_to_dfilter_repr(wmem_allocator_t *scope,
-			const guint8 *src, size_t src_size);
+			const uint8_t *src, size_t src_size);
 
 #endif /* FTYPES_INT_H */
 
