@@ -91,7 +91,7 @@ static void proto_tree_write_node_ek(proto_node *node, write_json_data *data);
 static const guint8 *get_field_data(GSList *src_list, field_info *fi);
 static void pdml_write_field_hex_value(write_pdml_data *pdata, field_info *fi);
 static void json_write_field_hex_value(write_json_data *pdata, field_info *fi);
-static gboolean print_hex_data_buffer(print_stream_t *stream, const guchar *cp,
+static bool print_hex_data_buffer(print_stream_t *stream, const guchar *cp,
                                       guint length, packet_char_enc encoding,
                                       guint hexdump_options);
 static void write_specified_fields(fields_format format,
@@ -137,7 +137,7 @@ void print_cache_field_handles(void)
 }
 
 gboolean
-proto_tree_print(print_dissections_e print_dissections, gboolean print_hex,
+proto_tree_print(print_dissections_e print_dissections, bool print_hex,
                  epan_dissect_t *edt, GHashTable *output_only_tables,
                  print_stream_t *stream)
 {
@@ -355,7 +355,7 @@ write_pdml_proto_tree(output_fields_t* fields, epan_dissect_t *edt, column_info
 
 void
 write_ek_proto_tree(output_fields_t* fields,
-                    gboolean print_summary, gboolean print_hex,
+                    bool print_summary, bool print_hex,
                     epan_dissect_t *edt,
                     column_info *cinfo,
                     FILE *fh)
@@ -737,7 +737,7 @@ write_json_index(json_dumper *dumper, epan_dissect_t *edt)
 void
 write_json_proto_tree(output_fields_t* fields,
                       print_dissections_e print_dissections,
-                      gboolean print_hex,
+                      bool print_hex,
                       epan_dissect_t *edt, column_info *cinfo,
                       proto_node_children_grouper_func node_children_grouper,
                       json_dumper *dumper)
@@ -821,7 +821,7 @@ write_json_proto_node_list(GSList *proto_node_list_head, write_json_data *pdata)
         gboolean is_filtered = pdata->filter != NULL && !check_protocolfilter(pdata->filter, json_key, &filter_flags);
 
         field_info *fi = first_value->finfo;
-        char *value_string_repr = fvalue_to_string_repr(NULL, fi->value, FTREPR_DISPLAY, fi->hfinfo->display);
+        char *value_string_repr = fvalue_to_string_repr(NULL, fi->value, FTREPR_JSON, fi->hfinfo->display);
         gboolean has_children = any_has_children(node_values_list);
 
         // We assume all values of a json key have roughly the same layout. Thus we can use the first value to derive
@@ -1032,8 +1032,10 @@ write_json_proto_node_value(proto_node *node, write_json_data *pdata)
 {
     field_info *fi = node->finfo;
     // Get the actual value of the node as a string.
-    char *value_string_repr = fvalue_to_string_repr(NULL, fi->value, FTREPR_DISPLAY, fi->hfinfo->display);
+    char *value_string_repr = fvalue_to_string_repr(NULL, fi->value, FTREPR_JSON, fi->hfinfo->display);
 
+    //TODO: Have FTREPR_JSON include quotes where appropriate and use json_dumper_value_anyf() here,
+    // so we can output booleans and numbers and not only strings.
     json_dumper_value_string(pdata->dumper, value_string_repr);
 
     wmem_free(NULL, value_string_repr);
@@ -1633,13 +1635,17 @@ static gchar *csv_massage_str(const gchar *source, const gchar *exceptions)
     return csv_str;
 }
 
-static void csv_write_str(const char *str, char sep, FILE *fh)
+static void csv_write_str(const char *str, char sep, FILE *fh, gboolean print_separator)
 {
     gchar *csv_str;
 
     /* Do not escape the UTF-8 right arrow character */
     csv_str = csv_massage_str(str, UTF8_RIGHTWARDS_ARROW);
-    fprintf(fh, "\"%s\"%c", csv_str, sep);
+    if (print_separator) {
+        fprintf(fh, "%c\"%s\"", sep, csv_str);
+    } else {
+        fprintf(fh, "\"%s\"", csv_str);
+    }
     g_free(csv_str);
 }
 
@@ -1647,26 +1653,36 @@ void
 write_csv_column_titles(column_info *cinfo, FILE *fh)
 {
     gint i;
+    gboolean print_separator = FALSE;
+    // Avoid printing separator for first column
 
-    for (i = 0; i < cinfo->num_cols - 1; i++) {
+    for (i = 0; i < cinfo->num_cols; i++) {
         if (!get_column_visible(i))
             continue;
-        csv_write_str(cinfo->columns[i].col_title, ',', fh);
+        csv_write_str(cinfo->columns[i].col_title, ',', fh, print_separator);
+        print_separator = TRUE;
+    }
+    if (print_separator) { // Only add line break if anything was output
+        fprintf(fh, "\n");
     }
-    csv_write_str(cinfo->columns[i].col_title, '\n', fh);
 }
 
 void
 write_csv_columns(epan_dissect_t *edt, FILE *fh)
 {
     gint i;
+    gboolean print_separator = FALSE;
+    // Avoid printing separator for first column
 
-    for (i = 0; i < edt->pi.cinfo->num_cols - 1; i++) {
+    for (i = 0; i < edt->pi.cinfo->num_cols; i++) {
         if (!get_column_visible(i))
             continue;
-        csv_write_str(get_column_text(edt->pi.cinfo, i), ',', fh);
+        csv_write_str(get_column_text(edt->pi.cinfo, i), ',', fh, print_separator);
+        print_separator = TRUE;
+    }
+    if (print_separator) { // Only add line break if anything was output
+        fprintf(fh, "\n");
     }
-    csv_write_str(get_column_text(edt->pi.cinfo,i), '\n', fh);
 }
 
 void
@@ -1693,7 +1709,7 @@ write_carrays_hex_data(guint32 num, FILE *fh, epan_dissect_t *edt)
 
         name = get_data_source_name(src);
         if (name) {
-            fprintf(fh, "/* %s */\n", name);
+            fprintf(fh, "// %s\n", name);
             wmem_free(NULL, name);
         }
         if (src_num) {
@@ -1717,12 +1733,12 @@ write_carrays_hex_data(guint32 num, FILE *fh, epan_dissect_t *edt)
                     for ( j = 0; j < 8 - rem; j++ )
                         fprintf(fh, "      ");
                 }
-                fprintf(fh, "  /* %s */\n};\n\n", ascii);
+                fprintf(fh, "  // %s\n};\n\n", ascii);
                 break;
             }
 
             if (!((i + 1) % 8)) {
-                fprintf(fh, ", /* %s */\n", ascii);
+                fprintf(fh, ", // %s\n", ascii);
                 memset(ascii, 0, sizeof(ascii));
             } else {
                 fprintf(fh, ", ");
@@ -1958,7 +1974,7 @@ json_write_field_hex_value(write_json_data *pdata, field_info *fi)
     }
 }
 
-gboolean
+bool
 print_hex_data(print_stream_t *stream, epan_dissect_t *edt, guint hexdump_options)
 {
     gboolean      multiple_sources;
@@ -2003,12 +2019,12 @@ print_hex_data(print_stream_t *stream, epan_dissect_t *edt, guint hexdump_option
     return TRUE;
 }
 
-static gboolean print_hex_data_line(void *stream, const char *line)
+static bool print_hex_data_line(void *stream, const char *line)
 {
     return print_line(stream, 0, line);
 }
 
-static gboolean print_hex_data_buffer(print_stream_t *stream, const guchar *cp,
+static bool print_hex_data_buffer(print_stream_t *stream, const guchar *cp,
                                       guint length, packet_char_enc encoding,
                                       guint hexdump_options)
 {
