@@ -17,7 +17,7 @@
 #include "addr_resolv.h"
 #include "proto.h"
 #include "color_filters.h"
-#include "column-info.h"
+#include <epan/column.h>
 #include "tap.h"
 #include <epan/wmem_scopes.h>
 
@@ -193,6 +193,14 @@ static void sequence_analysis_item_free(gpointer data)
     free_address(&seq_item->src_addr);
     free_address(&seq_item->dst_addr);
     if (seq_item->info_ptr) {
+#if 0
+        /* XXX: If seq_item->info_type is GA_INFO_TYPE_RTP, then we need
+         * to free the data, but rtpstream_info_free_* is in libui and
+         * not exported. */
+        if (seq_item->info_type == GA_INFO_TYPE_RTP) {
+            rtpstream_info_free_data((rtpstream_info_t *)seq_item->info_ptr);
+        }
+#endif
         g_free(seq_item->info_ptr);
     }
     g_free(data);
