@@ -16,6 +16,7 @@
 #include <epan/packet.h>
 #include <epan/exceptions.h>
 #include <epan/expert.h>
+#include <epan/prefs.h>
 #include <stdio.h>
 #include <inttypes.h>
 #include "wscbor.h"
@@ -140,10 +141,11 @@ static void wscbor_head_free(wmem_allocator_t *alloc, wscbor_head_t *head) {
 struct _wscbor_chunk_priv_t {
     /// The allocator used for wscbor_chunk_t.errors and wscbor_chunk_t.tags
     wmem_allocator_t *alloc;
+    /// Non-error expert info on this chunk (type wscbor_error_t*)
+    wmem_list_t *infos;
     /// For string types, including indefinite length, the item payload.
     /// Otherwise NULL.
     tvbuff_t *str_value;
-
 };
 
 /** Get a clamped string length suitable for tvb functions.
@@ -190,6 +192,7 @@ wscbor_chunk_t * wscbor_chunk_read(wmem_allocator_t *alloc, tvbuff_t *tvb, gint
     wscbor_chunk_t *chunk = wmem_new0(alloc, wscbor_chunk_t);
     chunk->_priv = wmem_new0(alloc, struct _wscbor_chunk_priv_t);
     chunk->_priv->alloc = alloc;
+    chunk->_priv->infos = wmem_list_new(alloc);
     chunk->errors = wmem_list_new(alloc);
     chunk->tags = wmem_list_new(alloc);
     chunk->start = *offset;
@@ -232,13 +235,12 @@ wscbor_chunk_t * wscbor_chunk_read(wmem_allocator_t *alloc, tvbuff_t *tvb, gint
                 // skip over definite data
                 *offset += datalen;
                 chunk->data_length += datalen;
-                if(datalen) {
-                    chunk->_priv->str_value = tvb_new_subset_length(tvb, chunk->start + chunk->head_length, datalen);
-                }
+                // allow even zero-length strings
+                chunk->_priv->str_value = tvb_new_subset_length(tvb, chunk->start + chunk->head_length, datalen);
             }
             else {
                 // indefinite length, sequence of definite items
-                chunk->_priv->str_value = tvb_new_composite();
+                chunk->_priv->str_value = NULL;
 
                 while (TRUE) {
                     wscbor_head_t *head = wscbor_head_read(alloc, tvb, offset);
@@ -263,6 +265,9 @@ wscbor_chunk_t * wscbor_chunk_read(wmem_allocator_t *alloc, tvbuff_t *tvb, gint
                             *offset += datalen;
                             chunk->data_length += datalen;
                             if(datalen) {
+                                if (!chunk->_priv->str_value) {
+                                    chunk->_priv->str_value = tvb_new_composite ();
+                                }
                                 tvb_composite_append(
                                     chunk->_priv->str_value,
                                     tvb_new_subset_length(tvb, head->start + head->length, datalen)
@@ -277,11 +282,18 @@ wscbor_chunk_t * wscbor_chunk_read(wmem_allocator_t *alloc, tvbuff_t *tvb, gint
                     }
                 }
 
-                wmem_list_append(chunk->errors, wscbor_error_new(
+                wmem_list_append(chunk->_priv->infos, wscbor_error_new(
                         chunk->_priv->alloc, &ei_cbor_indef_string,
                         NULL
                 ));
-                tvb_composite_finalize(chunk->_priv->str_value);
+
+                if (chunk->_priv->str_value) {
+                    tvb_composite_finalize(chunk->_priv->str_value);
+                }
+                else {
+                    // Create an empty subset tvb. str_value is expected to be non-NULL for string types.
+                    chunk->_priv->str_value = tvb_new_subset_length (tvb, 0, 0);
+                }
             }
             break;
         default:
@@ -299,6 +311,8 @@ static void wscbor_subitem_free(gpointer data, gpointer userdata) {
 void wscbor_chunk_free(wscbor_chunk_t *chunk) {
     DISSECTOR_ASSERT(chunk);
     wmem_allocator_t *alloc = chunk->_priv->alloc;
+    wmem_list_foreach(chunk->_priv->infos, wscbor_subitem_free, alloc);
+    wmem_destroy_list(chunk->_priv->infos);
     wmem_list_foreach(chunk->errors, wscbor_subitem_free, alloc);
     wmem_destroy_list(chunk->errors);
     wmem_list_foreach(chunk->tags, wscbor_subitem_free, alloc);
@@ -306,17 +320,30 @@ void wscbor_chunk_free(wscbor_chunk_t *chunk) {
     wmem_free(alloc, chunk);
 }
 
-guint64 wscbor_chunk_mark_errors(packet_info *pinfo, proto_item *item, const wscbor_chunk_t *chunk) {
-    for (wmem_list_frame_t *it = wmem_list_head(chunk->errors); it;
-            it = wmem_list_frame_next(it)) {
-        wscbor_error_t *err = (wscbor_error_t *) wmem_list_frame_data(it);
-        if (err->msg) {
-            expert_add_info_format(pinfo, item, err->ei, "%s", err->msg);
-        }
-        else {
-            expert_add_info(pinfo, item, err->ei);
-        }
+/// User data for wscbor_expert_add()
+typedef struct {
+    packet_info *pinfo;
+    proto_item *item;
+} wscbor_expert_add_t;
+
+/// A callback for wmem_list_foreach() to add the info
+static void wscbor_expert_add(gpointer data, gpointer userdata) {
+    const wscbor_error_t *err = (const wscbor_error_t *)data;
+    wscbor_expert_add_t *ctx = (wscbor_expert_add_t *)userdata;
+
+    if (err->msg) {
+        expert_add_info_format(ctx->pinfo, ctx->item, err->ei, "%s", err->msg);
     }
+    else {
+        expert_add_info(ctx->pinfo, ctx->item, err->ei);
+    }
+}
+
+guint64 wscbor_chunk_mark_errors(packet_info *pinfo, proto_item *item, const wscbor_chunk_t *chunk) {
+    wscbor_expert_add_t ctx = {pinfo, item};
+    wmem_list_foreach(chunk->errors, wscbor_expert_add, &ctx);
+    wmem_list_foreach(chunk->_priv->infos, wscbor_expert_add, &ctx);
+
     return wmem_list_count(chunk->errors);
 }
 
@@ -331,8 +358,25 @@ gboolean wscbor_is_indefinite_break(const wscbor_chunk_t *chunk) {
     );
 }
 
-gboolean wscbor_skip_next_item(wmem_allocator_t *alloc, tvbuff_t *tvb, gint *offset) {
+/** Add output parameter to indicate internal state.
+ * @param alloc The allocator to use.
+ * @param tvb The data buffer.
+ * @param[in,out] offset The initial offset to read and skip over.
+ * @param[out] is_break If non-null, set to true only when the item was
+ * an indefinite break.
+ * @return True if the skipped item was fully valid.
+ */
+// NOLINTNEXTLINE(misc-no-recursion)
+static gboolean wscbor_skip_next_item_internal(wmem_allocator_t *alloc, tvbuff_t *tvb, gint *offset, gboolean *is_break, unsigned depth) {
+    if (depth > prefs.gui_max_tree_depth) {
+
+        return false;
+    }
     wscbor_chunk_t *chunk = wscbor_chunk_read(alloc, tvb, offset);
+    if (wscbor_has_errors(chunk)) {
+        wscbor_chunk_free(chunk);
+        return FALSE;
+    }
     switch (chunk->type_major) {
         case CBOR_TYPE_UINT:
         case CBOR_TYPE_NEGINT:
@@ -346,12 +390,20 @@ gboolean wscbor_skip_next_item(wmem_allocator_t *alloc, tvbuff_t *tvb, gint *off
         case CBOR_TYPE_ARRAY: {
             if (chunk->type_minor == 31) {
                 // wait for indefinite break
-                while (!wscbor_skip_next_item(alloc, tvb, offset)) {}
+                gboolean was_break = FALSE;
+                do {
+                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, &was_break, depth + 1)) {
+                        return FALSE;
+                    }
+                }
+                while (!was_break);
             }
             else {
                 const guint64 count = chunk->head_value;
                 for (guint64 ix = 0; ix < count; ++ix) {
-                    wscbor_skip_next_item(alloc, tvb, offset);
+                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, NULL, depth + 1)) {
+                        return FALSE;
+                    }
                 }
             }
             break;
@@ -359,21 +411,40 @@ gboolean wscbor_skip_next_item(wmem_allocator_t *alloc, tvbuff_t *tvb, gint *off
         case CBOR_TYPE_MAP: {
             if (chunk->type_minor == 31) {
                 // wait for indefinite break
-                while (!wscbor_skip_next_item(alloc, tvb, offset)) {}
+                gboolean was_break = FALSE;
+                do {
+                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, &was_break, depth + 1)) {
+                        return FALSE;
+                    }
+                }
+                while (!was_break);
             }
             else {
                 const guint64 count = chunk->head_value;
                 for (guint64 ix = 0; ix < count; ++ix) {
-                    wscbor_skip_next_item(alloc, tvb, offset);
-                    wscbor_skip_next_item(alloc, tvb, offset);
+                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, NULL, depth + 1)) {
+                        return FALSE;
+                    }
+                    if (!wscbor_skip_next_item_internal(alloc, tvb, offset, NULL, depth + 1)) {
+                        return FALSE;
+                    }
                 }
             }
             break;
         }
     }
-    const gboolean is_break = wscbor_is_indefinite_break(chunk);
+    const gboolean got_break = wscbor_is_indefinite_break(chunk);
+    if (is_break) {
+        *is_break = got_break;
+    }
     wscbor_chunk_free(chunk);
-    return is_break;
+    // RFC 8949 Sec 3.2.1: a break code outside of an indefinite container is
+    // not valid, and is_break is non-null only in indefinite container.
+    return is_break || !got_break;
+}
+
+gboolean wscbor_skip_next_item(wmem_allocator_t *alloc, tvbuff_t *tvb, gint *offset) {
+    return wscbor_skip_next_item_internal(alloc, tvb, offset, NULL, 0);
 }
 
 gboolean wscbor_skip_if_errors(wmem_allocator_t *alloc, tvbuff_t *tvb, gint *offset, const wscbor_chunk_t *chunk) {
@@ -533,10 +604,10 @@ tvbuff_t * wscbor_require_bstr(wmem_allocator_t *alloc _U_, wscbor_chunk_t *chun
 proto_item * proto_tree_add_cbor_container(proto_tree *tree, int hfindex, packet_info *pinfo, tvbuff_t *tvb, const wscbor_chunk_t *chunk) {
     const header_field_info *hfinfo = proto_registrar_get_nth(hfindex);
     proto_item *item;
-    if (IS_FT_UINT(hfinfo->type)) {
+    if (FT_IS_UINT(hfinfo->type)) {
         item = proto_tree_add_uint64(tree, hfindex, tvb, chunk->start, chunk->head_length, chunk->head_value);
     }
-    else if (IS_FT_INT(hfinfo->type)) {
+    else if (FT_IS_INT(hfinfo->type)) {
         item = proto_tree_add_int64(tree, hfindex, tvb, chunk->start, chunk->head_length, chunk->head_value);
     }
     else {
@@ -607,22 +678,34 @@ proto_item * proto_tree_add_cbor_bitmask(proto_tree *tree, int hfindex, const gi
     return item;
 }
 
-proto_item * proto_tree_add_cbor_tstr(proto_tree *tree, int hfindex, packet_info *pinfo, tvbuff_t *tvb _U_, const wscbor_chunk_t *chunk) {
+proto_item * proto_tree_add_cbor_tstr(proto_tree *tree, int hfindex, packet_info *pinfo, tvbuff_t *tvb, const wscbor_chunk_t *chunk) {
+    proto_item *item;
     if (chunk->_priv->str_value) {
-        proto_item *item = proto_tree_add_item(tree, hfindex, chunk->_priv->str_value, 0, tvb_reported_length(chunk->_priv->str_value), 0);
-        wscbor_chunk_mark_errors(pinfo, item, chunk);
-        return item;
-    } else {
-        return NULL;
+        item = proto_tree_add_item(tree, hfindex, chunk->_priv->str_value, 0, tvb_reported_length(chunk->_priv->str_value), 0);
     }
+    else {
+        // still show an empty item with errors
+        item = proto_tree_add_item(tree, hfindex, tvb, chunk->start, 0, 0);
+    }
+    wscbor_chunk_mark_errors(pinfo, item, chunk);
+    return item;
 }
 
-proto_item * proto_tree_add_cbor_bstr(proto_tree *tree, int hfindex, packet_info *pinfo, tvbuff_t *tvb _U_, const wscbor_chunk_t *chunk) {
+proto_item * proto_tree_add_cbor_bstr(proto_tree *tree, int hfindex, packet_info *pinfo, tvbuff_t *tvb, const wscbor_chunk_t *chunk) {
+    proto_item *item;
     if (chunk->_priv->str_value) {
-        proto_item *item = proto_tree_add_item(tree, hfindex, chunk->_priv->str_value, 0, tvb_reported_length(chunk->_priv->str_value), 0);
-        wscbor_chunk_mark_errors(pinfo, item, chunk);
-        return item;
-    } else {
-        return NULL;
+        item = proto_tree_add_item(tree, hfindex, chunk->_priv->str_value, 0, tvb_reported_length(chunk->_priv->str_value), 0);
     }
+    else {
+        // still show an empty item with errors
+        item = proto_tree_add_item(tree, hfindex, tvb, chunk->start, 0, 0);
+    }
+    wscbor_chunk_mark_errors(pinfo, item, chunk);
+    return item;
+}
+
+proto_item * proto_tree_add_cbor_strlen(proto_tree *tree, int hfindex, packet_info *pinfo _U_, tvbuff_t *tvb, const wscbor_chunk_t *chunk) {
+    const guint str_len = (chunk->_priv->str_value ? tvb_reported_length(chunk->_priv->str_value) : 0);
+    proto_item *item = proto_tree_add_uint64(tree, hfindex, tvb, chunk->start, chunk->head_length, str_len);
+    return item;
 }
