@@ -837,14 +837,14 @@ void parseDiagnosticInfo(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, gi
     {
         parseInt32(subtree, tvb, pinfo, &iOffset, hf_opcua_diag_namespace);
     }
-    if (EncodingMask & DIAGNOSTICINFO_ENCODINGMASK_LOCALIZEDTEXT_FLAG)
-    {
-        parseInt32(subtree, tvb, pinfo, &iOffset, hf_opcua_diag_localizedtext);
-    }
     if (EncodingMask & DIAGNOSTICINFO_ENCODINGMASK_LOCALE_FLAG)
     {
         parseInt32(subtree, tvb, pinfo, &iOffset, hf_opcua_diag_locale);
     }
+    if (EncodingMask & DIAGNOSTICINFO_ENCODINGMASK_LOCALIZEDTEXT_FLAG)
+    {
+        parseInt32(subtree, tvb, pinfo, &iOffset, hf_opcua_diag_localizedtext);
+    }
     if (EncodingMask & DIAGNOSTICINFO_ENCODINGMASK_ADDITIONALINFO_FLAG)
     {
         parseString(subtree, tvb, pinfo, &iOffset, hf_opcua_diag_additionalinfo);
@@ -1145,7 +1145,7 @@ void parseArrayComplex(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, gint
     for (i=0; i<iLen; i++)
     {
         char szNum[20];
-        g_snprintf(szNum, 20, "[%i]", i);
+        snprintf(szNum, 20, "[%i]", i);
         (*pParserFunction)(subtree, tvb, pinfo, pOffset, szNum);
     }
     proto_item_set_end(ti, tvb, *pOffset);
@@ -1229,7 +1229,7 @@ void parseExtensionObject(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, g
 
     /* add nodeid subtree */
     TypeId = getExtensionObjectType(tvb, &iOffset);
-    parseExpandedNodeId(extobj_tree, tvb, pinfo, &iOffset, "TypeId");
+    parseNodeId(extobj_tree, tvb, pinfo, &iOffset, "TypeId");
 
     /* parse encoding mask */
     EncodingMask = tvb_get_guint8(tvb, iOffset);
