@@ -6,19 +6,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -33,6 +21,8 @@
 void proto_register_pn_mrp(void);
 void proto_reg_handoff_pn_mrp(void);
 
+static dissector_handle_t mrp_handle;
+
 static int proto_pn_mrp = -1;
 
 static int hf_pn_mrp_type = -1;
@@ -56,6 +46,7 @@ static int hf_pn_mrp_sub_tlv_header_length = -1;
 static int hf_pn_mrp_sub_option2 = -1;
 static int hf_pn_mrp_other_mrm_prio = -1;
 static int hf_pn_mrp_other_mrm_sa = -1;
+static int hf_pn_mrp_manufacturer_data = -1;
 
 static gint ett_pn_mrp = -1;
 static gint ett_pn_mrp_type = -1;
@@ -125,10 +116,26 @@ static const value_string pn_mrp_prio_vals[] = {
 #endif
 
 static const value_string pn_mrp_sub_tlv_header_type_vals[] = {
-    { 0x00, "End" },
+    /* 0x00 Reserved */
     { 0x01, "MRP_TestMgrNAck" },
     { 0x02, "MRP_TestPropagate" },
     { 0x03, "MRP_AutoMgr" },
+    /* 0x04 - 0xF0 Reserved for IEC specific functions */
+    { 0xF1, "Manufacturer specific functions" },
+    { 0xF2, "Manufacturer specific functions" },
+    { 0xF3, "Manufacturer specific functions" },
+    { 0xF4, "Manufacturer specific functions" },
+    { 0xF5, "Manufacturer specific functions" },
+    { 0xF6, "Manufacturer specific functions" },
+    { 0xF7, "Manufacturer specific functions" },
+    { 0xF8, "Manufacturer specific functions" },
+    { 0xF9, "Manufacturer specific functions" },
+    { 0xFA, "Manufacturer specific functions" },
+    { 0xFB, "Manufacturer specific functions" },
+    { 0xFC, "Manufacturer specific functions" },
+    { 0xFD, "Manufacturer specific functions" },
+    { 0xFE, "Manufacturer specific functions" },
+    { 0xFF, "Manufacturer specific functions" },
     { 0, NULL },
 };
 
@@ -336,12 +343,13 @@ packet_info *pinfo, proto_tree *tree)
 
     if (u8SubType == 0x00)
     {
-        // IEC area: 0x00: MRP_End;
+        // IEC area: 0x00: Reserved;
         return offset;
     }
-    else if (u8SubType == 0x01)
+    else if ( u8SubType == 0x01 || u8SubType == 0x02 )
     {
         // IEC area: 0x01: MRP_TestMgrNAck;
+        // IEC area: 0x02: MRP_AutoMgr;
 
         /* MRP_Prio */
         offset = dissect_pn_uint16_ret_item(tvb, offset, pinfo, sub_tree, hf_pn_mrp_prio, &u16Prio, &sub_item);
@@ -360,24 +368,11 @@ packet_info *pinfo, proto_tree *tree)
 
         offset = dissect_pn_align4(tvb, offset, pinfo, sub_tree);
     }
-    else if (u8SubType == 0x02)
+    else if ( 0xF1 <= u8SubType )
     {
-        /* MRP_Prio */
-        offset = dissect_pn_uint16_ret_item(tvb, offset, pinfo, sub_tree, hf_pn_mrp_prio, &u16Prio, &sub_item);
-        proto_item_append_text(sub_item, "%s", mrp_Prio2msg(u16Prio));
-
-        /* MRP_SA */
-        offset = dissect_pn_mac(tvb, offset, pinfo, sub_tree, hf_pn_mrp_sa, mac);
-
-        /* MRP_OtherMRMPrio */
-        offset = dissect_pn_uint16_ret_item(tvb, offset, pinfo, sub_tree, hf_pn_mrp_other_mrm_prio,
-            &u16OtherPrio, &sub_item);
-        proto_item_append_text(sub_item, "%s", mrp_Prio2msg(u16OtherPrio));
-
-        /* MRP_OtherMRMSA */
-        offset = dissect_pn_mac(tvb, offset, pinfo, sub_tree, hf_pn_mrp_other_mrm_sa, otherMac);
-
-        offset = dissect_pn_align4(tvb, offset, pinfo, sub_tree);
+        proto_tree_add_string_format(sub_tree, hf_pn_mrp_manufacturer_data, tvb, offset, u8Sublength, "data",
+        "Reserved for vendor specific data: %u byte", u8Sublength);
+        offset += u8Sublength;
     }
     return offset;
 }
@@ -391,12 +386,12 @@ dissect_PNMRP_Option(tvbuff_t *tvb, int offset,
 
     /* OUI (organizational unique id) */
     offset = dissect_pn_oid(tvb, offset, pinfo,tree, hf_pn_mrp_oui, &oui);
+    length -= 3;
 
     switch (oui)
     {
     case OUI_SIEMENS:
         proto_item_append_text(item, "(SIEMENS)");
-        length -= 3;
         offset = dissect_pn_uint8(tvb, offset, pinfo, tree, hf_pn_mrp_ed1type, &u8MrpEd1Type);
         length -= 1;
         switch (u8MrpEd1Type)
@@ -474,8 +469,8 @@ dissect_PNMRP_PDU(tvbuff_t *tvb, int offset,
         } else {
             proto_item_append_text(item, " ");
         }
-        col_append_str(pinfo->cinfo, COL_INFO, val_to_str_const(type, pn_mrp_block_type_vals, "Unknown TLVType 0x%x"));
-        proto_item_append_text(item, "%s", val_to_str_const(type, pn_mrp_block_type_vals, "Unknown TLVType 0x%x"));
+        col_append_str(pinfo->cinfo, COL_INFO, val_to_str(type, pn_mrp_block_type_vals, "Unknown TLVType 0x%x"));
+        proto_item_append_text(item, "%s", val_to_str(type, pn_mrp_block_type_vals, "Unknown TLVType 0x%x"));
 
         switch(type) {
         case 0x00:
@@ -640,6 +635,10 @@ proto_register_pn_mrp (void)
     { &hf_pn_mrp_other_mrm_sa,
       { "MRP_OtherMRMSA", "pn_mrp.other_mrm_sa",
         FT_ETHER, BASE_NONE, 0x0, 0x0,
+        NULL, HFILL }},
+    { &hf_pn_mrp_manufacturer_data,
+      { "MRP_ManufacturerData", "pn_mrp.manufacturer_data",
+        FT_STRING, BASE_NONE, NULL, 0x0,
         NULL, HFILL }}
     };
 
@@ -652,22 +651,18 @@ proto_register_pn_mrp (void)
     proto_pn_mrp = proto_register_protocol ("PROFINET MRP", "PN-MRP", "pn_mrp");
     proto_register_field_array (proto_pn_mrp, hf, array_length (hf));
     proto_register_subtree_array (ett, array_length (ett));
+    mrp_handle = register_dissector("pn_mrp", dissect_PNMRP, proto_pn_mrp);
 }
 
 
 void
 proto_reg_handoff_pn_mrp (void)
 {
-    dissector_handle_t mrp_handle;
-
-
-    mrp_handle = create_dissector_handle(dissect_PNMRP,proto_pn_mrp);
     dissector_add_uint("ethertype", ETHERTYPE_MRP, mrp_handle);
-
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
