@@ -175,8 +175,10 @@ static const value_string pn_io_error_code1_pnio[] = {
     { 0x06 /*  6*/, "Connect: Faulty MCRBlockReq" },
     { 0x07 /*  7*/, "Connect: Faulty ARRPCBlockReq" },
     { 0x08 /*  8*/, "Read/Write Record: Faulty Record" },
-    { 0x09 /*  9*/, "Connect: Faulty SubFrameBlock" },
-    { 0x0A /* 10*/, "Connect: Faulty IRTFrameBlock" },
+    { 0x09 /*  9*/, "Connect: Faulty IRInfoBlock" },
+    { 0x0A /* 10*/, "Connect: Faulty SRInfoBlock" },
+    { 0x0B /* 11*/, "Connect: Faulty ARFSUBlock" },
+    { 0x0C /* 12*/, "Connect: Faulty ARVendorBlockReq" },
     { 0x0D /* 13*/, "Connect: Faulty RSInfoBlock" },
     { 0x14 /* 20*/, "IODControl: Faulty ControlBlockConnect" },
     { 0x15 /* 21*/, "IODControl: Faulty ControlBlockPlug" },
