@@ -229,11 +229,11 @@ void wimax_proto_register_wimax_fch(void)
 	proto_register_field_array(proto_wimax_fch_decoder, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
-	register_dissector("wimax_fch_burst_handler", dissect_wimax_fch_decoder, -1);
+	register_dissector("wimax_fch_burst_handler", dissect_wimax_fch_decoder, proto_wimax_fch_decoder);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
