@@ -28,7 +28,7 @@ DONE=false
 # Currently running children
 RUNNER_PIDS=
 
-# Perform a two pass analysis on the capture file?
+# Perform a two-pass analysis on the capture file?
 TWO_PASS=
 
 # Specific config profile ?
@@ -37,6 +37,9 @@ CONFIG_PROFILE=
 # Run under valgrind ?
 VALGRIND=0
 
+# Abort on UTF-8 encoding errors
+CHECK_UTF_8="--log-fatal-domains=UTF-8 "
+
 # Run under AddressSanitizer ?
 ASAN=$CONFIGURED_WITH_ASAN
 
@@ -53,7 +56,7 @@ RUN_START_SECONDS=$SECONDS
 RUN_MAX_SECONDS=$(( RUN_START_SECONDS + 86400 ))
 
 # To do: add options for file names and limits
-while getopts "2b:C:d:e:agp:P:o:t:" OPTCHAR ; do
+while getopts "2b:C:d:e:agp:P:o:t:U" OPTCHAR ; do
     case $OPTCHAR in
         a) ASAN=1 ;;
         2) TWO_PASS="-2 " ;;
@@ -66,7 +69,8 @@ while getopts "2b:C:d:e:agp:P:o:t:" OPTCHAR ; do
         P) MIN_PLUGINS=$OPTARG ;;
         o) CHANGE_OFFSET=$OPTARG ;;
         t) RUN_MAX_SECONDS=$(( RUN_START_SECONDS + OPTARG )) ;;
-        *) printf "Unknown option %s" "$OPTCHAR"
+        U) CHECK_UTF_8= ;; # disable
+        *) printf "Unknown option %s\n" "$OPTCHAR"
     esac
 done
 shift $((OPTIND - 1))
@@ -76,7 +80,7 @@ shift $((OPTIND - 1))
 ws_bind_exec_paths
 ws_check_exec "$TSHARK" "$EDITCAP" "$CAPINFOS" "$DATE" "$TMP_DIR"
 
-COMMON_ARGS="${CONFIG_PROFILE}${TWO_PASS}"
+COMMON_ARGS="${CONFIG_PROFILE}${TWO_PASS}${CHECK_UTF_8}"
 KEEP=
 PACKET_RANGE=
 if [ $VALGRIND -eq 1 ]; then
@@ -144,7 +148,7 @@ if [ "$MAX_PASSES" -gt 0 ]; then
     HOWMANY="$MAX_PASSES passes"
 fi
 echo -n "Running $RUNNER $COMMON_ARGS with args: "
-printf "\"%s\" " "${RUNNER_ARGS[@]}"
+printf "\"%s\"\n" "${RUNNER_ARGS[@]}"
 echo "($HOWMANY)"
 echo ""
 
@@ -183,7 +187,6 @@ while { [ $PASS -lt "$MAX_PASSES" ] || [ "$MAX_PASSES" -lt 1 ]; } && ! $DONE ; d
         if [ "$OSTYPE" == "cygwin" ] ; then
             CF=$( cygpath --windows "$CF" )
         fi
-        printf "    %s: " "$( basename "$CF" )"
 
         "$CAPINFOS" "$CF" > /dev/null 2> "$TMP_DIR/$ERR_FILE"
         RETVAL=$?
@@ -196,12 +199,28 @@ while { [ $PASS -lt "$MAX_PASSES" ] || [ "$MAX_PASSES" -lt 1 ]; } && ! $DONE ; d
             ws_exit_error
         fi
 
+        # Choose a random subset of large captures.
+        KEEP=
+        PACKET_RANGE=
+        CF_PACKETS=$( "$CAPINFOS" -T -r -c "$CF" | cut -f2 )
+        if [[ CF_PACKETS -gt $MAX_FUZZ_PACKETS ]] ; then
+            START_PACKET=$(( CF_PACKETS - MAX_FUZZ_PACKETS ))
+            START_PACKET=$( shuf --input-range=1-$START_PACKET --head-count=1 )
+            END_PACKET=$(( START_PACKET + MAX_FUZZ_PACKETS ))
+            KEEP=-r
+            PACKET_RANGE="$START_PACKET-$END_PACKET"
+            printf "    Fuzzing packets %d-%d of %d\n" "$START_PACKET" "$END_PACKET" "$CF_PACKETS"
+        fi
+
         DISSECTOR_BUG=0
         VG_ERR_CNT=0
 
+        printf "    %s: " "$( basename "$CF" )"
+        # shellcheck disable=SC2086
         "$EDITCAP" -E "$ERR_PROB" -o "$CHANGE_OFFSET" $KEEP "$CF" "$TMP_DIR/$TMP_FILE" $PACKET_RANGE > /dev/null 2>&1
         RETVAL=$?
         if [ $RETVAL -ne 0 ] ; then
+            # shellcheck disable=SC2086
             "$EDITCAP" -E "$ERR_PROB" -o "$CHANGE_OFFSET" $KEEP -T ether "$CF" "$TMP_DIR/$TMP_FILE" $PACKET_RANGE \
                 > /dev/null 2>&1
             RETVAL=$?
@@ -285,7 +304,7 @@ while { [ $PASS -lt "$MAX_PASSES" ] || [ "$MAX_PASSES" -lt 1 ]; } && ! $DONE ; d
                 fi
             fi
 
-            if ! $DONE && { [ $RUNNER_RETVAL -ne 0 ] || [ $DISSECTOR_BUG -ne 0 ] || [ $VG_ERR_CNT -ne 0 ]; } ; then
+            if ! $DONE && { [ $RUNNER_RETVAL -ne 0 ] || [ $DISSECTOR_BUG -ne 0 ] || [ "$VG_ERR_CNT" -ne 0 ]; } ; then
                 # shellcheck disable=SC2086
                 rm -f $RUNNER_ERR_FILES
                 ws_exit_error
