@@ -620,7 +620,7 @@ capture_input_error(capture_session *cap_session _U_, char *error_msg,
     ws_assert(cap_session->state == CAPTURE_PREPARING || cap_session->state == CAPTURE_RUNNING);
 
     safe_error_msg = simple_dialog_format_message(error_msg);
-    if (*secondary_error_msg != '\0') {
+    if (secondary_error_msg != NULL && *secondary_error_msg != '\0') {
         /* We have both primary and secondary messages. */
         safe_secondary_error_msg = simple_dialog_format_message(secondary_error_msg);
         simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s%s%s\n\n%s",
@@ -709,7 +709,7 @@ capture_input_closed(capture_session *cap_session, gchar *msg)
         }
         /*
          * ws_log prefixes log messages with a timestamp delimited by " -- " and possibly
-         * a function name delimted by "(): ". Log it to sterr, but omit it in the UI.
+         * a function name delimited by "(): ". Log it to sterr, but omit it in the UI.
          */
         char *plain_msg = strstr(msg, "(): ");
         if (plain_msg != NULL) {
@@ -892,7 +892,8 @@ capture_stat_start(capture_options *capture_opts)
             }
         }
     } else {
-        g_free(msg); /* XXX: should we display this to the user ? */
+        ws_warning("%s", msg);
+        g_free(msg); /* XXX: should we display this to the user via the GUI? */
     }
     return sc;
 }
