@@ -21,7 +21,7 @@
 #include <epan/stat_tap_ui.h>
 #include <epan/addr_resolv.h>
 
-#include <ui/cmdarg_err.h>
+#include <wsutil/cmdarg_err.h>
 
 void register_tap_listener_hosts(void);
 
