@@ -23,12 +23,14 @@
 #include <epan/value_string.h>
 #include <epan/dissectors/packet-smb.h>
 
+#include <wsutil/cmdarg_err.h>
+
 void register_tap_listener_smbsids(void);
 
-static int
-smbsids_packet(void *pss _U_, packet_info *pinfo _U_, epan_dissect_t *edt _U_, const void *psi _U_)
+static tap_packet_status
+smbsids_packet(void *pss _U_, packet_info *pinfo _U_, epan_dissect_t *edt _U_, const void *psi _U_, tap_flags_t flags _U_)
 {
-	return 1;
+	return TAP_PACKET_REDRAW;
 }
 
 static void
@@ -68,7 +70,7 @@ smbsids_init(const char *opt_arg _U_, void *userdata _U_)
 
 	error_string = register_tap_listener("smb", NULL, NULL, 0, NULL, smbsids_packet, smbsids_draw, NULL);
 	if (error_string) {
-		fprintf(stderr, "tshark: Couldn't register smb,sids tap:%s\n",
+		cmdarg_err("Couldn't register smb,sids tap: %s",
 			error_string->str);
 		g_string_free(error_string, TRUE);
 		exit(1);
@@ -91,7 +93,7 @@ register_tap_listener_smbsids(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
