@@ -116,8 +116,6 @@ ColoringRulesDialog::ColoringRulesDialog(QWidget *parent, QString add_filter) :
         ui->coloringRulesTreeView->setCurrentIndex(QModelIndex());
     }
 
-    checkUnknownColorfilters();
-
     updateHint();
 }
 
@@ -126,22 +124,6 @@ ColoringRulesDialog::~ColoringRulesDialog()
     delete ui;
 }
 
-void ColoringRulesDialog::checkUnknownColorfilters()
-{
-    if (prefs.unknown_colorfilters) {
-        QMessageBox *mb = new QMessageBox();
-        mb->setText(tr("Your coloring rules file contains unknown rules"));
-        mb->setInformativeText(tr("Wireshark doesn't recognize one or more of your coloring rules. "
-                                 "They have been disabled."));
-        mb->setStandardButtons(QMessageBox::Ok);
-
-        mb->setWindowModality(Qt::ApplicationModal);
-        mb->setAttribute(Qt::WA_DeleteOnClose);
-        mb->show();
-        prefs.unknown_colorfilters = FALSE;
-    }
-}
-
 void ColoringRulesDialog::copyFromProfile(QString filename)
 {
     QString err;
@@ -153,8 +135,6 @@ void ColoringRulesDialog::copyFromProfile(QString filename)
     for (int i = 0; i < colorRuleModel_.columnCount(); i++) {
         ui->coloringRulesTreeView->resizeColumnToContents(i);
     }
-
-    checkUnknownColorfilters();
 }
 
 void ColoringRulesDialog::showEvent(QShowEvent *)
@@ -174,17 +154,17 @@ void ColoringRulesDialog::rowCountChanged()
 bool ColoringRulesDialog::isValidFilter(QString filter, QString * error)
 {
     dfilter_t *dfp = NULL;
-    gchar *err_msg;
+    df_error_t *df_err = NULL;
 
-    if (dfilter_compile(filter.toUtf8().constData(), &dfp, &err_msg)) {
+    if (dfilter_compile(filter.toUtf8().constData(), &dfp, &df_err)) {
         dfilter_free(dfp);
         return true;
     }
 
-    if (err_msg)
+    if (df_err)
     {
-        error->append(err_msg);
-        g_free(err_msg);
+        error->append(df_err->msg);
+        df_error_free(&df_err);
     }
 
     return false;
@@ -435,13 +415,11 @@ void ColoringRulesDialog::on_buttonBox_clicked(QAbstractButton *button)
 
     if (button == import_button_) {
         QString file_name = WiresharkFileDialog::getOpenFileName(this, mainApp->windowTitleString(tr("Import Coloring Rules")),
-                                                         mainApp->lastOpenDir().path());
+                                                         mainApp->openDialogInitialDir().path());
         if (!file_name.isEmpty()) {
             if (!colorRuleModel_.importColors(file_name, err)) {
                 simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", err.toUtf8().constData());
             }
-
-            checkUnknownColorfilters();
         }
     } else if (button == export_button_) {
         int num_items = static_cast<int>(ui->coloringRulesTreeView->selectionModel()->selectedIndexes().count()) / colorRuleModel_.columnCount();
@@ -455,7 +433,7 @@ void ColoringRulesDialog::on_buttonBox_clicked(QAbstractButton *button)
 
         QString caption = mainApp->windowTitleString(tr("Export %1 Coloring Rules").arg(num_items));
         QString file_name = WiresharkFileDialog::getSaveFileName(this, caption,
-                                                         mainApp->lastOpenDir().path());
+                                                         mainApp->openDialogInitialDir().path());
         if (!file_name.isEmpty()) {
             if (!colorRuleModel_.exportColors(file_name, err)) {
                 simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", err.toUtf8().constData());
@@ -467,9 +445,12 @@ void ColoringRulesDialog::on_buttonBox_clicked(QAbstractButton *button)
 void ColoringRulesDialog::on_buttonBox_accepted()
 {
     QString err;
+    int ret = QDialog::Accepted;
     if (!colorRuleModel_.writeColors(err)) {
         simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", err.toUtf8().constData());
+        ret = QDialog::Rejected;
     }
+    done(ret);
 }
 
 void ColoringRulesDialog::on_buttonBox_helpRequested()
