@@ -21,8 +21,6 @@ public:
      *
      * @param parent Parent widget.
      * @param cf Capture file. No statistics will be calculated if this is NULL.
-     * @param cli_proto_id If valid, add this protocol and bring it to the front.
-     * @param filter Display filter to apply.
      */
     explicit ConversationDialog(QWidget &parent, CaptureFile &cf);
 
@@ -30,7 +28,7 @@ protected:
     void captureFileClosing();
 
 signals:
-    void openFollowStreamDialog(follow_type_t type, guint stream_num, guint sub_stream_num);
+    void openFollowStreamDialog(int proto_id, guint stream_num, guint sub_stream_num);
 
 private:
     QPushButton *follow_bt_;
