@@ -14,7 +14,7 @@
 #include <ui/qt/models/pref_models.h>
 #include <ui_font_color_preferences_frame.h>
 #include <ui/qt/utils/color_utils.h>
-#include "wireshark_application.h"
+#include "main_application.h"
 
 #include <functional>
 #include <QFontDialog>
@@ -36,7 +36,7 @@ FontColorPreferencesFrame::FontColorPreferencesFrame(QWidget *parent) :
 {
     ui->setupUi(this);
 
-    pref_qt_gui_font_name_ = prefFromPrefPtr(&prefs.gui_qt_font_name);
+    pref_qt_gui_font_name_ = prefFromPrefPtr(&prefs.gui_font_name);
     pref_active_fg_ = prefFromPrefPtr(&prefs.gui_active_fg);
     pref_active_bg_ = prefFromPrefPtr(&prefs.gui_active_bg);
     pref_active_style_ = prefFromPrefPtr(&prefs.gui_active_style);
@@ -70,7 +70,7 @@ void FontColorPreferencesFrame::showEvent(QShowEvent *)
     QString pangram = QString(font_pangrams_[g_rand_int_range(rand_state, 0, num_font_pangrams_)]) + " 0123456789";
     ui->fontSampleLineEdit->setText(pangram);
     ui->fontSampleLineEdit->setCursorPosition(0);
-    ui->fontSampleLineEdit->setMinimumWidth(wsApp->monospaceTextSize(pangram.toUtf8().constData()) + wsApp->monospaceTextSize(" "));
+    ui->fontSampleLineEdit->setMinimumWidth(mainApp->monospaceTextSize(pangram.toUtf8().constData()) + mainApp->monospaceTextSize(" "));
     g_rand_free(rand_state);
 
     updateWidgets();
@@ -102,11 +102,13 @@ void FontColorPreferencesFrame::updateWidgets()
         "}";
     QString sample_text_ss =
         "QLineEdit {"
+        "  border: 1px solid palette(Dark);"
         "  color: %1;"
         "  background-color: %2;"
         "}";
     QString sample_text_ex_ss =
         "QLineEdit {"
+        "  border: 1px solid palette(Dark);"
         "  color: %1;"
         "  background-color: qlineargradient(x1:0, y1:0, x2:0, y2:1 stop: 0 %3, stop: 0.5 %2, stop: 1 %3);"
         "}";
@@ -125,13 +127,11 @@ void FontColorPreferencesFrame::updateWidgets()
 
         foreground  = default_pal.highlightedText().color();
         background1 = default_pal.highlight().color();
-        background2 = default_pal.highlight().color();
         break;
 
     case COLOR_STYLE_FLAT:
         foreground  = ColorUtils::fromColorT(prefs_get_color_value(pref_active_fg_, pref_stashed));
         background1 = ColorUtils::fromColorT(prefs_get_color_value(pref_active_bg_, pref_stashed));
-        background2 = ColorUtils::fromColorT(prefs_get_color_value(pref_active_bg_, pref_stashed));
         break;
 
     case COLOR_STYLE_GRADIENT:
@@ -143,10 +143,16 @@ void FontColorPreferencesFrame::updateWidgets()
 
     ui->activeFGPushButton->setStyleSheet(color_button_ss.arg(foreground.name()).arg(margin));
     ui->activeBGPushButton->setStyleSheet(color_button_ss.arg(background1.name()).arg(0));
-    ui->activeSampleLineEdit->setStyleSheet(sample_text_ex_ss.arg(
+    if (colorstyle == COLOR_STYLE_GRADIENT) {
+        ui->activeSampleLineEdit->setStyleSheet(sample_text_ex_ss.arg(
                                                 foreground.name(),
                                                 background1.name(),
                                                 background2.name()));
+    } else {
+        ui->activeSampleLineEdit->setStyleSheet(sample_text_ss.arg(
+                                                foreground.name(),
+                                                background1.name()));
+    }
     ui->activeSampleLineEdit->setFont(cur_font_);
     ui->activeStyleComboBox->setCurrentIndex(prefs_get_enum_value(pref_active_style_, pref_stashed));
 
@@ -168,13 +174,11 @@ void FontColorPreferencesFrame::updateWidgets()
 
         foreground  = default_pal.highlightedText().color();
         background1 = default_pal.highlight().color();
-        background2 = default_pal.highlight().color();
         break;
 
     case COLOR_STYLE_FLAT:
         foreground  = ColorUtils::fromColorT(prefs_get_color_value(pref_inactive_fg_, pref_stashed));
         background1 = ColorUtils::fromColorT(prefs_get_color_value(pref_inactive_bg_, pref_stashed));
-        background2 = ColorUtils::fromColorT(prefs_get_color_value(pref_inactive_bg_, pref_stashed));
         break;
 
     case COLOR_STYLE_GRADIENT:
@@ -186,10 +190,16 @@ void FontColorPreferencesFrame::updateWidgets()
 
     ui->inactiveFGPushButton->setStyleSheet(color_button_ss.arg(foreground.name()).arg(margin));
     ui->inactiveBGPushButton->setStyleSheet(color_button_ss.arg(background1.name()).arg(0));
-    ui->inactiveSampleLineEdit->setStyleSheet(sample_text_ex_ss.arg(
-                                                foreground.name(),
-                                                background1.name(),
-                                                background2.name()));
+    if (colorstyle == COLOR_STYLE_GRADIENT) {
+        ui->inactiveSampleLineEdit->setStyleSheet(sample_text_ex_ss.arg(
+                                                  foreground.name(),
+                                                  background1.name(),
+                                                  background2.name()));
+    } else {
+        ui->inactiveSampleLineEdit->setStyleSheet(sample_text_ss.arg(
+                                                  foreground.name(),
+                                                  background1.name()));
+    }
     ui->inactiveSampleLineEdit->setFont(cur_font_);
     ui->inactiveStyleComboBox->setCurrentIndex(prefs_get_enum_value(pref_inactive_style_, pref_stashed));
 
@@ -317,7 +327,7 @@ void FontColorPreferencesFrame::colorChanged(pref_t *pref, const QColor &cc)
 void FontColorPreferencesFrame::on_fontPushButton_clicked()
 {
     bool ok;
-    QFont new_font = QFontDialog::getFont(&ok, cur_font_, this, wsApp->windowTitleString(tr("Font")));
+    QFont new_font = QFontDialog::getFont(&ok, cur_font_, this, mainApp->windowTitleString(tr("Font")));
     if (ok) {
         prefs_set_string_value(pref_qt_gui_font_name_, new_font.toString().toStdString().c_str(), pref_stashed);
         cur_font_ = new_font;
@@ -412,16 +422,3 @@ void FontColorPreferencesFrame::on_deprecatedFilterBGPushButton_clicked()
 {
     changeColor(pref_deprecated_bg_);
 }
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
