@@ -19,6 +19,8 @@
 
 #include <QFont>
 #include <QColor>
+#include <QRegularExpression>
+#include <QApplication>
 
 // XXX Should we move this to ui/preference_utils?
 static GHashTable * pref_ptr_to_pref_ = NULL;
@@ -74,14 +76,6 @@ int PrefsItem::getPrefType() const
     return prefs_get_type(pref_);
 }
 
-int PrefsItem::getPrefGUIType() const
-{
-    if (pref_ == NULL)
-        return GUI_ALL;
-
-    return prefs_get_gui_type(pref_);
-}
-
 bool PrefsItem::isPrefDefault() const
 {
     if (pref_ == NULL)
@@ -150,7 +144,7 @@ int PrefsModel::rowCount(const QModelIndex &parent) const
     if (parent_item == NULL)
         return 0;
 
-    return parent_item->childCount();
+    return static_cast<int>(parent_item->childCount());
 }
 
 int PrefsModel::columnCount(const QModelIndex&) const
@@ -217,7 +211,7 @@ QVariant PrefsModel::data(const QModelIndex &index, int role) const
         return item->getName();
 
     case colStatus:
-        if ((item->getPrefType() == PREF_UAT && (item->getPrefGUIType() == GUI_ALL || item->getPrefGUIType() == GUI_QT)) || item->getPrefType() == PREF_CUSTOM)
+        if (item->getPrefType() == PREF_UAT || item->getPrefType() == PREF_CUSTOM)
             return QObject::tr("Unknown");
 
         if (item->isPrefDefault())
@@ -230,7 +224,7 @@ QVariant PrefsModel::data(const QModelIndex &index, int role) const
         if (item->getPref() == NULL)
             return QVariant();
 
-        return QString(gchar_free_to_qstring(prefs_pref_to_str(item->getPref(), pref_stashed)).remove(QRegExp("\n\t")));
+        return QString(gchar_free_to_qstring(prefs_pref_to_str(item->getPref(), pref_stashed)).remove(QRegularExpression("\n\t")));
     default:
         break;
     }
@@ -281,14 +275,6 @@ fill_prefs(module_t *module, gpointer root_ptr)
 
 void PrefsModel::populate()
 {
-    //Since "expert" is really a pseudo protocol, it shouldn't be
-    //categorized with other "real" protocols when it comes to
-    //preferences.  Since it's just a UAT, don't bury it in
-    //with the other protocols
-    module_t *expert_module = prefs_find_module("_ws.expert");
-    if (expert_module)
-       expert_module->use_gui = FALSE;
-
     prefs_modules_foreach_submodules(NULL, fill_prefs, (gpointer)root_);
 
     //Add the "specially handled" preferences
@@ -340,7 +326,9 @@ QString PrefsModel::typeToString(int type)
 
 AdvancedPrefsModel::AdvancedPrefsModel(QObject * parent)
 : QSortFilterProxyModel(parent),
-filter_()
+filter_(),
+show_changed_values_(false),
+passwordChar_(QApplication::style()->styleHint(QStyle::SH_LineEdit_PasswordCharacter))
 {
 }
 
@@ -399,7 +387,12 @@ QVariant AdvancedPrefsModel::data(const QModelIndex &dataindex, int role) const
             if (item->getPref() == NULL)
                 return QVariant();
 
-            return sourceModel()->data(sourceModel()->index(modelIndex.row(), PrefsModel::colValue, modelIndex.parent()), role);
+            if (PREF_PASSWORD == item->getPrefType())
+            {
+                return QString(sourceModel()->data(sourceModel()->index(modelIndex.row(), PrefsModel::colValue, modelIndex.parent()), role).toString().size(), passwordChar_);
+            } else {
+                return sourceModel()->data(sourceModel()->index(modelIndex.row(), PrefsModel::colValue, modelIndex.parent()), role);
+            }
         default:
             break;
         }
@@ -496,6 +489,9 @@ bool AdvancedPrefsModel::setData(const QModelIndex &dataindex, const QVariant &v
         case PREF_STRING:
             prefs_set_string_value(item->getPref(), value.toString().toStdString().c_str(), pref_stashed);
             break;
+        case PREF_PASSWORD:
+            prefs_set_password_value(item->getPref(), value.toString().toStdString().c_str(), pref_stashed);
+            break;
         case PREF_DECODE_AS_RANGE:
         case PREF_RANGE:
             prefs_set_stashed_range_value(item->getPref(), value.toString().toUtf8().constData());
@@ -586,7 +582,7 @@ void AdvancedPrefsModel::setFirstColumnSpanned(QTreeView* tree, const QModelInde
 
 bool AdvancedPrefsModel::filterAcceptItem(PrefsItem& item) const
 {
-    if (filter_.isEmpty())
+    if (filter_.isEmpty() && !show_changed_values_)
         return true;
 
     QString name, tooltip;
@@ -599,7 +595,18 @@ bool AdvancedPrefsModel::filterAcceptItem(PrefsItem& item) const
         tooltip = prefs_get_description(item.getPref());
     }
 
-    if (name.contains(filter_, Qt::CaseInsensitive) || tooltip.contains(filter_, Qt::CaseInsensitive))
+    if (show_changed_values_ && item.getPref()) {
+        // UATs and custom preferences are "unknown", do not show when show_changed_only.
+        if (item.isPrefDefault() || item.getPrefType() == PREF_UAT || item.getPrefType() == PREF_CUSTOM) {
+            return false;
+        } else if (filter_.isEmpty()) {
+            return true;
+        }
+    }
+
+    // Do not match module title or description when having show_changed_only.
+    if (!(filter_.isEmpty() || (show_changed_values_ && !item.getPref())) &&
+        (name.contains(filter_, Qt::CaseInsensitive) || tooltip.contains(filter_, Qt::CaseInsensitive)))
         return true;
 
     PrefsItem *child_item;
@@ -636,7 +643,11 @@ void AdvancedPrefsModel::setFilter(const QString& filter)
     invalidateFilter();
 }
 
-
+void AdvancedPrefsModel::setShowChangedValues(bool show_changed_values)
+{
+    show_changed_values_ = show_changed_values;
+    invalidateFilter();
+}
 
 
 
