@@ -110,7 +110,7 @@ QString Mtp3SummaryDialog::summaryToHtml()
         << table_data_tmpl.arg(file_size_to_qstring(summary.file_length))
         << table_row_end;
 
-    QString format_str = wtap_file_type_subtype_string(summary.file_type);
+    QString format_str = wtap_file_type_subtype_description(summary.file_type);
     const char *compression_type_description = wtap_compression_type_description(summary.compression_type);
     if (compression_type_description != NULL) {
         format_str += QString(" (%1)").arg(compression_type_description);
@@ -287,6 +287,8 @@ void Mtp3SummaryDialog::updateWidgets()
 
 extern "C" {
 
+void register_tap_listener_qt_mtp3_summary(void);
+
 static void
 mtp3_summary_reset(
     void        *tapdata)
@@ -298,12 +300,13 @@ mtp3_summary_reset(
 }
 
 
-static gboolean
+static tap_packet_status
 mtp3_summary_packet(
     void            *tapdata,
     packet_info     *,
     epan_dissect_t  *,
-    const void      *data)
+    const void      *data,
+    tap_flags_t)
 {
     mtp3_stat_t           (*stat_p)[MTP3_MAX_NUM_OPC_DPC] = (mtp3_stat_t(*)[MTP3_MAX_NUM_OPC_DPC])tapdata;
     const mtp3_tap_rec_t  *data_p = (const mtp3_tap_rec_t *)data;
@@ -314,8 +317,9 @@ mtp3_summary_packet(
         /*
          * we thought this si_code was not used ?
          * is MTP3_NUM_SI_CODE out of date ?
+         * XXX - if this is an error, report it and return TAP_PACKET_FAILED.
          */
-        return(FALSE);
+        return(TAP_PACKET_DONT_REDRAW);
     }
 
     /*
@@ -341,8 +345,9 @@ mtp3_summary_packet(
         {
             /*
              * too many
+             * XXX - report an error and return TAP_PACKET_FAILED?
              */
-            return(FALSE);
+            return(TAP_PACKET_DONT_REDRAW);
         }
 
         mtp3_num_used++;
@@ -353,7 +358,7 @@ mtp3_summary_packet(
     (*stat_p)[i].mtp3_si_code[data_p->mtp3_si_code].num_msus++;
     (*stat_p)[i].mtp3_si_code[data_p->mtp3_si_code].size += data_p->size;
 
-    return(TRUE);
+    return(TAP_PACKET_REDRAW);
 }
 
 void
@@ -380,16 +385,3 @@ register_tap_listener_qt_mtp3_summary(void)
 }
 
 } // extern "C"
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
