@@ -550,7 +550,6 @@ void PacketList::selectionChanged (const QItemSelection & selected, const QItemS
         selection_history_.resize(cur_history_);
         selection_history_.append(cap_file_->current_frame->num);
     }
-    in_history_ = false;
 
     related_packet_delegate_.clear();
 
@@ -1038,6 +1037,8 @@ void PacketList::setRecentColumnWidth(int col)
 
 void PacketList::drawCurrentPacket()
 {
+    // XXX - Update for multi-select? If more than one packet is Selected,
+    // this changes it so that only the Current packet is Selected.
     QModelIndex current_index = currentIndex();
     if (selectionModel() && current_index.isValid()) {
         selectionModel()->clearSelection();
