@@ -1,4 +1,4 @@
-/* preferences_dialog.h
+/** @file
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -60,6 +60,7 @@ private:
 private slots:
     void selectPane(QString pane);
     void on_advancedSearchLineEdit_textEdited(const QString &search_re);
+    void on_showChangedValuesCheckBox_toggled(bool checked);
 
     void on_buttonBox_accepted();
     void on_buttonBox_rejected();
