@@ -1,4 +1,4 @@
-/* color_utils.h
+/** @file
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -22,7 +22,6 @@
 
 class ColorUtils : public QObject
 {
-    Q_OBJECT
 public:
     explicit ColorUtils(QObject *parent = 0);
 
@@ -71,16 +70,18 @@ public:
      */
     static const QColor contrastingTextColor(const QColor color);
 
+    /**
+     * Returns an appropriate background color for hovered abstract items.
+     * @return The background color.
+     */
+    static const QColor hoverBackground();
+
     /**
      * Returns an appropriate warning background color for the current mode.
      * @return The background color.
      */
     static const QColor warningBackground();
 
-signals:
-
-public slots:
-
 private:
     static QList<QRgb> graph_colors_;
     static QList<QRgb> sequence_colors_;
