@@ -18,15 +18,17 @@
 
 // References:
 //
-// http://standards.freedesktop.org/icon-theme-spec/icon-theme-spec-latest.html
-// http://standards.freedesktop.org/icon-naming-spec/icon-naming-spec-latest.html
+// https://specifications.freedesktop.org/icon-theme-spec/icon-theme-spec-latest.html
+// https://specifications.freedesktop.org/icon-naming-spec/icon-naming-spec-latest.html
 //
-// http://mithatkonar.com/wiki/doku.php/qt/icons
+// https://mithatkonar.com/wiki/doku.php/qt/icons
 //
-// https://developer.apple.com/library/mac/documentation/userexperience/conceptual/applehiguidelines/IconsImages/IconsImages.html#//apple_ref/doc/uid/20000967-TPXREF102
-// http://msdn.microsoft.com/en-us/library/windows/desktop/dn742485.aspx
-// https://developer.gnome.org/hig-book/stable/icons-types.html.en
-// http://msdn.microsoft.com/en-us/library/ms246582.aspx
+// https://web.archive.org/web/20140829010224/https://developer.apple.com/library/mac/documentation/userexperience/conceptual/applehiguidelines/IconsImages/IconsImages.html
+// https://developer.apple.com/design/human-interface-guidelines/macos/icons-and-images/image-size-and-resolution/
+// https://developer.apple.com/design/human-interface-guidelines/macos/icons-and-images/app-icon/
+// https://docs.microsoft.com/en-us/windows/win32/uxguide/vis-icons
+// https://developer.gnome.org/hig/stable/icons-and-artwork.html.en
+// https://docs.microsoft.com/en-us/visualstudio/designers/the-visual-studio-image-library
 
 // To do:
 // - 32x32, 48x48, 64x64, and unscaled (.svg) icons.
@@ -38,12 +40,12 @@
 //   GTK_STOCK_PREFERENCES preferences-system
 //   GTK_STOCK_HELP help-contents
 
-#include "wireshark_application.h"
-
+#include <QApplication>
 #include <QFile>
 #include <QFontMetrics>
 #include <QMap>
 #include <QPainter>
+#include <QPainterPath>
 #include <QStyle>
 #include <QStyleOption>
 
@@ -69,13 +71,13 @@ StockIcon::StockIcon(const QString icon_name) :
 
     // Is this is an icon we've manually mapped to a standard pixmap below?
     if (icon_name_to_standard_pixmap_.contains(icon_name)) {
-        QIcon standard_icon = wsApp->style()->standardIcon(icon_name_to_standard_pixmap_[icon_name]);
+        QIcon standard_icon = qApp->style()->standardIcon(icon_name_to_standard_pixmap_[icon_name]);
         swap(standard_icon);
         return;
     }
 
     // Is this one of our locally sourced, cage-free, organic icons?
-    QStringList types = QStringList() << "8x8" << "14x14" << "16x16" << "24x14" << "24x24";
+    QStringList types = QStringList() << "24x24" << "24x14" << "16x16" << "14x14" << "8x8";
     QList<QIcon::Mode> icon_modes = QList<QIcon::Mode>()
             << QIcon::Disabled
             << QIcon::Active
@@ -94,7 +96,7 @@ StockIcon::StockIcon(const QString icon_name) :
                 QPixmap mask_pm = mask_icon.pixmap(sz);
                 QImage normal_img(sz, QImage::Format_ARGB32);
                 QPainter painter(&normal_img);
-                QBrush br(wsApp->palette().color(QPalette::Active, QPalette::WindowText));
+                QBrush br(qApp->palette().color(QPalette::Active, QPalette::WindowText));
                 painter.fillRect(0, 0, sz.width(), sz.height(), br);
                 painter.setCompositionMode(QPainter::CompositionMode_DestinationIn);
                 painter.drawPixmap(0, 0, mask_pm);
@@ -104,9 +106,9 @@ StockIcon::StockIcon(const QString icon_name) :
                 addPixmap(normal_pm, QIcon::Normal, QIcon::Off);
 
                 QStyleOption opt = {};
-                opt.palette = wsApp->palette();
+                opt.palette = qApp->palette();
                 foreach (QIcon::Mode icon_mode, icon_modes) {
-                    QPixmap mode_pm = wsApp->style()->generatedIconPixmap(icon_mode, normal_pm, &opt);
+                    QPixmap mode_pm = qApp->style()->generatedIconPixmap(icon_mode, normal_pm, &opt);
                     addPixmap(mode_pm, icon_mode, QIcon::On);
                     addPixmap(mode_pm, icon_mode, QIcon::Off);
                 }
@@ -144,7 +146,7 @@ StockIcon::StockIcon(const QString icon_name) :
 // Create a square icon filled with the specified color.
 QIcon StockIcon::colorIcon(const QRgb bg_color, const QRgb fg_color, const QString glyph)
 {
-    QList<int> sizes = QList<int>() << 12 << 16 << 24 << 32 << 48;
+    QList<int> sizes = QList<int>() << 48 << 32 << 24 << 16 << 12;
     QIcon color_icon;
 
     foreach (int size, sizes) {
@@ -156,7 +158,7 @@ QIcon StockIcon::colorIcon(const QRgb bg_color, const QRgb fg_color, const QStri
         painter.drawRect(border);
 
         if (!glyph.isEmpty()) {
-            QFont font(wsApp->font());
+            QFont font(qApp->font());
             font.setPointSizeF(size / 2.0);
             painter.setFont(font);
             QRectF bounding = painter.boundingRect(pm.rect(), glyph, Qt::AlignHCenter | Qt::AlignVCenter);
@@ -168,6 +170,78 @@ QIcon StockIcon::colorIcon(const QRgb bg_color, const QRgb fg_color, const QStri
     return color_icon;
 }
 
+// Create a triangle icon filled with the specified color.
+QIcon StockIcon::colorIconTriangle(const QRgb bg_color, const QRgb fg_color)
+{
+    QList<int> sizes = QList<int>() << 48 << 32 << 24 << 16 << 12;
+    QIcon color_icon;
+
+    foreach (int size, sizes) {
+        QPixmap pm(size, size);
+        QPainter painter(&pm);
+        QPainterPath triangle;
+        pm.fill();
+        painter.fillRect(0, 0, size-1, size-1, Qt::transparent);
+        painter.setPen(fg_color);
+        painter.setBrush(QColor(bg_color));
+        triangle.moveTo(0, size-1);
+        triangle.lineTo(size-1, size-1);
+        triangle.lineTo((size-1)/2, 0);
+        triangle.closeSubpath();
+        painter.fillPath(triangle, QColor(bg_color));
+
+        color_icon.addPixmap(pm);
+    }
+    return color_icon;
+}
+
+// Create a cross icon filled with the specified color.
+QIcon StockIcon::colorIconCross(const QRgb bg_color, const QRgb fg_color)
+{
+    QList<int> sizes = QList<int>() << 48 << 32 << 24 << 16 << 12;
+    QIcon color_icon;
+
+    foreach (int size, sizes) {
+        QPixmap pm(size, size);
+        QPainter painter(&pm);
+        QPainterPath cross;
+        pm.fill();
+        painter.fillRect(0, 0, size-1, size-1, Qt::transparent);
+        painter.setPen(QPen(QBrush(bg_color), 3));
+        painter.setBrush(QColor(fg_color));
+        cross.moveTo(0, 0);
+        cross.lineTo(size-1, size-1);
+        cross.moveTo(0, size-1);
+        cross.lineTo(size-1, 0);
+        painter.drawPath(cross);
+
+        color_icon.addPixmap(pm);
+    }
+    return color_icon;
+}
+
+// Create a circle icon filled with the specified color.
+QIcon StockIcon::colorIconCircle(const QRgb bg_color, const QRgb fg_color)
+{
+    QList<int> sizes = QList<int>() << 48 << 32 << 24 << 16 << 12;
+    QIcon color_icon;
+
+    foreach (int size, sizes) {
+        QPixmap pm(size, size);
+        QPainter painter(&pm);
+        QRect border(2, 2, size - 3, size - 3);
+        pm.fill();
+        painter.fillRect(0, 0, size-1, size-1, Qt::transparent);
+        painter.setPen(QPen(QBrush(bg_color), 3));
+        painter.setBrush(QColor(fg_color));
+        painter.setBrush(QColor(bg_color));
+        painter.drawEllipse(border);
+
+        color_icon.addPixmap(pm);
+    }
+    return color_icon;
+}
+
 void StockIcon::fillIconNameMap()
 {
     // Note that some of Qt's standard pixmaps are awful. We shouldn't add an
@@ -177,16 +251,3 @@ void StockIcon::fillIconNameMap()
     icon_name_to_standard_pixmap_["media-playback-start"] = QStyle::SP_MediaPlay;
     icon_name_to_standard_pixmap_["media-playback-stop"] = QStyle::SP_MediaStop;
 }
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
