@@ -85,7 +85,8 @@ void WiresharkDialog::dialogCleanup(bool closeDialog)
     }
 
     if (retap_depth_ < 1 && dialog_closed_) {
-        disconnect();
+        // Is this disconnection necessary?
+        disconnect(&cap_file_, &CaptureFile::captureEvent, this, &WiresharkDialog::captureEvent);
         deleteLater();
     }
 }
@@ -95,7 +96,7 @@ void WiresharkDialog::updateWidgets()
     setWindowSubtitle(subtitle_);
 }
 
-bool WiresharkDialog::registerTapListener(const char *tap_name, void *tap_data, const char *filter, guint flags, void (*tap_reset)(void *), tap_packet_status (*tap_packet)(void *, struct _packet_info *, struct epan_dissect *, const void *), void (*tap_draw)(void *))
+bool WiresharkDialog::registerTapListener(const char *tap_name, void *tap_data, const char *filter, guint flags, tap_reset_cb tap_reset, tap_packet_cb tap_packet, tap_draw_cb tap_draw)
 {
     GString *error_string = register_tap_listener(tap_name, tap_data, filter, flags,
                                                   tap_reset, tap_packet, tap_draw, NULL);
