@@ -1,4 +1,4 @@
-/* 5views.h
+/** @file
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -12,7 +12,5 @@
 #include "wtap.h"
 
 wtap_open_return_val _5views_open(wtap *wth, int *err, gchar **err_info);
-gboolean _5views_dump_open(wtap_dumper *wdh, int *err, gchar **err_info);
-int _5views_dump_can_write_encap(int encap);
 
 #endif
