@@ -52,7 +52,6 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <errno.h>
 #include "wtap-int.h"
 #include "file_wrappers.h"
 #include "ipfix.h"
@@ -116,13 +115,13 @@ ipfix_read_message_header(ipfix_message_header_t *pfx_hdr, FILE_T fh, int *err,
     if (pfx_hdr->version != IPFIX_VERSION) {
         /* Not an ipfix file. */
         *err = WTAP_ERR_BAD_FILE;
-        *err_info = g_strdup_printf("ipfix: wrong version %d", pfx_hdr->version);
+        *err_info = ws_strdup_printf("ipfix: wrong version %d", pfx_hdr->version);
         return FALSE;
     }
 
     if (pfx_hdr->message_length < 16) {
         *err = WTAP_ERR_BAD_FILE;
-        *err_info = g_strdup_printf("ipfix: message length %u is too short", pfx_hdr->message_length);
+        *err_info = ws_strdup_printf("ipfix: message length %u is too short", pfx_hdr->message_length);
         return FALSE;
     }
 
@@ -155,6 +154,7 @@ ipfix_read_message(FILE_T fh, wtap_rec *rec, Buffer *buf, int *err, gchar **err_
      */
 
     rec->rec_type = REC_TYPE_PACKET;
+    rec->block = wtap_block_create(WTAP_BLOCK_PACKET);
     rec->presence_flags = WTAP_HAS_TS;
     rec->rec_header.packet_header.len = msg_hdr.message_length;
     rec->rec_header.packet_header.caplen = msg_hdr.message_length;
@@ -290,7 +290,7 @@ ipfix_read(wtap *wth, wtap_rec *rec, Buffer *buf, int *err,
     gchar **err_info, gint64 *data_offset)
 {
     *data_offset = file_tell(wth->fh);
-    ws_debug("offset is initially %" G_GINT64_MODIFIER "d", *data_offset);
+    ws_debug("offset is initially %" PRId64, *data_offset);
 
     if (!ipfix_read_message(wth->fh, rec, buf, err, err_info)) {
         ws_debug("couldn't read message header with code: %d\n, and error '%s'",
@@ -314,7 +314,7 @@ ipfix_seek_read(wtap *wth, gint64 seek_off, wtap_rec *rec,
         return FALSE;   /* Seek error */
     }
 
-    ws_debug("reading at offset %" G_GINT64_MODIFIER "u", seek_off);
+    ws_debug("reading at offset %" PRIu64, seek_off);
 
     if (!ipfix_read_message(wth->random_fh, rec, buf, err, err_info)) {
         ws_debug("couldn't read message header");
