@@ -14,7 +14,6 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <errno.h>
 #include "wtap-int.h"
 #include "file_wrappers.h"
 #include "atm.h"
@@ -482,6 +481,9 @@ static const struct {
 	/* USB 2.0/1.1/1.0 packets as transmitted over the cable */
 	{ 288,		WTAP_ENCAP_USB_2_0 },
 
+	/* ATSC Link-Layer Protocol (A/330) packets */
+	{ 289,		WTAP_ENCAP_ATSC_ALP },
+
 	/* Event Tracing for Windows records */
 	{ 290,		WTAP_ENCAP_ETW },
 
@@ -493,6 +495,18 @@ static const struct {
 	{ 294,		WTAP_ENCAP_USB_2_0_FULL_SPEED },
 	{ 295,		WTAP_ENCAP_USB_2_0_HIGH_SPEED },
 
+	/* Auerswald log file captured from any supported Auerswald device */
+	{ 296,		WTAP_ENCAP_AUERSWALD_LOG },
+
+	/* Silicon Labs debug channel */
+	{ 298,		WTAP_ENCAP_SILABS_DEBUG_CHANNEL },
+
+	/* Ultra-wideband (UWB) controller interface protocol (UCI) */
+	{ 299,		WTAP_ENCAP_FIRA_UCI },
+
+	/* MDB (Multi-Drop Bus) */
+	{ 300,		WTAP_ENCAP_MDB },
+
 	/*
 	 * To repeat:
 	 *
@@ -982,7 +996,6 @@ pcap_write_sunatm_pseudoheader(wtap_dumper *wdh,
 	phtons(&atm_hdr[SUNATM_VCI], pseudo_header->atm.vci);
 	if (!wtap_dump_file_write(wdh, atm_hdr, sizeof(atm_hdr), err))
 		return FALSE;
-	wdh->bytes_dumped += sizeof(atm_hdr);
 	return TRUE;
 }
 
@@ -1040,7 +1053,6 @@ pcap_write_irda_pseudoheader(wtap_dumper *wdh,
 	phtons(&irda_hdr[IRDA_SLL_PROTOCOL_OFFSET], 0x0017);
 	if (!wtap_dump_file_write(wdh, irda_hdr, sizeof(irda_hdr), err))
 		return FALSE;
-	wdh->bytes_dumped += sizeof(irda_hdr);
 	return TRUE;
 }
 
@@ -1094,7 +1106,6 @@ pcap_write_mtp2_pseudoheader(wtap_dumper *wdh,
 	    pseudo_header->mtp2.link_number);
 	if (!wtap_dump_file_write(wdh, mtp2_hdr, sizeof(mtp2_hdr), err))
 		return FALSE;
-	wdh->bytes_dumped += sizeof(mtp2_hdr);
 	return TRUE;
 }
 
@@ -1160,7 +1171,6 @@ pcap_write_lapd_pseudoheader(wtap_dumper *wdh,
 	    pseudo_header->lapd.we_network?0x01:0x00;
 	if (!wtap_dump_file_write(wdh, lapd_hdr, sizeof(lapd_hdr), err))
 		return FALSE;
-	wdh->bytes_dumped += sizeof(lapd_hdr);
 	return TRUE;
 }
 
@@ -1219,7 +1229,6 @@ pcap_write_sita_pseudoheader(wtap_dumper *wdh,
 	sita_hdr[SITA_PROTO_OFFSET]   = pseudo_header->sita.sita_proto;
 	if (!wtap_dump_file_write(wdh, sita_hdr, sizeof(sita_hdr), err))
 		return FALSE;
-	wdh->bytes_dumped += sizeof(sita_hdr);
 	return TRUE;
 }
 
@@ -1268,7 +1277,6 @@ pcap_write_bt_pseudoheader(wtap_dumper *wdh,
 	bt_hdr.direction = GUINT32_TO_BE(direction);
 	if (!wtap_dump_file_write(wdh, &bt_hdr, sizeof bt_hdr, err))
 		return FALSE;
-	wdh->bytes_dumped += sizeof bt_hdr;
 	return TRUE;
 }
 
@@ -1318,7 +1326,6 @@ pcap_write_bt_monitor_pseudoheader(wtap_dumper *wdh,
 
 	if (!wtap_dump_file_write(wdh, &bt_monitor_hdr, sizeof bt_monitor_hdr, err))
 		return FALSE;
-	wdh->bytes_dumped += sizeof bt_monitor_hdr;
 	return TRUE;
 }
 
@@ -1359,7 +1366,6 @@ pcap_write_llcp_pseudoheader(wtap_dumper *wdh,
 	phdr[LLCP_FLAGS_OFFSET] = pseudo_header->llcp.flags;
 	if (!wtap_dump_file_write(wdh, &phdr, sizeof phdr, err))
 		return FALSE;
-	wdh->bytes_dumped += sizeof phdr;
 	return TRUE;
 }
 
@@ -1407,7 +1413,6 @@ pcap_write_ppp_pseudoheader(wtap_dumper *wdh,
 	ppp_hdr.direction = (pseudo_header->p2p.sent ? 1 : 0);
 	if (!wtap_dump_file_write(wdh, &ppp_hdr, sizeof ppp_hdr, err))
 		return FALSE;
-	wdh->bytes_dumped += sizeof ppp_hdr;
 	return TRUE;
 }
 
@@ -1606,7 +1611,6 @@ pcap_write_erf_pseudoheader(wtap_dumper *wdh,
 	phtons(&erf_hdr[14], pseudo_header->erf.phdr.wlen);
 	if (!wtap_dump_file_write(wdh, erf_hdr,  sizeof(struct erf_phdr), err))
 		return FALSE;
-	wdh->bytes_dumped += sizeof(struct erf_phdr);
 
 	/*
 	 * Now write out the extension headers.
@@ -1624,7 +1628,6 @@ pcap_write_erf_pseudoheader(wtap_dumper *wdh,
 				erf_exhdr[0] = erf_exhdr[0] & 0x7F;
 			if (!wtap_dump_file_write(wdh, erf_exhdr, 8, err))
 				return FALSE;
-			wdh->bytes_dumped += 8;
 			i++;
 		} while (type & 0x80 && i < max);
 	}
@@ -1644,14 +1647,12 @@ pcap_write_erf_pseudoheader(wtap_dumper *wdh,
 		if (!wtap_dump_file_write(wdh, erf_subhdr,
 		    sizeof(struct erf_mc_hdr), err))
 			return FALSE;
-		wdh->bytes_dumped += sizeof(struct erf_mc_hdr);;
 		break;
 	case ERF_TYPE_AAL2:
 		phtonl(&erf_subhdr[0], pseudo_header->erf.subhdr.aal2_hdr);
 		if (!wtap_dump_file_write(wdh, erf_subhdr,
 		    sizeof(struct erf_aal2_hdr), err))
 			return FALSE;
-		wdh->bytes_dumped += sizeof(struct erf_aal2_hdr);;
 		break;
 	case ERF_TYPE_ETH:
 	case ERF_TYPE_COLOR_ETH:
@@ -1661,7 +1662,6 @@ pcap_write_erf_pseudoheader(wtap_dumper *wdh,
 		if (!wtap_dump_file_write(wdh, erf_subhdr,
 		    sizeof(struct erf_eth_hdr), err))
 			return FALSE;
-		wdh->bytes_dumped += sizeof(struct erf_eth_hdr);
 		break;
 	default:
 		break;
@@ -1719,7 +1719,6 @@ pcap_write_i2c_linux_pseudoheader(wtap_dumper *wdh,
 	phtonl((guint8 *)&i2c_linux_hdr.flags, pseudo_header->i2c.flags);
 	if (!wtap_dump_file_write(wdh, &i2c_linux_hdr, sizeof(i2c_linux_hdr), err))
 		return FALSE;
-	wdh->bytes_dumped += sizeof(i2c_linux_hdr);
 	return TRUE;
 }
 
@@ -1932,13 +1931,26 @@ struct usb_device_setup_hdr {
 		PBSWAP64((guint8 *)fieldp); \
 	}
 
-struct can_socketcan_hdr {
-	guint32 can_id;			/* CAN ID and flags */
-	guint8 payload_length;		/* Frame payload length */
-	guint8 padding;
-	guint8 reserved1;
-	guint8 reserved2;
-};
+/*
+ * Offset and length of the CAN ID field in the CAN classic/CAN FD
+ * SocketCAN header.
+ */
+#define CAN_CANFD_CAN_ID_OFFSET		0
+#define CAN_CANFD_CAN_ID_LEN		4
+
+/*
+ * Offsets and lengths of fields in the CAN XL SocketCAN header.
+ */
+#define CANXL_PRIORITY_VCID_OFFSET	0
+#define CANXL_PRIORITY_VCID_LEN		4
+#define CANXL_FLAGS_OFFSET		(CANXL_PRIORITY_VCID_OFFSET + CANXL_PRIORITY_VCID_LEN)
+#define CANXL_FLAGS_LEN			1
+#define CANXL_SDU_TYPE_OFFSET		(CANXL_FLAGS_OFFSET + CANXL_FLAGS_LEN)
+#define CANXL_SDU_TYPE_LEN		1
+#define CANXL_PAYLOAD_LENGTH_OFFSET	(CANXL_SDU_TYPE_OFFSET + CANXL_SDU_TYPE_LEN)
+#define CANXL_PAYLOAD_LENGTH_LEN	2
+#define CANXL_ACCEPTANCE_FIELD_OFFSET	(CANXL_PAYLOAD_LENGTH_OFFSET + CANXL_PAYLOAD_LENGTH_LEN)
+#define CANXL_ACCEPTANCE_FIELD_LEN	4
 
 /*
  * CAN fake link-layer headers in Linux cooked packets.
@@ -1952,15 +1964,65 @@ struct can_socketcan_hdr {
 /*
  * The protocols we have to check for.
  */
-#define LINUX_SLL_P_CAN			0x000C	/* Controller Area Network */
+#define LINUX_SLL_P_CAN			0x000C	/* Controller Area Network classic */
 #define LINUX_SLL_P_CANFD		0x000D	/* Controller Area Network flexible data rate */
+#define LINUX_SLL_P_CANXL		0x000E	/* Controller Area Network extended length */
+
+static void
+pcap_byteswap_can_socketcan_pseudoheader(guint packet_size, guint16 protocol,
+    guint8 *pd)
+{
+	switch (protocol) {
+
+	case LINUX_SLL_P_CAN:
+	case LINUX_SLL_P_CANFD:
+		/*
+		 * CAN classic or CAN FD; byte-swap the ID/flags field
+		 * into our host byte order.
+		 *
+		 * Make sure we have the entire field.
+		 */
+		if (packet_size < (CAN_CANFD_CAN_ID_OFFSET + CAN_CANFD_CAN_ID_LEN)) {
+			/* Not enough data to have the full CAN ID */
+			return;
+		}
+		PBSWAP32(&pd[CAN_CANFD_CAN_ID_OFFSET]);
+		break;
+
+	case LINUX_SLL_P_CANXL:
+		/*
+		 * CAN classic or CAN FD; byte-swap the priority-and-VCID
+		 * field, the payload length, ad the acceptance field
+		 * into our host byte order.
+		 */
+		if (packet_size < (CANXL_PRIORITY_VCID_OFFSET + CANXL_PRIORITY_VCID_LEN)) {
+			/* Not enough data to have the full priority/VCID field */
+			return;
+		}
+		PBSWAP32(&pd[CANXL_PRIORITY_VCID_OFFSET]);
+		if (packet_size < (CANXL_PAYLOAD_LENGTH_OFFSET + CANXL_PAYLOAD_LENGTH_LEN)) {
+			/* Not enough data to have the full payload length field */
+			return;
+		}
+		PBSWAP16(&pd[CANXL_PAYLOAD_LENGTH_OFFSET]);
+		if (packet_size < (CANXL_ACCEPTANCE_FIELD_OFFSET + CANXL_ACCEPTANCE_FIELD_LEN)) {
+			/* Not enough data to have the full payload length field */
+			return;
+		}
+		PBSWAP32(&pd[CANXL_ACCEPTANCE_FIELD_OFFSET]);
+		break;
+
+	default:
+		/* Not a CAN packet; nothing to fix */
+		return;
+	}
+}
 
 static void
 pcap_byteswap_linux_sll_pseudoheader(wtap_rec *rec, guint8 *pd)
 {
 	guint packet_size;
 	guint16 protocol;
-	struct can_socketcan_hdr *can_socketcan_phdr;
 
 	/*
 	 * Minimum of captured and actual length (just in case the
@@ -1976,26 +2038,12 @@ pcap_byteswap_linux_sll_pseudoheader(wtap_rec *rec, guint8 *pd)
 		return;
 	}
 
-	protocol = pntoh16(&pd[LINUX_SLL_PROTOCOL_OFFSET]);
-	if (protocol != LINUX_SLL_P_CAN && protocol != LINUX_SLL_P_CANFD) {
-		/* Not a CAN packet; nothing to fix */
-		return;
-	}
-
 	/*
-	 * Greasy hack, but we never directly dereference any of
-	 * the fields in *can_socketcan_phdr, we just get offsets
-	 * of and addresses of its members and byte-swap it with a
-	 * byte-at-a-time macro, so it's alignment-safe.
+	 * Byte-swap the SocketCAN pseudoheader, if we have one.
 	 */
-	can_socketcan_phdr = (struct can_socketcan_hdr *)(void *)(pd + LINUX_SLL_LEN);
-
-	if (packet_size < LINUX_SLL_LEN + sizeof(can_socketcan_phdr->can_id)) {
-		/* Not enough data to have the full CAN ID */
-		return;
-	}
-
-	PBSWAP32((guint8 *)&can_socketcan_phdr->can_id);
+	protocol = pntoh16(&pd[LINUX_SLL_PROTOCOL_OFFSET]);
+	pcap_byteswap_can_socketcan_pseudoheader(packet_size - LINUX_SLL_LEN,
+	    protocol, pd + LINUX_SLL_LEN);
 }
 
 static void
@@ -2003,7 +2051,6 @@ pcap_byteswap_linux_sll2_pseudoheader(wtap_rec *rec, guint8 *pd)
 {
 	guint packet_size;
 	guint16 protocol;
-	struct can_socketcan_hdr *can_socketcan_phdr;
 
 	/*
 	 * Minimum of captured and actual length (just in case the
@@ -2019,26 +2066,12 @@ pcap_byteswap_linux_sll2_pseudoheader(wtap_rec *rec, guint8 *pd)
 		return;
 	}
 
-	protocol = pntoh16(&pd[LINUX_SLL2_PROTOCOL_OFFSET]);
-	if (protocol != LINUX_SLL_P_CAN && protocol != LINUX_SLL_P_CANFD) {
-		/* Not a CAN packet; nothing to fix */
-		return;
-	}
-
 	/*
-	 * Greasy hack, but we never directly dereference any of
-	 * the fields in *can_socketcan_phdr, we just get offsets
-	 * of and addresses of its members and byte-swap it with a
-	 * byte-at-a-time macro, so it's alignment-safe.
+	 * Byte-swap the SocketCAN pseudoheader, if we have one.
 	 */
-	can_socketcan_phdr = (struct can_socketcan_hdr *)(void *)(pd + LINUX_SLL2_LEN);
-
-	if (packet_size < LINUX_SLL2_LEN + sizeof(can_socketcan_phdr->can_id)) {
-		/* Not enough data to have the full CAN ID */
-		return;
-	}
-
-	PBSWAP32((guint8 *)&can_socketcan_phdr->can_id);
+	protocol = pntoh16(&pd[LINUX_SLL2_PROTOCOL_OFFSET]);
+	pcap_byteswap_can_socketcan_pseudoheader(packet_size - LINUX_SLL2_LEN,
+	    protocol, pd + LINUX_SLL2_LEN);
 }
 
 static void
@@ -2578,7 +2611,15 @@ pcap_read_post_process(gboolean is_nokia, int wtap_encap,
 		break;
 
 	case WTAP_ENCAP_ETHERNET:
-		rec->rec_header.packet_header.pseudo_header.eth.fcs_len = fcs_len;
+		/*
+		 * The FCS length is supposed to be in bits.
+		 * If it's < 8, assume it's in bytes; otherwise,
+		 * convert it to bytes.
+		 */
+		if (fcs_len < 8)
+			rec->rec_header.packet_header.pseudo_header.eth.fcs_len = fcs_len;
+		else
+			rec->rec_header.packet_header.pseudo_header.eth.fcs_len = fcs_len/8;
 		break;
 
 	case WTAP_ENCAP_SLL:
