@@ -193,7 +193,7 @@ wtap_open_return_val toshiba_open(wtap *wth, int *err, gchar **err_info)
 	wth->snapshot_length = 0; /* not known */
 	wth->subtype_read = toshiba_read;
 	wth->subtype_seek_read = toshiba_seek_read;
-	wth->file_tsprec = WTAP_TSPREC_CSEC;
+	wth->file_tsprec = WTAP_TSPREC_10_MSEC;
 
 	return WTAP_OPEN_MINE;
 }
@@ -308,7 +308,7 @@ parse_toshiba_packet(FILE_T fh, wtap_rec *rec, Buffer *buf,
 		 * to allocate space for an immensely-large packet.
 		 */
 		*err = WTAP_ERR_BAD_FILE;
-		*err_info = g_strdup_printf("toshiba: File has %u-byte packet, bigger than maximum of %u",
+		*err_info = ws_strdup_printf("toshiba: File has %u-byte packet, bigger than maximum of %u",
 		    (guint)pkt_len, WTAP_MAX_PACKET_SIZE_STANDARD);
 		return FALSE;
 	}
