@@ -69,6 +69,45 @@ add_model_name_to_string(void * key, void * value _U_,
     return false;
 }
 
+static const char *
+get_translator_name(void)
+{
+  #if defined(__APPLE__) /* Darwin */
+    /*
+     * OK, are we running x86(-64) code on Arm(64) under Rosetta?
+     *
+     * See
+     *
+     *    https://developer.apple.com/documentation/apple-silicon/about-the-rosetta-translation-environment#Determine-Whether-Your-App-Is-Running-as-a-Translated-Binary
+     */
+    int proc_translated;
+    size_t proc_translated_len = sizeof proc_translated;
+
+    if (sysctlbyname("sysctl.proc_translated", &proc_translated,
+                     &proc_translated_len, NULL, 0) == -1) {
+        /*
+         * errno = ENOENT means there's no such name; presumably
+         * that means there's no translator to check for, so we're
+         * not running under translation.
+         *
+         * For other errors, we just punt.
+         */
+        return NULL;
+    }
+    return proc_translated ? "Rosetta 2" : NULL;
+  #else
+    /*
+     * XXX - handle Windows x86-64-to-ARM64 translator, possibly with
+     * IsWow64Process2(); see
+     *
+     *    https://learn.microsoft.com/en-us/windows/win32/api/wow64apiset/nf-wow64apiset-iswow64process2
+     *
+     * Any others?
+     */
+    return NULL;
+  #endif
+}
+
 /*
  * Get the CPU info, and append it to the GString
  *
@@ -84,6 +123,7 @@ void
 get_cpu_info(GString *str)
 {
     GTree *model_names = g_tree_new_full(compare_model_names, NULL, g_free, NULL);
+    const char *translator_name;
 
 #if defined(__linux__)
     /*
@@ -456,6 +496,18 @@ get_cpu_info(GString *str)
     /* We're done; get rid of the tree. */
     g_tree_destroy(model_names);
 
+    /*
+     * Are we running under a translator?
+     */
+    translator_name = get_translator_name();
+    if (translator_name != NULL) {
+        /*
+         * Yes.
+         */
+         g_string_append(str, " running ");
+         g_string_append(str, translator_name);
+    }
+
     /*
      * We do this on all OSes and instruction sets, so that we don't
      * have to figure out how to dredge the "do we have SSE 4.2?"
