@@ -27,9 +27,10 @@ static uint32_t postseed;
 void
 wmem_init_hashing(void)
 {
+    /* Get a random odd integer to multiply the hash by. */
     x = g_random_int();
-    if (G_UNLIKELY(x == 0))
-        x = 1;
+    if ((x % 2) == 0)
+        x += 1;
 
     preseed  = g_random_int();
     postseed = g_random_int();
@@ -231,8 +232,8 @@ wmem_map_contains(wmem_map_t *map, const void *key)
 {
     wmem_map_item_t *item;
 
-    /* Make sure we have a table */
-    if (map->table == NULL) {
+    /* Make sure we have map and a table */
+    if (map == NULL || map->table == NULL) {
         return false;
     }
 
@@ -255,8 +256,8 @@ wmem_map_lookup(wmem_map_t *map, const void *key)
 {
     wmem_map_item_t *item;
 
-    /* Make sure we have a table */
-    if (map->table == NULL) {
+    /* Make sure we have map and a table */
+    if (map == NULL || map->table == NULL) {
         return NULL;
     }
 
@@ -279,8 +280,8 @@ wmem_map_lookup_extended(wmem_map_t *map, const void *key, const void **orig_key
 {
     wmem_map_item_t *item;
 
-    /* Make sure we have a table */
-    if (map->table == NULL) {
+    /* Make sure we have map and a table */
+    if (map == NULL || map->table == NULL) {
         return false;
     }
 
@@ -310,8 +311,8 @@ wmem_map_remove(wmem_map_t *map, const void *key)
     wmem_map_item_t **item, *tmp;
     void *value;
 
-    /* Make sure we have a table */
-    if (map->table == NULL) {
+    /* Make sure we have map and a table */
+    if (map == NULL || map->table == NULL) {
         return NULL;
     }
 
@@ -341,8 +342,8 @@ wmem_map_steal(wmem_map_t *map, const void *key)
 {
     wmem_map_item_t **item, *tmp;
 
-    /* Make sure we have a table */
-    if (map->table == NULL) {
+    /* Make sure we have map and a table */
+    if (map == NULL || map->table == NULL) {
         return false;
     }
 
@@ -395,7 +396,7 @@ wmem_map_foreach(wmem_map_t *map, GHFunc foreach_func, void * user_data)
     unsigned i;
 
     /* Make sure we have a table */
-    if (map->table == NULL) {
+    if (map == NULL || map->table == NULL) {
         return;
     }
 
@@ -415,7 +416,7 @@ wmem_map_foreach_remove(wmem_map_t *map, GHRFunc foreach_func, void * user_data)
     unsigned i, deleted = 0;
 
     /* Make sure we have a table */
-    if (map->table == NULL) {
+    if (map == NULL || map->table == NULL) {
         return 0;
     }
 
